# -*- coding: cp1250 -*-

"""
plik: displacementAnalyzerComp.py
autor: Krzysztof Szajek (biuro@soldis.com.pl)

Przykad reguy wymiarowania analizujcej przemieszczenia.

Modu stanowi integraln cz progrmau Soldis PROJEKTANT. Zabrania si rozpowszechniania fragmentw lub caoci poniszego kodu bez zgody AUTORA. Szczegowe warunki licencji - patrz: licencja/licence.txt w katalogu instalacyjnym programu.
"""

#general
from dnBaseLib import *

#python modules
import os
import random
import types
import copy

#solsec modules
import dnConstants
import dnComponent
import dnComponentDlg

#soldis
import sdConstants
import sdRTFReport
import sdSchemeImageMaker

#soldis env
import soSymbols

#ext
import PyRTF


DISPLACEMENT_X=trans(u'Przemieszczenia x')
DISPLACEMENT_Y=trans(u'Przemieszczenia y')
DISPLACEMENT_R=trans(u'Przemieszczenia wypadkowe')
DISPLACEMENT_FI=trans(u'Przemieszczenia ktowe')
        
class DisplacementAnalyzerDlg_classic(dnComponentDlg.ComponentContextBeamDlg):
    controlWidth=12
    def __init__(self, parent, compObj, **kw):

        #klasa nadrzedna
        dnComponentDlg.ComponentContextBeamDlg.__init__(self, parent, compObj, **kw)

        #rejestracja zakladek
        tabObj=self.registerGeneralTab(addSubjectChooser=True)
        #tabObj=self.registerProfileTab()
        self.registerLoadCombTab()
        self.registerTab('general', image=self._createImage('tab_general'),
                         createFunc=self.createGeneralTab, updateFun=self.updateGeneralTab, subjectId=[0, 1, 2, 3])
        self.registerStdResultTab()

        #dodanie listy z rzednymi i typami wynikow
        self.registerOrdinateChooser()
        self.registerTypeChooser()

        #rejestracja widoku przekroju z zakladka podstawowa
        self.registerSectionView(activeSectionEdges=False)                
        self.registerGeneralSectionViewTab()

        #rejestracja przyciskow
        self.registerOrdinateButton()
        self.registerSizingPointsButton()
        self.registerDefaultPointsNumberControl()
        self.registerNextPrevButtons()
        self.setDefaultTab(tabObj['name'])
        
        #buduj okno
        self.build()

    def setVars(self):

        #rejestracja zmiennych projektowych              
        self._addVar('useXLimit', type='IntVar')
        self._addVar('useYLimit', type='IntVar')
        self._addVar('useRLimit', type='IntVar')
        self._addVar('useFiLimit', type='IntVar')
        
        self._addVar('xLocal', type='IntVar')
        self._addVar('yLocal', type='IntVar')
        #self._addVar('rLocal', type='IntVar')

        self._addVar('yChord', type='IntVar')
        
        self._addVar('xLimit', type='DoubleVar')
        self._addVar('yLimit', type='DoubleVar')
        self._addVar('rLimit', type='DoubleVar')
        self._addVar('fiLimit', type='DoubleVar')
        
        
    #
    def _createGeneralResults(self, tab):
        

        #wstaw ramke
        sFrame=soLabelFrame(tab, text=trans(u'Wyniki'), padding=[2,5,2,5])

        resFrame=Frame(sFrame)
        resFrame.pack(expand=1, fill=BOTH, padx=3, pady=3)

        #ustawienia
        labelSettings={ 'justify': LEFT, 'anchor':W}#'width':10,
        
        #wstaw opis
        l=soLabel(resFrame, text=trans(u'Zestawienie wartoci ektremalnych dla elementu'))
        l.grid(row=0, column=1, sticky=E, columnspan=6, pady=3)        
        
        ##PRZEMIESZCZENIE X
        l=soLabel(resFrame, text=self.getCompObj().summarySubjects[0]+': ')
        l.grid(row=2, column=1, sticky=E)

        l=soLabel(resFrame, image=self._createImage('res_dispXMax'))
        l.grid(row=2, column=3, sticky=E)
        self.res_dispX_value=soLabel(resFrame, **labelSettings)
        self.res_dispX_value.grid(row=2, column=4, sticky=W)
        self.res_dispX_signum=soLabel(resFrame, text='')
        self.res_dispX_signum.grid(row=2, column=5, sticky=E)
        self.res_dispX_allowed=soLabel(resFrame, text='')
        self.res_dispX_allowed.grid(row=2, column=6, sticky=E)
        l=soLabel(resFrame, image=self._createImage('res_dispXMaxLimit'))
        l.grid(row=2, column=7, sticky=W)
        
        ##PRZEMIESZCZENIE y
        l=soLabel(resFrame, text=self.getCompObj().summarySubjects[1]+': ')
        l.grid(row=3, column=1, sticky=E)

        l=soLabel(resFrame, image=self._createImage('res_dispYMax'))
        l.grid(row=3, column=3, sticky=E)
        self.res_dispY_value=soLabel(resFrame, **labelSettings)
        self.res_dispY_value.grid(row=3, column=4, sticky=W)
        self.res_dispY_signum=soLabel(resFrame, text='')
        self.res_dispY_signum.grid(row=3, column=5, sticky=E)
        self.res_dispY_allowed=soLabel(resFrame, text='')
        self.res_dispY_allowed.grid(row=3, column=6, sticky=E)
        l=soLabel(resFrame, image=self._createImage('res_dispYMaxLimit'))
        l.grid(row=3, column=7, sticky=W)

        ##PRZEMIESZCZENIE WYPADKOWE
        l=soLabel(resFrame, text=self.getCompObj().summarySubjects[2]+': ')
        l.grid(row=4, column=1, sticky=E)

        l=soLabel(resFrame, image=self._createImage('res_dispRMax'))
        l.grid(row=4, column=3, sticky=E)
        self.res_dispR_value=soLabel(resFrame, **labelSettings)
        self.res_dispR_value.grid(row=4, column=4, sticky=W)
        self.res_dispR_signum=soLabel(resFrame, text='')
        self.res_dispR_signum.grid(row=4, column=5, sticky=E)
        self.res_dispR_allowed=soLabel(resFrame, text='')
        self.res_dispR_allowed.grid(row=4, column=6, sticky=E)
        l=soLabel(resFrame, image=self._createImage('res_dispRMaxLimit'))
        l.grid(row=4, column=7, sticky=W)

        ##PRZEMIESZCZENIE KATOWE
        l=soLabel(resFrame, text=self.getCompObj().summarySubjects[3]+': ')
        l.grid(row=5, column=1, sticky=E)

        l=soLabel(resFrame, image=self._createImage('res_dispFiMax'))
        l.grid(row=5, column=3, sticky=E)
        self.res_dispFi_value=soLabel(resFrame, **labelSettings)
        self.res_dispFi_value.grid(row=5, column=4, sticky=W)
        self.res_dispFi_signum=soLabel(resFrame, text='')
        self.res_dispFi_signum.grid(row=5, column=5, sticky=E)
        self.res_dispFi_allowed=soLabel(resFrame, text='')
        self.res_dispFi_allowed.grid(row=5, column=6, sticky=E)
        l=soLabel(resFrame, image=self._createImage('res_dispFiMaxLimit'))
        l.grid(row=5, column=7, sticky=W)
        
        return sFrame



    def createGeneralTab(self, tab):

        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=DISPLACEMENT_X, padding=[5,0,5,0])
        f.pack(padx=5, pady=1, fill=X)

        #wstawienie ramki
        f1=Frame(f)
        f1.pack()
        f1.columnconfigure(0, weight=1)
        f1.columnconfigure(99, weight=1)

        #wstawienie ramki
        dispLimitLF=Frame(f1)
        dispLimitLF.grid(row=4, column=1, columnspan=1, sticky=E+W, pady=3)
        dispLimitLF.columnconfigure(0, weight=1)
        dispLimitLF.columnconfigure(99, weight=1)
        
        #ustawienia limitu
        def _checkIfFloat(x):
            #check if float            
            try:
                float(x)
                return True
            except:
                return False     

        def limitValidate(x):
            if not _checkIfFloat(x):
                x=1.0
            if float(x)>10e9:
                x=10e6
            if float(x)<10e-6:
                x=0.
            return x

        def onUseXLimit():
            #change control
            self.xLimitCon['state']=[DISABLED, NORMAL][self.var_useXLimit.get()]
            self.localXChB['state']=[DISABLED, NORMAL][self.var_useXLimit.get()]
                
        self.useXDispChB=soCheckbutton(dispLimitLF,
                                                variable=self.var_useXLimit,
                                                command=onUseXLimit,
                                                text=trans(u'Ogranicz przemieszczenia po kierunku x')
                                                )
        self.useXDispChB.grid(row=2, column=1, columnspan=1, sticky=W)

        #ustawienia limitu
        self.xLimitCon = soControl(dispLimitLF,
                                    label=' ---> '+trans(u'Limit [m]: '),
                                    variable=self.var_xLimit,
                                    step=0.01,
                                    allowempty=False,
                                    validatecmd=limitValidate)
        self.xLimitCon['selectmode']='normal'
        self.xLimitCon.entry['width']=self.controlWidth
        self.xLimitCon.grid(row=2, column=2, columnspan=1)

        self.localXChB=soCheckbutton(dispLimitLF,
                                                variable=self.var_xLocal,
                                                text=trans(u'Lokalne')
                                                )
        self.localXChB.grid(row=2, column=3, columnspan=2, padx=5)


        s=soSeparator(f, orient='horizontal')
        s.pack(fill=X, pady=2)

        f0=Frame(f)
        f0.pack(fill=X)

        #dodanie podstawowych informacji o wynikach        
        self.disp_res_x_generalInfo=dnComponentDlg.GeneralInfo(f0, hideIfNoData=True)
        self.disp_res_x_generalInfo.pack()

        #dodanie ramki
        f10=Frame(f)
        f10.pack(fill=X)

        #warunke projektowy
        self.disp_res_x_comparison=dnComponentDlg.Comparison(f10, hideIfNoData=True,
                                                      lImage=self._createImage('res_dispXMax'),
                                                      rImage=self._createImage('res_dispXMaxLimit'),
                                                      lFormat='%.4f', rFormat='%.4f')
        self.disp_res_x_comparison.pack()

        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=DISPLACEMENT_Y, padding=[5,0,5,0])
        f.pack(padx=5, pady=1, fill=X)
        f.columnconfigure(0, weight=1)

        #utworzenie ramki
        f1=Frame(f)
        f1.pack()
        f1.columnconfigure(0, weight=1)
        f1.columnconfigure(99, weight=1)

        #utworzenie ramki
        dispLimitLF=Frame(f1)
        dispLimitLF.grid(row=4, column=1, columnspan=1, sticky=E+W, pady=3)

        #ustawienia limitu
        def onUseYLimit():
            #change control
            self.yLimitCon['state']=[DISABLED, NORMAL][self.var_useYLimit.get()]
            self.localYChB['state']=[DISABLED, NORMAL][self.var_useYLimit.get()]
            if self.var_useYLimit.get() and self.var_yLocal.get():
                self.chordChB['state']=NORMAL
            else:
                self.var_yChord.set(False)
                self.chordChB['state']=DISABLED
                
        self.useYDispChB=soCheckbutton(dispLimitLF,
                                                variable=self.var_useYLimit,
                                                command=onUseYLimit,
                                                text=trans(u'Ogranicz przemieszczenia po kierunku y')
                                                )
        self.useYDispChB.grid(row=5, column=0, columnspan=1, sticky=W)

        self.yLimitCon = soControl(dispLimitLF,
                                    label=' ---> '+trans(u'Limit [m]: '),
                                    variable=self.var_yLimit,
                                    step=0.01,
                                    allowempty=False,
                                    validatecmd=limitValidate)
        self.yLimitCon['selectmode']='normal'
        self.yLimitCon.entry['width']=self.controlWidth
        self.yLimitCon.grid(row=5, column=1, columnspan=1)

        def onChangeYLocal():
            #change control
            if self.var_yLocal.get():
                self.chordChB['state']=NORMAL
            else:
                self.var_yChord.set(False)
                self.chordChB['state']=DISABLED
            
        self.localYChB=soCheckbutton(dispLimitLF,
                                                variable=self.var_yLocal,
                                                text=trans(u'Lokalne'),
                                                command=onChangeYLocal,
                                                )
        self.localYChB.grid(row=5, column=2, columnspan=1, padx=5)

        f1=Frame(dispLimitLF)
        f1.grid(row=6, column=0, columnspan=3)


        self.chordChB=soCheckbutton(f1,
                                                variable=self.var_yChord,
                                                text=trans(u'Mierz od ciciwy prta')
                                                )
        self.chordChB.pack()

        s=soSeparator(f, orient='horizontal')
        s.pack(fill=X, pady=2)

        #wstawienie ramki
        f0=Frame(f)
        f0.pack(fill=X)

        #dodanie podstawowych informacji o wynikach        
        self.disp_res_y_generalInfo=dnComponentDlg.GeneralInfo(f0, hideIfNoData=True)
        self.disp_res_y_generalInfo.pack()

        #warunek projektowy
        self.disp_res_y_comparison=dnComponentDlg.Comparison(f0, hideIfNoData=True,
                                                      lImage=self._createImage('res_dispYMax'),
                                                      rImage=self._createImage('res_dispYMaxLimit'),
                                                      lFormat='%.4f', rFormat='%.4f')
        self.disp_res_y_comparison.pack()

        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=DISPLACEMENT_R, padding=[5,0,5,0])
        f.pack(padx=5, pady=1, fill=X)
        f.columnconfigure(0, weight=1)

        #utworzenie ramki
        f1=Frame(f)
        f1.pack()
        f1.columnconfigure(0, weight=1)
        f1.columnconfigure(99, weight=1)

        #utworzenie ramki
        dispLimitLF=Frame(f1)
        dispLimitLF.grid(row=4, column=1, columnspan=1, sticky=E+W, pady=3)

        #kontrola limitu
        def onUseRLimit():
            #change control
            self.rLimitCon['state']=[DISABLED, NORMAL][self.var_useRLimit.get()]
            #self.localRChB['state']=[DISABLED, NORMAL][self.var_useRLimit.get()]
                
        self.useRDispChB=soCheckbutton(dispLimitLF,
                                                variable=self.var_useRLimit,
                                                command=onUseRLimit,
                                                text=trans(u'Ogranicz przemieszczenia wypadkowe')
                                                )
        self.useRDispChB.grid(row=9, column=0, columnspan=1, sticky=W)

        self.rLimitCon = soControl(dispLimitLF,
                                    label=' ---> '+trans(u'Limit [m]: '),
                                    variable=self.var_rLimit,
                                    step=0.01,
                                    allowempty=False,
                                    validatecmd=limitValidate)
        self.rLimitCon['selectmode']='normal'
        self.rLimitCon.entry['width']=self.controlWidth
        self.rLimitCon.grid(row=9, column=1, columnspan=1)

        #dodanie separatora
        s=soSeparator(f, orient='horizontal')
        s.pack(fill=X, pady=2)

        #wstawienie ramki
        f0=Frame(f)
        f0.pack(fill=X)

        #dodanie podstawowych informacji o wynikach        
        self.disp_res_r_generalInfo=dnComponentDlg.GeneralInfo(f0, hideIfNoData=True)
        self.disp_res_r_generalInfo.pack()

        #warunek projektowy
        self.disp_res_r_comparison=dnComponentDlg.Comparison(f0, hideIfNoData=True,
                                                      lImage=self._createImage('res_dispRMax'),
                                                      rImage=self._createImage('res_dispRMaxLimit'),
                                                      lFormat='%.4f', rFormat='%.4f')
        self.disp_res_r_comparison.pack()

        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=DISPLACEMENT_FI, padding=[5,0,5,0])
        f.pack(padx=5, pady=1, fill=X)
        f.columnconfigure(0, weight=1)

        #utworzenie ramki
        f1=Frame(f)
        f1.pack()
        f1.columnconfigure(0, weight=1)
        f1.columnconfigure(99, weight=1)

        #utworzenie ramki
        dispLimitLF=Frame(f1)
        dispLimitLF.grid(row=4, column=1, columnspan=1, sticky=E+W, pady=3)

        #kontrola limitu
        def onUseFiLimit():
            self.fiLimitCon['state']=[DISABLED, NORMAL][self.var_useFiLimit.get()]
                
        self.useFiDispChB=soCheckbutton(dispLimitLF,
                                                variable=self.var_useFiLimit,
                                                command=onUseFiLimit,
                                                text=trans(u'Ogranicz przemieszczenia ktowe')
                                                )
        self.useFiDispChB.grid(row=13, column=0, columnspan=1, sticky=W)
        
        self.fiLimitCon = soControl(dispLimitLF,
                                    label=' ---> '+trans(u'Limit [rad]: '),
                                    variable=self.var_fiLimit,
                                    step=0.01,
                                    allowempty=False,
                                    validatecmd=limitValidate)
        self.fiLimitCon['selectmode']='normal'
        self.fiLimitCon.entry['width']=self.controlWidth
        self.fiLimitCon.grid(row=13, column=1, columnspan=1)

        #wstaw separator
        s=soSeparator(f, orient='horizontal')
        s.pack(fill=X, pady=2)

        #utworzenie ramki
        f0=Frame(f)
        f0.pack(fill=X)

        #dodanie podstawowych informacji o wynikach        
        self.disp_res_fi_generalInfo=dnComponentDlg.GeneralInfo(f0, hideIfNoData=True)
        self.disp_res_fi_generalInfo.pack()

        #warunek projektowy
        self.disp_res_fi_comparison=dnComponentDlg.Comparison(f0,
                                                      lImage=self._createImage('res_dispFiMax'),
                                                      rImage=self._createImage('res_dispFiMaxLimit'),
                                                      lFormat='%.4f', rFormat='%.4f', hideIfNoData=True)
        self.disp_res_fi_comparison.pack()

        ################################

        #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
        self.addUpdateTabFunctions('general', updateFunc=[onUseFiLimit,
                                                          onUseRLimit,
                                                          onUseYLimit,
                                                          onUseXLimit,
                                                          ])

    #upd
    def updateGeneralTab(self):


        #pobranie wynikw
        resCont=self.getCompObj().getResults()

        #pobranie obiektu z wynikami dla poszczegolnych rzednych
        iprCont=resCont.getInPointResults()

        #pobranie ekstremalnego wyniku dla biezacej rzednej oraz odpowiedniego warunku projektowego i typu wynikow
        ipsData=iprCont.find_theBiggestRatio(types=[self.getCurrentType(), ],
                                             subjects=[DISPLACEMENT_X, ],
                                             ords=[self.getCurrentPoint(), ],
                                             
                                             subject=DISPLACEMENT_X,
                                             )

        #jezeli znaleziono jakikolwiek wynik zwracana jest lista z szczegolowymi informacjami        
        if ipsData!=None and ipsData['calculated']:

            #wyswietlenie wartosci
            self.disp_res_x_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci dla warunkow projektowych
            self.disp_res_x_comparison.setValues(fabs(ipsData['x']), ipsData['limit'])

        
        else:

            #wyczyszczenie            
            self.disp_res_x_generalInfo.clear()
            self.disp_res_x_comparison.clear()


        #######################################

        #pobranie ekstremalnego wyniku dla biezacej rzednej oraz odpowiedniego warunku projektowego i typu wynikow
        ipsData=iprCont.find_theBiggestRatio(types=[self.getCurrentType(), ],
                                             subjects=[DISPLACEMENT_Y, ],
                                             ords=[self.getCurrentPoint(), ],
                                             
                                             subject=DISPLACEMENT_Y,
                                             )
        #jezeli znaleziono jakikolwiek wynik zwracana jest lista z szczegolowymi informacjami
        if ipsData!=None and ipsData['calculated']:


            #wyswietlenie wartosci
            self.disp_res_y_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci dla warunkow projektowych
            self.disp_res_y_comparison.setValues(fabs(ipsData['y']), ipsData['limit'])

        
        else:

            #wyczyszczenie            
            self.disp_res_y_generalInfo.clear()
            self.disp_res_y_comparison.clear()



        #######################################

        #pobranie ekstremalnego wyniku dla biezacej rzednej oraz odpowiedniego warunku projektowego i typu wynikow
        ipsData=iprCont.find_theBiggestRatio(types=[self.getCurrentType(), ],
                                             subjects=[DISPLACEMENT_R, ],
                                             ords=[self.getCurrentPoint(), ],
                                             
                                             subject=DISPLACEMENT_R,
                                             )
        
        #jezeli znaleziono jakikolwiek wynik zwracana jest lista z szczegolowymi informacjami
        if ipsData!=None and ipsData['calculated']:

            #wyswietlenie wartosci
            self.disp_res_r_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci dla warunkow projektowych
            self.disp_res_r_comparison.setValues(fabs(ipsData['r']), ipsData['limit'])

        
        else:

            #wyczyszczenie            
            self.disp_res_r_generalInfo.clear()
            self.disp_res_r_comparison.clear()


        #######################################

        #pobranie ekstremalnego wyniku dla biezacej rzednej oraz odpowiedniego warunku projektowego i typu wynikow
        ipsData=iprCont.find_theBiggestRatio(types=[self.getCurrentType(), ],
                                             subjects=[DISPLACEMENT_FI, ],
                                             ords=[self.getCurrentPoint(), ],
                                             
                                             subject=DISPLACEMENT_FI,
                                             )
        
        #jezeli znaleziono jakikolwiek wynik zwracana jest lista z szczegolowymi informacjami
        if ipsData!=None and ipsData['calculated']:


            #wyswietlenie wartosci
            self.disp_res_fi_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci dla warunkow projektowych
            self.disp_res_fi_comparison.setValues(fabs(ipsData['fi']), ipsData['limit'])

        
        else:

            #wyczyszczenie            
            self.disp_res_fi_generalInfo.clear()
            self.disp_res_fi_comparison.clear()


    #
    def getSize(self):
        return (515, 540)
    

class DisplacementAnalyzerDlg_multiPoint(dnComponentDlg.ComponentContextMultiPointBeamDlg):
    controlWidth=12
    def __init__(self, parent, compObj, **kw):

        #klasa nadrzedna
        dnComponentDlg.ComponentContextMultiPointBeamDlg.__init__(self, parent, compObj, **kw)

        #rejestracja zakladek (parametry projektowe)
        self.registerTab('data',
                         image=self._createImage('tab_data_icon'),
                         createFunc=self.createTab_data,
                         updateFun=self.updateTab_data,
                         tabType=dnConstants.TAB_TYPE_GENERAL_DATA,
                         displayName=u'Ustawienia ogranicze',
                         noUserCheckComment=u'Zwryfikuj parametry wymiarowania',
                         )
        self.registerLoadCombTab()
        self.registerStdResultTab()

        #rejestracja zakladek (wyniki)
        self.registerTab('disp_x',
                         image=self._createImage('tab_x_icon'),
                         createFunc=self.createTab_x,
                         updateFun=self.updateTab_x,
                         subjectId=DISPLACEMENT_X,
                         tabType=dnConstants.TAB_TYPE_RESULT_IN_POINT,
                         displayName=DISPLACEMENT_X,
                         references=['disp_y', 'disp_fi', 'disp_r'
                                     ],#referencja do zakadek z innymi wynikami
                         )
        self.registerTab('disp_y',
                         image=self._createImage('tab_y_icon'),
                         createFunc=self.createTab_y,
                         updateFun=self.updateTab_y,
                         subjectId=DISPLACEMENT_Y,
                         tabType=dnConstants.TAB_TYPE_RESULT_IN_POINT,
                         displayName=DISPLACEMENT_Y,
                         references=['disp_x', 'disp_fi', 'disp_r', 
                                     ],#referencja do zakadek z innymi wynikami
                         )
        self.registerTab('disp_fi',
                         image=self._createImage('tab_fi_icon'),
                         createFunc=self.createTab_fi,
                         updateFun=self.updateTab_fi,
                         subjectId=DISPLACEMENT_FI,
                         tabType=dnConstants.TAB_TYPE_RESULT_IN_POINT,
                         displayName=DISPLACEMENT_FI,
                         references=['disp_x', 'disp_y', 'disp_r',
                                     ],#referencja do zakadek z innymi wynikami, ogranicze i wynikami
                         )
        self.registerTab('disp_r',
                         image=self._createImage('tab_r_icon'),
                         createFunc=self.createTab_r,
                         updateFun=self.updateTab_r,
                         subjectId=DISPLACEMENT_R,
                         tabType=dnConstants.TAB_TYPE_RESULT_IN_POINT,
                         displayName=DISPLACEMENT_R,
                         references=['disp_x', 'disp_y', 'disp_fi', 
                                     ],#referencja do zakadek z innymi wynikami
                         )
        
        #dodanie listy z rzednymi i typami wynikow
        self.registerTypeChooser()

        #rejestracja widoku przekroju z zakladka podstawowa
        self.registerSectionView(activeSectionEdges=False)                
        self.registerGeneralSectionViewTab()

        #rejestracja przyciskow
        self.registerOrdinateButton()
        self.registerSizingPointsButton()
        self.registerDefaultPointsNumberControl()
        self.registerRaportGeneratorButton()
        
        #buduj okno
        self.build()

    def setVars(self):

        #rejestracja zmiennych projektowych              
        self._addVar('useXLimit', type='IntVar')
        self._addVar('useYLimit', type='IntVar')
        self._addVar('useRLimit', type='IntVar')
        self._addVar('useFiLimit', type='IntVar')
        
        self._addVar('xLocal', type='IntVar')
        self._addVar('yLocal', type='IntVar')
        #self._addVar('rLocal', type='IntVar')

        self._addVar('yChord', type='IntVar')
        
        self._addVar('xLimit', type='DoubleVar')
        self._addVar('yLimit', type='DoubleVar')
        self._addVar('rLimit', type='DoubleVar')
        self._addVar('fiLimit', type='DoubleVar')
        
        
    #
    def _checkIfFloat(self, x):
        #check if float            
        try:
            float(x)
            return True
        except:
            return False
        
    def _limitValidate(self, x):
        
        if not self._checkIfFloat(x):
            x=1.0
        if float(x)>10e9:
            x=10e6
        if float(x)<10e-6:
            x=0.
        return x
    
    def createTab_data(self, tab):

        #zmienne pomocnicze
        spacer=6*' '

        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=DISPLACEMENT_Y, padding=[5,0,5,0])
        f.pack(padx=5, pady=1, fill=X)
        f.columnconfigure(0, weight=1)

        #utworzenie ramki
        f1=Frame(f)
        f1.pack()
        #f1.columnconfigure(0, weight=1)
        f1.columnconfigure(99, weight=1)

        #utworzenie ramki
        dispLimitLF=Frame(f1)
        dispLimitLF.grid(row=4, column=1, columnspan=1, sticky=E+W, pady=3)

        #ustawienia limitu
        def onUseYLimit():
            #change control
            yLimitCon['state']=[DISABLED, NORMAL][self.var_useYLimit.get()]
            localYChB['state']=[DISABLED, NORMAL][self.var_useYLimit.get()]
            if self.var_useYLimit.get() and self.var_yLocal.get():
                chordChB['state']=NORMAL
            else:
                self.var_yChord.set(False)
                chordChB['state']=DISABLED
                
        useYDispChB=soCheckbutton(dispLimitLF,
                                                variable=self.var_useYLimit,
                                                command=onUseYLimit,
                                                text=trans(u'Ogranicz przemieszczenia po kierunku y')
                                                )
        useYDispChB.grid(row=5, column=0, columnspan=3, sticky=W)

        yLimitCon = soControl(dispLimitLF,
                                    label=spacer+trans(u'Limit [m]: '),
                                    variable=self.var_yLimit,
                                    step=0.01,
                                    allowempty=False,
                                    validatecmd=self._limitValidate)
        yLimitCon['selectmode']='normal'
        yLimitCon.entry['width']=self.controlWidth
        yLimitCon.grid(row=6, column=0, columnspan=1, sticky=W)

        def onChangeYLocal():
            #change control
            if self.var_yLocal.get():
                chordChB['state']=NORMAL
            else:
                self.var_yChord.set(False)
                chordChB['state']=DISABLED
            
        localYChB=soCheckbutton(dispLimitLF,
                                                variable=self.var_yLocal,
                                                text=trans(u'Lokalne'),
                                                command=onChangeYLocal,
                                                )
        localYChB.grid(row=6, column=1, columnspan=1, padx=5)

        f1=Frame(dispLimitLF)
        f1.grid(row=7, column=0, columnspan=3)


        chordChB=soCheckbutton(f1,
                                                variable=self.var_yChord,
                                                text=trans(u'Mierz od ciciwy prta')
                                                )
        chordChB.pack()


        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=DISPLACEMENT_X, padding=[5,0,5,0])
        f.pack(padx=5, pady=1, fill=X)

        #wstawienie ramki
        f1=Frame(f)
        f1.pack()
        #f1.columnconfigure(0, weight=1)
        f1.columnconfigure(99, weight=1)

        #wstawienie ramki
        dispLimitLF=Frame(f1)
        dispLimitLF.grid(row=4, column=1, columnspan=1, sticky=E+W, pady=3)
        #dispLimitLF.columnconfigure(0, weight=1)
        dispLimitLF.columnconfigure(99, weight=1)
        
        #ustawienia limitu
        def onUseXLimit():
            #change control
            xLimitCon['state']=[DISABLED, NORMAL][self.var_useXLimit.get()]
            localXChB['state']=[DISABLED, NORMAL][self.var_useXLimit.get()]
                
        useXDispChB=soCheckbutton(dispLimitLF,
                                                variable=self.var_useXLimit,
                                                command=onUseXLimit,
                                                text=trans(u'Ogranicz przemieszczenia po kierunku x')
                                                )
        useXDispChB.grid(row=2, column=1, columnspan=2, sticky=W)

        #ustawienia limitu
        xLimitCon = soControl(dispLimitLF,
                                    label=spacer+trans(u'Limit [m]: '),
                                    variable=self.var_xLimit,
                                    step=0.01,
                                    allowempty=False,
                                    validatecmd=self._limitValidate)
        xLimitCon['selectmode']='normal'
        xLimitCon.entry['width']=self.controlWidth
        xLimitCon.grid(row=3, column=1, columnspan=1, sticky=W)

        localXChB=soCheckbutton(dispLimitLF,
                                                variable=self.var_xLocal,
                                                text=trans(u'Lokalne')
                                                )
        localXChB.grid(row=3, column=2, columnspan=1, padx=5)


        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=DISPLACEMENT_R, padding=[5,0,5,0])
        f.pack(padx=5, pady=1, fill=X)
        f.columnconfigure(0, weight=1)

        #utworzenie ramki
        f1=Frame(f)
        f1.pack()
        #f1.columnconfigure(0, weight=1)
        f1.columnconfigure(99, weight=1)

        #utworzenie ramki
        dispLimitLF=Frame(f1)
        dispLimitLF.grid(row=4, column=1, columnspan=1, sticky=E+W, pady=3)

        #kontrola limitu
        def onUseRLimit():
            #change control
            rLimitCon['state']=[DISABLED, NORMAL][self.var_useRLimit.get()]
            #self.localRChB['state']=[DISABLED, NORMAL][self.var_useRLimit.get()]
                
        useRDispChB=soCheckbutton(dispLimitLF,
                                                variable=self.var_useRLimit,
                                                command=onUseRLimit,
                                                text=trans(u'Ogranicz przemieszczenia wypadkowe')
                                                )
        useRDispChB.grid(row=9, column=0, columnspan=2, sticky=W)

        rLimitCon = soControl(dispLimitLF,
                                    label=spacer+trans(u'Limit [m]: '),
                                    variable=self.var_rLimit,
                                    step=0.01,
                                    allowempty=False,
                                    validatecmd=self._limitValidate)
        rLimitCon['selectmode']='normal'
        rLimitCon.entry['width']=self.controlWidth
        rLimitCon.grid(row=10, column=0, columnspan=1, sticky=W)


        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=DISPLACEMENT_FI, padding=[5,0,5,0])
        f.pack(padx=5, pady=1, fill=X)
        f.columnconfigure(0, weight=1)

        #utworzenie ramki
        f1=Frame(f)
        f1.pack()
        #f1.columnconfigure(0, weight=1)
        f1.columnconfigure(99, weight=1)

        #utworzenie ramki
        dispLimitLF=Frame(f1)
        dispLimitLF.grid(row=4, column=1, columnspan=1, sticky=E+W, pady=3)

        #kontrola limitu
        def onUseFiLimit():
            fiLimitCon['state']=[DISABLED, NORMAL][self.var_useFiLimit.get()]
                
        useFiDispChB=soCheckbutton(dispLimitLF,
                                                variable=self.var_useFiLimit,
                                                command=onUseFiLimit,
                                                text=trans(u'Ogranicz przemieszczenia ktowe')
                                                )
        useFiDispChB.grid(row=13, column=0, columnspan=2, sticky=W)
        
        fiLimitCon = soControl(dispLimitLF,
                                    label=spacer+trans(u'Limit [rad]: '),
                                    variable=self.var_fiLimit,
                                    step=0.01,
                                    allowempty=False,
                                    validatecmd=self._limitValidate)
        fiLimitCon['selectmode']='normal'
        fiLimitCon.entry['width']=self.controlWidth
        fiLimitCon.grid(row=14, column=0, columnspan=1, sticky=W)


        ################################

        #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
        self.addUpdateTabFunctions('data', updateFunc=[onUseFiLimit,
                                                          onUseRLimit,
                                                          onUseYLimit,
                                                          onUseXLimit,
                                                          ])

    def createTab_x(self, tab):

        #utworzenie ramki
        f=soLabelFrame(tab, text=DISPLACEMENT_X, padding=[5,0,5,0])
        f.pack(padx=5, pady=1, fill=X)
        
        #dodanie podstawowych informacji o wynikach        
        self.disp_res_x_generalInfo=dnComponentDlg.GeneralInfo(f, ordinateText='x/L: ', typeText=u'Komb: ', hideIfNoData=True)
        self.disp_res_x_generalInfo.pack()

        s=soSeparator(f, orient='horizontal')
        s.pack(fill=X, pady=5)

        #warunek projektowy
        self.disp_res_x_comparison=dnComponentDlg.Comparison(f, hideIfNoData=True,
                                                      lImage=self._createImage('res_dispXMax'),
                                                      rImage=self._createImage('res_dispXMaxLimit'),
                                                      lFormat='%.4f', rFormat='%.4f')
        self.disp_res_x_comparison.pack()

        ################################

        s=soSeparatorWithText(f, text='Opcje', orient='horizontal')
        s.pack(fill=X, pady=2)

        #wstawienie ramki
        dispLimitLF=Frame(f)
        dispLimitLF.pack()
        
        #ustawienia limitu
        def onUseXLimit():
            #change control
            xLimitCon['state']=[DISABLED, NORMAL][self.var_useXLimit.get()]
            localXChB['state']=[DISABLED, NORMAL][self.var_useXLimit.get()]
                
        #ustawienia limitu
        xLimitCon = soControl(dispLimitLF,
                                    label=6*' '+trans(u'Limit [m]: '),
                                    variable=self.var_xLimit,
                                    step=0.01,
                                    allowempty=False,
                                    validatecmd=self._limitValidate)
        xLimitCon['selectmode']='normal'
        xLimitCon.entry['width']=self.controlWidth
        xLimitCon.grid(row=3, column=1, columnspan=1, sticky=W)

        localXChB=soCheckbutton(dispLimitLF,
                                                variable=self.var_xLocal,
                                                text=trans(u'Lokalne')
                                                )
        localXChB.grid(row=3, column=2, columnspan=1, padx=5)

        ################################

        #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
        self.addUpdateTabFunctions('disp_x', updateFunc=[onUseXLimit,
                                                          ])

    def createTab_y(self, tab):

        #utworzenie ramki
        f=soLabelFrame(tab, text=DISPLACEMENT_X, padding=[5,0,5,0])
        f.pack(padx=5, pady=1, fill=X)
        
        #dodanie podstawowych informacji o wynikach        
        self.disp_res_y_generalInfo=dnComponentDlg.GeneralInfo(f, ordinateText='x/L: ', typeText=u'Komb: ', hideIfNoData=True)
        self.disp_res_y_generalInfo.pack()

        s=soSeparator(f, orient='horizontal')
        s.pack(fill=X, pady=5)

        #warunek projektowy
        self.disp_res_y_comparison=dnComponentDlg.Comparison(f, hideIfNoData=True,
                                                      lImage=self._createImage('res_dispYMax'),
                                                      rImage=self._createImage('res_dispYMaxLimit'),
                                                      lFormat='%.4f', rFormat='%.4f')
        self.disp_res_y_comparison.pack()

        ################################

        s=soSeparatorWithText(f, text='Opcje', orient='horizontal')
        s.pack(fill=X, pady=2)

        #wstawienie ramki
        dispLimitLF=Frame(f)
        dispLimitLF.pack()


        #ustawienia limitu
        def onUseYLimit():
            #change control
            yLimitCon['state']=[DISABLED, NORMAL][self.var_useYLimit.get()]
            localYChB['state']=[DISABLED, NORMAL][self.var_useYLimit.get()]
                
        #ustawienia limitu
        yLimitCon = soControl(dispLimitLF,
                                    label=6*' '+trans(u'Limit [m]: '),
                                    variable=self.var_yLimit,
                                    step=0.01,
                                    allowempty=False,
                                    validatecmd=self._limitValidate)
        yLimitCon['selectmode']='normal'
        yLimitCon.entry['width']=self.controlWidth
        yLimitCon.grid(row=3, column=1, columnspan=1, sticky=W)



        def onChangeYLocal():
            #change control
            if self.var_yLocal.get():
                chordChB['state']=NORMAL
            else:
                self.var_yChord.set(False)
                chordChB['state']=DISABLED
            
        localYChB=soCheckbutton(dispLimitLF,
                                                variable=self.var_yLocal,
                                                text=trans(u'Lokalne'),
                                                command=onChangeYLocal,
                                                )
        localYChB.grid(row=3, column=2, columnspan=1, padx=5)


        f1=Frame(dispLimitLF)
        f1.grid(row=4, column=1, columnspan=2)


        chordChB=soCheckbutton(f1,
                                                variable=self.var_yChord,
                                                text=trans(u'Mierz od ciciwy prta')
                                                )
        chordChB.pack()


        ################################

        #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
        self.addUpdateTabFunctions('disp_y', updateFunc=[onUseYLimit,
                                                          ])

    def createTab_fi(self, tab):

        #utworzenie ramki
        f=soLabelFrame(tab, text=DISPLACEMENT_FI, padding=[5,0,5,0])
        f.pack(padx=5, pady=1, fill=X)
        
        #dodanie podstawowych informacji o wynikach        
        self.disp_res_fi_generalInfo=dnComponentDlg.GeneralInfo(f, ordinateText='x/L: ', typeText=u'Komb: ', hideIfNoData=True)
        self.disp_res_fi_generalInfo.pack()

        s=soSeparator(f, orient='horizontal')
        s.pack(fill=X, pady=5)

        #warunek projektowy
        self.disp_res_fi_comparison=dnComponentDlg.Comparison(f, hideIfNoData=True,
                                                      lImage=self._createImage('res_dispFiMax'),
                                                      rImage=self._createImage('res_dispFiMaxLimit'),
                                                      lFormat='%.4f', rFormat='%.4f')
        self.disp_res_fi_comparison.pack()

        ################################

        s=soSeparatorWithText(f, text='Opcje', orient='horizontal')
        s.pack(fill=X, pady=2)

        #wstawienie ramki
        dispLimitLF=Frame(f)
        dispLimitLF.pack()
        
        #ustawienia limitu
        def onUseFiLimit():
            #change control
            fiLimitCon['state']=[DISABLED, NORMAL][self.var_useFiLimit.get()]
                
        #ustawienia limitu
        fiLimitCon = soControl(dispLimitLF,
                                    label=trans(u'Limit [rad]: '),
                                    variable=self.var_fiLimit,
                                    step=0.01,
                                    allowempty=False,
                                    validatecmd=self._limitValidate)
        fiLimitCon['selectmode']='normal'
        fiLimitCon.entry['width']=self.controlWidth
        fiLimitCon.grid(row=3, column=1, columnspan=1, sticky=W)


        ################################

        #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
        self.addUpdateTabFunctions('disp_fi', updateFunc=[onUseFiLimit,
                                                          ])

    def createTab_r(self, tab):

        #utworzenie ramki
        f=soLabelFrame(tab, text=DISPLACEMENT_FI, padding=[5,0,5,0])
        f.pack(padx=5, pady=1, fill=X)
        
        #dodanie podstawowych informacji o wynikach        
        self.disp_res_r_generalInfo=dnComponentDlg.GeneralInfo(f, ordinateText='x/L: ', typeText=u'Komb: ', hideIfNoData=True)
        self.disp_res_r_generalInfo.pack()

        s=soSeparator(f, orient='horizontal')
        s.pack(fill=X, pady=5)

        #warunek projektowy
        self.disp_res_r_comparison=dnComponentDlg.Comparison(f, hideIfNoData=True,
                                                      lImage=self._createImage('res_dispRMax'),
                                                      rImage=self._createImage('res_dispRMaxLimit'),
                                                      lFormat='%.4f', rFormat='%.4f')
        self.disp_res_r_comparison.pack()

        ################################

        s=soSeparatorWithText(f, text='Opcje', orient='horizontal')
        s.pack(fill=X, pady=2)

        #wstawienie ramki
        dispLimitLF=Frame(f)
        dispLimitLF.pack()
        
        #ustawienia limitu
        def onUseRLimit():
            #change control
            rLimitCon['state']=[DISABLED, NORMAL][self.var_useRLimit.get()]
                
        #ustawienia limitu
        rLimitCon = soControl(dispLimitLF,
                                    label=trans(u'Limit [rad]: '),
                                    variable=self.var_rLimit,
                                    step=0.01,
                                    allowempty=False,
                                    validatecmd=self._limitValidate)
        rLimitCon['selectmode']='normal'
        rLimitCon.entry['width']=self.controlWidth
        rLimitCon.grid(row=3, column=1, columnspan=1, sticky=W)


        ################################

        #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
        self.addUpdateTabFunctions('disp_r', updateFunc=[onUseRLimit,
                                                          ])


    def createGeneralTab(self, tab):

        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=DISPLACEMENT_X, padding=[5,0,5,0])
        f.pack(padx=5, pady=1, fill=X)

        #wstawienie ramki
        f1=Frame(f)
        f1.pack()
        f1.columnconfigure(0, weight=1)
        f1.columnconfigure(99, weight=1)

        #wstawienie ramki
        dispLimitLF=Frame(f1)
        dispLimitLF.grid(row=4, column=1, columnspan=1, sticky=E+W, pady=3)
        dispLimitLF.columnconfigure(0, weight=1)
        dispLimitLF.columnconfigure(99, weight=1)
        
        #ustawienia limitu
        def onUseXLimit():
            #change control
            self.xLimitCon['state']=[DISABLED, NORMAL][self.var_useXLimit.get()]
            self.localXChB['state']=[DISABLED, NORMAL][self.var_useXLimit.get()]
                
        self.useXDispChB=soCheckbutton(dispLimitLF,
                                                variable=self.var_useXLimit,
                                                command=onUseXLimit,
                                                text=trans(u'Ogranicz przemieszczenia po kierunku x')
                                                )
        self.useXDispChB.grid(row=2, column=1, columnspan=1, sticky=W)

        #ustawienia limitu
        self.xLimitCon = soControl(dispLimitLF,
                                    label=' ---> '+trans(u'Limit [m]: '),
                                    variable=self.var_xLimit,
                                    step=0.01,
                                    allowempty=False,
                                    validatecmd=limitValidate)
        self.xLimitCon['selectmode']='normal'
        self.xLimitCon.entry['width']=self.controlWidth
        self.xLimitCon.grid(row=2, column=2, columnspan=1)

        self.localXChB=soCheckbutton(dispLimitLF,
                                                variable=self.var_xLocal,
                                                text=trans(u'Lokalne')
                                                )
        self.localXChB.grid(row=2, column=3, columnspan=2, padx=5)


        s=soSeparator(f, orient='horizontal')
        s.pack(fill=X, pady=2)

        f0=Frame(f)
        f0.pack(fill=X)

        #dodanie podstawowych informacji o wynikach        
        self.disp_res_x_generalInfo=dnComponentDlg.GeneralInfo(f0, hideIfNoData=True)
        self.disp_res_x_generalInfo.pack()

        #dodanie ramki
        f10=Frame(f)
        f10.pack(fill=X)

        #warunke projektowy
        self.disp_res_x_comparison=dnComponentDlg.Comparison(f10, hideIfNoData=True,
                                                      lImage=self._createImage('res_dispXMax'),
                                                      rImage=self._createImage('res_dispXMaxLimit'),
                                                      lFormat='%.4f', rFormat='%.4f')
        self.disp_res_x_comparison.pack()

        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=DISPLACEMENT_Y, padding=[5,0,5,0])
        f.pack(padx=5, pady=1, fill=X)
        f.columnconfigure(0, weight=1)

        #utworzenie ramki
        f1=Frame(f)
        f1.pack()
        f1.columnconfigure(0, weight=1)
        f1.columnconfigure(99, weight=1)

        #utworzenie ramki
        dispLimitLF=Frame(f1)
        dispLimitLF.grid(row=4, column=1, columnspan=1, sticky=E+W, pady=3)

        #ustawienia limitu
        def onUseYLimit():
            #change control
            self.yLimitCon['state']=[DISABLED, NORMAL][self.var_useYLimit.get()]
            self.localYChB['state']=[DISABLED, NORMAL][self.var_useYLimit.get()]
            if self.var_useYLimit.get() and self.var_yLocal.get():
                self.chordChB['state']=NORMAL
            else:
                self.var_yChord.set(False)
                self.chordChB['state']=DISABLED
                
        self.useYDispChB=soCheckbutton(dispLimitLF,
                                                variable=self.var_useYLimit,
                                                command=onUseYLimit,
                                                text=trans(u'Ogranicz przemieszczenia po kierunku y')
                                                )
        self.useYDispChB.grid(row=5, column=0, columnspan=1, sticky=W)

        self.yLimitCon = soControl(dispLimitLF,
                                    label=' ---> '+trans(u'Limit [m]: '),
                                    variable=self.var_yLimit,
                                    step=0.01,
                                    allowempty=False,
                                    validatecmd=limitValidate)
        self.yLimitCon['selectmode']='normal'
        self.yLimitCon.entry['width']=self.controlWidth
        self.yLimitCon.grid(row=5, column=1, columnspan=1)

        def onChangeYLocal():
            #change control
            if self.var_yLocal.get():
                self.chordChB['state']=NORMAL
            else:
                self.var_yChord.set(False)
                self.chordChB['state']=DISABLED
            
        self.localYChB=soCheckbutton(dispLimitLF,
                                                variable=self.var_yLocal,
                                                text=trans(u'Lokalne'),
                                                command=onChangeYLocal,
                                                )
        self.localYChB.grid(row=5, column=2, columnspan=1, padx=5)

        f1=Frame(dispLimitLF)
        f1.grid(row=6, column=0, columnspan=3)


        self.chordChB=soCheckbutton(f1,
                                                variable=self.var_yChord,
                                                text=trans(u'Mierz od ciciwy prta')
                                                )
        self.chordChB.pack()

        s=soSeparator(f, orient='horizontal')
        s.pack(fill=X, pady=2)

        #wstawienie ramki
        f0=Frame(f)
        f0.pack(fill=X)

        #dodanie podstawowych informacji o wynikach        
        self.disp_res_y_generalInfo=dnComponentDlg.GeneralInfo(f0, hideIfNoData=True)
        self.disp_res_y_generalInfo.pack()

        #warunek projektowy
        self.disp_res_y_comparison=dnComponentDlg.Comparison(f0, hideIfNoData=True,
                                                      lImage=self._createImage('res_dispYMax'),
                                                      rImage=self._createImage('res_dispYMaxLimit'),
                                                      lFormat='%.4f', rFormat='%.4f')
        self.disp_res_y_comparison.pack()

        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=DISPLACEMENT_R, padding=[5,0,5,0])
        f.pack(padx=5, pady=1, fill=X)
        f.columnconfigure(0, weight=1)

        #utworzenie ramki
        f1=Frame(f)
        f1.pack()
        f1.columnconfigure(0, weight=1)
        f1.columnconfigure(99, weight=1)

        #utworzenie ramki
        dispLimitLF=Frame(f1)
        dispLimitLF.grid(row=4, column=1, columnspan=1, sticky=E+W, pady=3)

        #kontrola limitu
        def onUseRLimit():
            #change control
            self.rLimitCon['state']=[DISABLED, NORMAL][self.var_useRLimit.get()]
            #self.localRChB['state']=[DISABLED, NORMAL][self.var_useRLimit.get()]
                
        self.useRDispChB=soCheckbutton(dispLimitLF,
                                                variable=self.var_useRLimit,
                                                command=onUseRLimit,
                                                text=trans(u'Ogranicz przemieszczenia wypadkowe')
                                                )
        self.useRDispChB.grid(row=9, column=0, columnspan=1, sticky=W)

        self.rLimitCon = soControl(dispLimitLF,
                                    label=' ---> '+trans(u'Limit [m]: '),
                                    variable=self.var_rLimit,
                                    step=0.01,
                                    allowempty=False,
                                    validatecmd=limitValidate)
        self.rLimitCon['selectmode']='normal'
        self.rLimitCon.entry['width']=self.controlWidth
        self.rLimitCon.grid(row=9, column=1, columnspan=1)

        #dodanie separatora
        s=soSeparator(f, orient='horizontal')
        s.pack(fill=X, pady=2)

        #wstawienie ramki
        f0=Frame(f)
        f0.pack(fill=X)

        #dodanie podstawowych informacji o wynikach        
        self.disp_res_r_generalInfo=dnComponentDlg.GeneralInfo(f0, hideIfNoData=True)
        self.disp_res_r_generalInfo.pack()

        #warunek projektowy
        self.disp_res_r_comparison=dnComponentDlg.Comparison(f0, hideIfNoData=True,
                                                      lImage=self._createImage('res_dispRMax'),
                                                      rImage=self._createImage('res_dispRMaxLimit'),
                                                      lFormat='%.4f', rFormat='%.4f')
        self.disp_res_r_comparison.pack()

        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=DISPLACEMENT_FI, padding=[5,0,5,0])
        f.pack(padx=5, pady=1, fill=X)
        f.columnconfigure(0, weight=1)

        #utworzenie ramki
        f1=Frame(f)
        f1.pack()
        f1.columnconfigure(0, weight=1)
        f1.columnconfigure(99, weight=1)

        #utworzenie ramki
        dispLimitLF=Frame(f1)
        dispLimitLF.grid(row=4, column=1, columnspan=1, sticky=E+W, pady=3)

        #kontrola limitu
        def onUseFiLimit():
            self.fiLimitCon['state']=[DISABLED, NORMAL][self.var_useFiLimit.get()]
                
        self.useFiDispChB=soCheckbutton(dispLimitLF,
                                                variable=self.var_useFiLimit,
                                                command=onUseFiLimit,
                                                text=trans(u'Ogranicz przemieszczenia ktowe')
                                                )
        self.useFiDispChB.grid(row=13, column=0, columnspan=1, sticky=W)
        
        self.fiLimitCon = soControl(dispLimitLF,
                                    label=' ---> '+trans(u'Limit [rad]: '),
                                    variable=self.var_fiLimit,
                                    step=0.01,
                                    allowempty=False,
                                    validatecmd=limitValidate)
        self.fiLimitCon['selectmode']='normal'
        self.fiLimitCon.entry['width']=self.controlWidth
        self.fiLimitCon.grid(row=13, column=1, columnspan=1)

        #wstaw separator
        s=soSeparator(f, orient='horizontal')
        s.pack(fill=X, pady=2)

        #utworzenie ramki
        f0=Frame(f)
        f0.pack(fill=X)

        #dodanie podstawowych informacji o wynikach        
        self.disp_res_fi_generalInfo=dnComponentDlg.GeneralInfo(f0, hideIfNoData=True)
        self.disp_res_fi_generalInfo.pack()

        #warunek projektowy
        self.disp_res_fi_comparison=dnComponentDlg.Comparison(f0,
                                                      lImage=self._createImage('res_dispFiMax'),
                                                      rImage=self._createImage('res_dispFiMaxLimit'),
                                                      lFormat='%.4f', rFormat='%.4f', hideIfNoData=True)
        self.disp_res_fi_comparison.pack()

        ################################

        #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
        self.addUpdateTabFunctions('general', updateFunc=[onUseFiLimit,
                                                          onUseRLimit,
                                                          onUseYLimit,
                                                          onUseXLimit,
                                                          ])

    #upd
    def updateTab_data(self):
        pass
    def updateTab_x(self, ipsData):

        #ipsData to slownik ze szczegolowymi informacjami zapisanymi w czasie wymiarowania
        if ipsData!=None and ipsData['calculated']:

            #wyswietlenie wartosci
            self.disp_res_x_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci dla warunkow projektowych
            self.disp_res_x_comparison.setValues(fabs(ipsData['x']), ipsData['limit'])

        
        else:

            #wyczyszczenie            
            self.disp_res_x_generalInfo.clear()
            self.disp_res_x_comparison.clear()


    def updateTab_y(self, ipsData):

        #ipsData to slownik ze szczegolowymi informacjami zapisanymi w czasie wymiarowania
        if ipsData!=None and ipsData['calculated']:

            #wyswietlenie wartosci
            self.disp_res_y_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci dla warunkow projektowych
            self.disp_res_y_comparison.setValues(fabs(ipsData['y']), ipsData['limit'])

        
        else:

            #wyczyszczenie            
            self.disp_res_y_generalInfo.clear()
            self.disp_res_y_comparison.clear()

    def updateTab_fi(self, ipsData):

        #ipsData to slownik ze szczegolowymi informacjami zapisanymi w czasie wymiarowania
        if ipsData!=None and ipsData['calculated']:

            #wyswietlenie wartosci
            self.disp_res_fi_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci dla warunkow projektowych
            self.disp_res_fi_comparison.setValues(fabs(ipsData['fi']), ipsData['limit'])
        
        else:

            #wyczyszczenie            
            self.disp_res_fi_generalInfo.clear()
            self.disp_res_fi_comparison.clear()
        
    def updateTab_r(self, ipsData):

        #ipsData to slownik ze szczegolowymi informacjami zapisanymi w czasie wymiarowania  
        if ipsData!=None and ipsData['calculated']:

            #wyswietlenie wartosci
            self.disp_res_r_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci dla warunkow projektowych
            self.disp_res_r_comparison.setValues(fabs(ipsData['r']), ipsData['limit'])
        
        else:

            #wyczyszczenie            
            self.disp_res_r_generalInfo.clear()
            self.disp_res_r_comparison.clear()

    def updateGeneralTab(self):


        #pobranie wynikw
        resCont=self.getCompObj().getResults()

        #pobranie obiektu z wynikami dla poszczegolnych rzednych
        iprCont=resCont.getInPointResults()

        #pobranie ekstremalnego wyniku dla biezacej rzednej oraz odpowiedniego warunku projektowego i typu wynikow
        ipsData=iprCont.find_theBiggestRatio(types=[self.getCurrentType(), ],
                                             subjects=[DISPLACEMENT_X, ],
                                             ords=[self.getCurrentPoint(), ],
                                             
                                             subject=DISPLACEMENT_X,
                                             )

        #jezeli znaleziono jakikolwiek wynik zwracana jest lista z szczegolowymi informacjami        
        if ipsData!=None and ipsData['calculated']:

            #wyswietlenie wartosci
            self.disp_res_x_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci dla warunkow projektowych
            self.disp_res_x_comparison.setValues(fabs(ipsData['x']), ipsData['limit'])

        
        else:

            #wyczyszczenie            
            self.disp_res_x_generalInfo.clear()
            self.disp_res_x_comparison.clear()


        #######################################

        #pobranie ekstremalnego wyniku dla biezacej rzednej oraz odpowiedniego warunku projektowego i typu wynikow
        ipsData=iprCont.find_theBiggestRatio(types=[self.getCurrentType(), ],
                                             subjects=[DISPLACEMENT_Y, ],
                                             ords=[self.getCurrentPoint(), ],
                                             
                                             subject=DISPLACEMENT_Y,
                                             )
        #jezeli znaleziono jakikolwiek wynik zwracana jest lista z szczegolowymi informacjami
        if ipsData!=None and ipsData['calculated']:


            #wyswietlenie wartosci
            self.disp_res_y_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci dla warunkow projektowych
            self.disp_res_y_comparison.setValues(fabs(ipsData['y']), ipsData['limit'])

        
        else:

            #wyczyszczenie            
            self.disp_res_y_generalInfo.clear()
            self.disp_res_y_comparison.clear()



        #######################################

        #pobranie ekstremalnego wyniku dla biezacej rzednej oraz odpowiedniego warunku projektowego i typu wynikow
        ipsData=iprCont.find_theBiggestRatio(types=[self.getCurrentType(), ],
                                             subjects=[DISPLACEMENT_R, ],
                                             ords=[self.getCurrentPoint(), ],
                                             
                                             subject=DISPLACEMENT_R,
                                             )
        
        #jezeli znaleziono jakikolwiek wynik zwracana jest lista z szczegolowymi informacjami
        if ipsData!=None and ipsData['calculated']:

            #wyswietlenie wartosci
            self.disp_res_r_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci dla warunkow projektowych
            self.disp_res_r_comparison.setValues(fabs(ipsData['r']), ipsData['limit'])

        
        else:

            #wyczyszczenie            
            self.disp_res_r_generalInfo.clear()
            self.disp_res_r_comparison.clear()


        #######################################

        #pobranie ekstremalnego wyniku dla biezacej rzednej oraz odpowiedniego warunku projektowego i typu wynikow
        ipsData=iprCont.find_theBiggestRatio(types=[self.getCurrentType(), ],
                                             subjects=[DISPLACEMENT_FI, ],
                                             ords=[self.getCurrentPoint(), ],
                                             
                                             subject=DISPLACEMENT_FI,
                                             )
        
        #jezeli znaleziono jakikolwiek wynik zwracana jest lista z szczegolowymi informacjami
        if ipsData!=None and ipsData['calculated']:


            #wyswietlenie wartosci
            self.disp_res_fi_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci dla warunkow projektowych
            self.disp_res_fi_comparison.setValues(fabs(ipsData['fi']), ipsData['limit'])

        
        else:

            #wyczyszczenie            
            self.disp_res_fi_generalInfo.clear()
            self.disp_res_fi_comparison.clear()


    #
    def getSize(self):
        return (0.85, 0.85)
    
class DisplacementAnalyzer(dnComponent.BeamComponent):
    type=dnConstants.COMP_DISPLACEMENT_ANALYZER
    name=trans(u'Dopuszczalne przemieszczenia')
    description=trans(u'Analiza przemieszcze dopuszczalnych dla elementu prtowego')
    dirPath=os.path.join(dnConstants.LIB_DIR_PATH, 'components/beam/displacementAnalyzer')
    iconPath=os.path.join(dnConstants.LIB_DIR_PATH, 'components/beam/displacementAnalyzer/img/icon.gif')
    summarySubjects=[
            DISPLACEMENT_X,
            DISPLACEMENT_Y,
            DISPLACEMENT_R,
            DISPLACEMENT_FI,
                         ]
    def __init__(self, parent, itemId):

        #klasa nadrzedna
        dnComponent.BeamComponent.__init__(self, parent, itemId)

        #minimalna liczba rzednych do wymiarowania (rozstaw rownomierny)
        self.setDefaultPointsNumber(3, update=False)

        #set upd hard for vars
        self.addHardRecalcVars(['xLocal', 'yLocal', 'yChord'])

    def setDefault(self):

        #metoda obiektu nadrzednego
        dnComponent.BeamComponent.setDefault(self)

        #zmienne projektowe
        self.useXLimit=False
        self.useYLimit=True
        self.useRLimit=False
        self.useFiLimit=False

        self.xLocal=False
        self.yLocal=False
        self.yChord=False
        
        self.xLimit=round(self.getItem().getLength()/150., 4)
        self.yLimit=round(self.getItem().getLength()/150., 4)
        self.rLimit=round(self.getItem().getLength()/150., 4)
        self.fiLimit=round(self.getItem().getLength()/1500., 4)

        
    #   
    def _calcDisplacement(self):

        #pobarnie obiektu zarzadzajacego wynikami dla elementu
        resultsObj=self.getItem().getResults().getStatResults()

        #obliczenie sil przekrojowych dla elementu dla rznych kombinacji obciazenia
        sf={}
        for sfType in [0,1,2,3]: # petla  sily przekrojowe

            if [self.useXLimit, self.useYLimit, self.useRLimit, self.useFiLimit][sfType]:

                #dodanie klucza do slownika
                sf[sfType]={}

                for envType in [sdConstants.ENVELOPE_TYPE_MIN, sdConstants.ENVELOPE_TYPE_MAX]: #petla  typ obwiedni

                    sf[sfType][envType]=[]
                    
                    for p in self.getPoints():

                        if self.xLocal and sfType==0:
                            local=True
                        elif self.yLocal and sfType==1:
                            local=True
                        else:
                            local=False

                        if self.yChord and sfType==1:
                            yChord=True
                        else:
                            yChord=False

                        r=resultsObj.getDisplacementForPoint(
                                                        p,
                                                        loadCombination=self.loadCombination,

                                                        #tylko dla kombinatoryki
                                                        leadingValue=sfType,
                                                        envelopeType=envType,
                                                        laodCombinationType=self.loadCombinationType,    
                                                        
                                                        local=local,
                                                        fromChord=yChord,
                                                        
                                                        )

                        sf[sfType][envType].append(r) 
                        

        # przypisanie slownika z silami przekrojowymi do zmiennej klasy
        self._displacement=sf

    #
    def doCustomCheck(self):
        return True

    def doBeforeCalculate(self):
        return True

    def doCalculate(self, soft=False):

        #przelicz przemieszczenie jezeli konieczne
        if not soft:
            self._calcDisplacement()

        #################################
        ###  DANE WEJSCIOWE
        #################################

        #W TYM PRZYKLADZIE POTRZEBNE SA TYLKO PRZEMIESZCZENIA

        #################################
        ###  OBLICZENIA
        #################################

        # obliczenia elementu dla poszczeglnych kombinacji i rzednych
        for sfType, sfData in self._displacement.items(): # petla  PRZEMIESZCZENIA
                          
            for envType, envData in sfData.items(): # petla  typ obwiedni
                          
                for i in range(0, len(self.getPoints())):

                    # pobranie rzednej
                    ord = self.getPoints()[i]
                    lcType='%s %s'%(['min', 'max'][[sdConstants.ENVELOPE_TYPE_MIN, sdConstants.ENVELOPE_TYPE_MAX].index(envType)], ['X', 'Y', 'R', 'Fi'][sfType])               

                    # pobranie obiektu przechowujacego wyniki w punkcie
                    iprContObj=self.getResults().getInPointResults()

                    # dodanie wynikw dla rzednej; jezeli istnieja to zamiast tworzyc nowy obiekt, metoda add zwrci obiekt juz istniejacy
                    iprObj=iprContObj.add(ord)


                    # pobranie przemieszczen i kombinacji obciazenia
                    x = envData[i].getDisplacement(resultType=0)
                    y = envData[i].getDisplacement(resultType=1)
                    fi = envData[i].getDisplacement(resultType=2)
                    r = envData[i].getDisplacement(resultType=3)
                    x_combLoadGroups = envData[i].getLoadGroupList(resultType=0)
                    y_combLoadGroups = envData[i].getLoadGroupList(resultType=1)
                    fi_combLoadGroups = envData[i].getLoadGroupList(resultType=2)
                    r_combLoadGroups = envData[i].getLoadGroupList(resultType=3)
                    
                    ## obliczenie warunkow projektowych                    
                    
                    ####################################
                    ### PRZEMIESZCZENIA X
                    ####################################
           
                    if self.useXLimit:
                        if self.xLimit<1e-8:
                            ratio=10.
                        else:
                            ratio=fabs(x)/self.xLimit
                        
                        #dodanie wynikw
                        iprObj.addData(lcType, DISPLACEMENT_X, {
                                        'x':x,
                                        'limit':self.xLimit,
                                        'ratio':ratio,
                                        'calculated':True,
                                        },
                                       loadGroups = x_combLoadGroups,
                                       )

                    else:
                        iprObj.addData(lcType, DISPLACEMENT_X, { 'ratio':0., 'calculated':False, })

                    ####################################
                    ### PRZEMIESZCZENIA Y
                    ####################################
           

                    if self.useYLimit:
                        
                        if self.yLimit<1e-8:
                            ratio=10.
                        else:
                            ratio=fabs(y)/self.yLimit
                        
                        #dodanie wynikw
                        iprObj.addData(lcType, DISPLACEMENT_Y, {
                                        'y':y,
                                        'limit':self.yLimit,
                                        'ratio':ratio,
                                        'calculated':True,
                                        },                                       
                                       loadGroups = x_combLoadGroups,
                                       )
                    
                    else:
                        iprObj.addData(lcType, DISPLACEMENT_Y, { 'ratio':0., 'calculated':False, })
                        
                    ####################################
                    ### PRZEMIESZCZENIA R
                    ####################################
           
                    if self.useRLimit:
                        if self.rLimit<1e-8:
                            ratio=10.
                        else:
                            ratio=fabs(r)/self.rLimit

                        #dodanie wynikw
                        iprObj.addData(lcType, DISPLACEMENT_R, {
                                        'r':r,
                                        'limit':self.rLimit,
                                        'ratio':ratio,
                                        'calculated':True,
                                        },                                       
                                       loadGroups = x_combLoadGroups,
                                       )
                    else:
                        iprObj.addData(lcType, DISPLACEMENT_R, { 'ratio':0., 'calculated':False, })
                        
                    ####################################
                    ### PRZEMIESZCZENIA FI
                    ####################################
           
                    if self.useFiLimit:
                        if self.fiLimit<1e-8:
                            ratio=10.
                        else:
                            ratio=fabs(fi)/self.fiLimit
                        
                        #dodanie wynikw
                        iprObj.addData(lcType, DISPLACEMENT_FI, {
                                        'fi':fi,
                                        'limit':self.fiLimit,
                                        'ratio':ratio,
                                        'calculated':True,
                                        },                                       
                                       loadGroups = x_combLoadGroups,
                                       )                          
                    else:
                        iprObj.addData(lcType, DISPLACEMENT_FI, { 'ratio':0., 'calculated':False, })
                        
                  
        ####################################
        ### DODANIE WYNIKOW OGOLNYCH
        ####################################

        pass
        
        #################################
        ###  OKRESLENIE WYTEZENIA ELEMENTU
        #################################

        #oblicz wytezenie
        ripObj=self.getResults().getInPointResults()
        maxRatio, maxRatios = ripObj.getMaxRatio(return_all=True)

        #przypisz wytezenie dla poszczegolnych warunkow projektowych  
        self.getResults().setSummary( [[h, maxRatios[h]] for h in self.summarySubjects] )
        

        #################################
        ###  DODANIE KOMENTARZA
        #################################

        #dodaj komentarz
        if self.getResults().getUseRatio() > 1.:
            self.getMessageManager().addMessage(u'!!!Nono elementu przekroczona!!!.', type=dnComponent.MSG_TYPE_ERROR)
        else:
            self.getMessageManager().addMessage(u'Element zaprojektowany poprawnie.', type=dnComponent.MSG_TYPE_IMPORTANT)
  
        return True


    #
    def insertRTFReport(self, docObj, sectionObj):

        #utworz kontroler
        rtfReportMethod=sdRTFReport.RTFRaport_MethodsObj(self, docObj, sectionObj)

        #wciecie
        indent=3*' '

        ##DANE OGOLNE     
        self.insertRTFReport_ComponentHeader(rtfReportMethod)        

        ##DANE OGOLNE    
        self.insertRTFReport_ElementInfo(rtfReportMethod)
  
        ##ZMIENNE PROJEKTOWE
        rtfReportMethod.insertTitle(trans('Dane projektowe'))
        rtfReportMethod.insertText()

        #x
        rtfReportMethod.insertText(trans('Ogranicz przemieszczenia po kierunku x')+': '+[trans('Nie'), trans('Tak')][self.useXLimit])
        rtfReportMethod.insertText(indent+trans('Limit: ')+'%.4f'%self.xLimit)
        rtfReportMethod.insertText(indent+trans('Lokalne')+': '+[trans('Nie'), trans('Tak')][self.xLocal])
            
        #y
        rtfReportMethod.insertText(trans('Ogranicz przemieszczenia po kierunku y')+': '+[trans('Nie'), trans('Tak')][self.useYLimit])
        rtfReportMethod.insertText(indent+trans('Limit: ')+'%.4f'%self.yLimit)
        rtfReportMethod.insertText(indent+trans('Lokalne')+': '+[trans('Nie'), trans('Tak')][self.yLocal])
        rtfReportMethod.insertText(indent+trans('Mierz od ciciwy prta')+': '+[trans('Nie'), trans('Tak')][self.yChord])

        #r
        rtfReportMethod.insertText(trans('Ogranicz przemieszczenia wypadkowe')+': '+[trans('Nie'), trans('Tak')][self.useRLimit])
        rtfReportMethod.insertText(indent+trans('Limit: ')+'%.4f'%self.rLimit)
          
        #fi
        rtfReportMethod.insertText(trans('Ogranicz przemieszczenia ktowe')+': '+[trans('Nie'), trans('Tak')][self.useFiLimit])
        rtfReportMethod.insertText(indent+trans('Limit: ')+'%.6f'%self.fiLimit)


            
        rtfReportMethod.insertText(trans('Kombinacja obcienia')+': '+[trans('Nie'), trans('Tak')][self.loadCombination])
        if self.loadCombination:
            loadCombDescr=self._getStatResultManager().getConfigurationText(
                                         loadCombination=self.loadCombination,
                                         loadCombinationType=self.loadCombinationType,
                                         #obliqueValues=self.obliqueValues,
                                         #permamentValues=self.permamentValues,                            
                                         )
            rtfReportMethod.insertText(indent+trans('Typ kombinacji')+': '+loadCombDescr.encode('cp1250'))
        rtfReportMethod.insertText()
        
        ##        
        ## WYNIKI
        ##

        rtfReportMethod.insertTitle(trans('Wyniki dla elementu'))

        #insert graph
        graphObj=rtfReportMethod.InsertScheme(GrafName="DISPLACEMENT_GRAF_COMBINATIONS")
        graphObj.InitiateGraf(filtr=sdSchemeImageMaker.ELEMENTS, items=[self.getItem().getGraphId(), ])
        graphObj.DrawNode()
        graphObj.DrawElements()
        graphObj.DrawBC()
        graphObj.DrawDispleacmant(loadCombination=self.loadCombination,

                            leadingValue=None,
                                  
                            loadCombinationType=self.loadCombinationType,
                           )
        
        graphObj.InsertGraph()
            
        #wstaw opis
        loadCombDescr=self._getStatResultManager().getConfigurationText(
                                     loadCombination=self.loadCombination,
                                     loadCombinationType=self.loadCombinationType,
                                     #obliqueValues=self.obliqueValues,
                                     #permamentValues=self.permamentValues,                            
                                     )
        rtfReportMethod.insertText()


        ##
        ## WSKAZNIKI WYTEZENIA
        ##
        
        self.insertRTFReport_EffortRatios(rtfReportMethod)

        ##
        ## WYNIKI DLA PUNKTOW
        ##

        self.insertRTFReport_ResultInPoints(rtfReportMethod)

    
    #
    def drawIcon_OFF(self, canvas, x, y):

        #rysuj symbol
        iconId=canvas.create_text(x,y,
                                              text='u',
                                              fill='blue',
                                              #anchor=W,
                                              activefill='red',
                                              font=('arial', 13, 'bold'),
                                              )
        return iconId
    
    #       
    def getDlgClass(self):
        return DisplacementAnalyzerDlg_multiPoint

    def getAvailableDlgClasses(self):
        return [['klasyczny', DisplacementAnalyzerDlg_classic], ['ulepszony', DisplacementAnalyzerDlg_multiPoint]]
                