# -*- coding: cp1250 -*-

"""
plik: sectionForcesAnalyzer.py
autor: Krzysztof Szajek (biuro@soldis.com.pl)

Przykad reguy wymiarowania analizujcej siy przekrojowe.

Modu stanowi integraln cz progrmau Soldis PROJEKTANT. Zabrania si rozpowszechniania fragmentw lub caoci poniszego kodu bez zgody AUTORA. Szczegowe warunki licencji - patrz: licencja/licence.txt w katalogu instalacyjnym programu.
"""

#general
from dnBaseLib import *

#python modules
import os
import types
import copy

#solsec modules
import ssConstants

#design modules
import dnConstants
import dnComponent
import dnComponentDlg

#soldis
import sdConstants
import sdRTFReport
import sdSchemeImageMaker

#soldis env
import soSymbols
import soMath

#add
import PyRTF


#CONSTANTS
NORMAL_FORCE='Normalna N'
SHEAR=u'Tnca Ty'
BENDING='Moment Mx'
SHEAR_X=u'Tnca Tx'
BENDING_Y='Moment My'

class SectionForcesAnalyzerDlg_classic(dnComponentDlg.ComponentContextBeamDlg):
    controlWidth=12
    def __init__(self, parent, compObj, **kw):

        #wywolanie klasy bazowej
        dnComponentDlg.ComponentContextBeamDlg.__init__(self, parent, compObj, **kw)

        #utworzenie zakladek
        self.genTabObj=self.registerGeneralTab(addSubjectChooser=True)
        self.loadCombTabObj=self.registerLoadCombTab()
        self.registerTab('normal',
                         image=self._createImage('tab_normal_icon'),
                         createFunc=self.createTab_normal,
                         updateFun=self.updateTab_normal,
                         subjectId=[0, ])
        self.registerTab('shear',
                         image=self._createImage('tab_shear_icon'),
                         createFunc=self.createTab_shear,
                         updateFun=self.updateTab_shear,
                         subjectId=[1, ])
        self.registerTab('bending',
                         image=self._createImage('tab_bending_icon'),
                         createFunc=self.createTab_bending,
                         updateFun=self.updateTab_bending,
                         subjectId=[2, ])
        self.registerTab('shear_x',
                         image=self._createImage('tab_shear_x_icon'),
                         createFunc=self.createTab_shear_x,
                         updateFun=self.updateTab_shear_x,
                         subjectId=[3, ])
        self.registerTab('bending_y',
                         image=self._createImage('tab_bending_y_icon'),
                         createFunc=self.createTab_bending_y,
                         updateFun=self.updateTab_bending_y,
                         subjectId=[4, ])
        self.resTabObj=self.registerStdResultTab()
        
        ##przyklad zakladki ze zmienna dialogowa (niezalezna od obiektu dnComponent.Component) - obsluguje tylko okno dialogowe
        #self.registerTab('demo',
        #                 text='Demo',
        #                 createFunc=self.createDemoTab,
        #                 updateFun=self.updateDemoTab,
        #                 subjectId=None)

        #ustawienie zakladki domyslnej   
        self.setDefaultTab(self.genTabObj['name'])

        #dodanie przyciskow z dodatkowymi funkcjami 
        self.registerOrdinateButton()
        self.registerNextPrevButtons()
        self.registerDefaultPointsNumberControl()
        self.registerLateralLoadButton()
        self.registerCalcSavingOptButton()
        self.registerSizingPointsButton()
        
        #dodanie listy z rzednymi i typami wynikow
        self.registerOrdinateChooser()
        self.registerTypeChooser()
        
        #dodanie widokow
        self.registerSectionView()

        #dodanie zakladek w widoku przekroju
        self.registerGeneralSectionViewTab()

        ##PRZYKLAD DODANIE ZAKLADKI W WIDOKU PRZEKROJU (ABY WLACZYC USUN ZNAK '#' W LINIACH PONIZEJ)         
        #self.registerSectionViewTab('demoTab', text='Demo', image=None, createFunc=self.createDemoTab, updateFunc=self.updateDemoTab)
        #self.setDefaultSectionViewTab('demoTab')
        
        #zbudowanie okna
        self.build()
        
    def setVars(self):

        #dodanie zmiennych podstawowych       
        self.addVar('check_N', type='IntVar')
        self.addVar('check_Tx', type='IntVar')
        self.addVar('check_Mx', type='IntVar')
        self.addVar('check_Ty', type='IntVar')
        self.addVar('check_My', type='IntVar')
        self.addVar('limit_N_min', type='DoubleVar')
        self.addVar('limit_N_max', type='DoubleVar')
        self.addVar('limit_Tx_min', type='DoubleVar')
        self.addVar('limit_Tx_max', type='DoubleVar')
        self.addVar('limit_Mx_min', type='DoubleVar')
        self.addVar('limit_Mx_max', type='DoubleVar')
        self.addVar('limit_Ty_min', type='DoubleVar')
        self.addVar('limit_Ty_max', type='DoubleVar')
        self.addVar('limit_My_min', type='DoubleVar')
        self.addVar('limit_My_max', type='DoubleVar')

        #dodanie zmiennych okna
        self.addVar('dialogVariable', type='StringVar', dlgVar=True, value='')
        self.addVar('dialogVariable_string', type='StringVar', dlgVar=True, value='Brak')
        self.addVar('dialogVariable_boolean', type='IntVar', dlgVar=True, value=True)
        self.addVar('dialogVariable_double', type='DoubleVar', dlgVar=True, value=True)
        
    #create
    def createTab_normal(self, tab):


        #dodanie naglowka
        l=self.createTabElement_heading(tab, u"Sia normalna")
        l.pack(fill=X)
        


        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, padding=5, text='Ograniczenia')
        f.pack(fill=X, padx=5)


        #utworzenie ramki
        fc=soFrame(f)
        fc.pack()

        def onCheckChange():
         
            if self.var_check_Ty.get():
                self.normal_maxLimit['state']=NORMAL
                self.normal_minLimit['state']=NORMAL
            else:
                
                self.normal_maxLimit['state']=DISABLED
                self.normal_minLimit['state']=DISABLED



        self.normal_checkChB=soCheckbutton(fc,
                                                variable=self.var_check_N,
                                                command=onCheckChange,
                                                text=trans(u'Uwzgldnij ograniczenia'),
                                                )
        self.normal_checkChB.grid(row=1, column=1, columnspan=1, sticky=W, pady=5)


        #dodanie elementow do kontroli wartosci max i min
        def maxValidate(x):

            #sprawdzenie formatu
            try:
                x=float(x)
            except:
                return self.var_limit_N_max.get()

            #sprawdzenie minimum
            if x<0.:
                x=0.
            
            return x

        def minValidate(x):

            #sprawdzenie formatu
            try:
                x=float(x)
            except:
                return self.var_limit_N_min.get()

            #sprawdzenie minimum
            if x>0.:
                x=0.
            
            return x
                
        self.normal_maxLimit = soControl(fc,
                                    label=u'Maksymalna warto [kN]: ',
                                    variable=self.var_limit_N_max,
                                    step=.1,
                                    allowempty=False,
                                    validatecmd=maxValidate)
        self.normal_maxLimit['selectmode']='normal'
        self.normal_maxLimit.entry['width']=8
        self.normal_maxLimit.grid(row=2, column=1, columnspan=1, sticky=E, padx=20)


        self.normal_minLimit = soControl(fc,
                                    label=u'Minimalna warto [kN]: ',
                                    variable=self.var_limit_N_min,
                                    step=.1,
                                    allowempty=False,
                                    validatecmd=minValidate)
        self.normal_minLimit['selectmode']='normal'
        self.normal_minLimit.entry['width']=8
        self.normal_minLimit.grid(row=3, column=1, columnspan=1, sticky=E, padx=20)



        ################################

        #utworzenie ramki
        self.normal_hideFrame=dnComponentDlg.ResultLabelFrame(tab, text='Wyniki', padding=5)
        self.normal_hideFrame.pack(fill=X, padx=5, pady=5)

        f=self.normal_hideFrame.getFrame()

        #utworzenie ramki
        fc=soFrame(f)
        fc.pack()

        #dodanie podstawowych informacji o wynikach        
        self.normal_res_generalInfo=dnComponentDlg.GeneralInfo(fc)
        self.normal_res_generalInfo.grid(row=1, column=1, padx=5, sticky=W)

        #dodanie separatora
        l=soSeparator(fc, orient='horizontal')
        l.grid(row=2, column=1, sticky=W+E)

        #dodanie pustej ramki (obnienie tekstu poniej)
        space=soFrame(fc, height=10)
        space.grid(row=3, column=1)

        #dodanie opisu
        l=soLabel(fc, text=u'Warto siy normalnej')
        l.grid(row=4, column=1, columnspan=1, sticky=W)

        #wyswietlenie sily dla najbardziej wytonego przekroju
        self.normal_res_N=dnComponentDlg.ResultValue(fc, lImage=self._createImage('normal_N'), rImage=self._createImage('unit_kN'), format='%.2f')
        self.normal_res_N.grid(row=5, column=1, padx=5, sticky=W+E, pady=8)


        #dodanie opisu
        l=soLabel(fc, text=u'Sprawdzenie warunku projektowego')
        l.grid(row=6, column=1, columnspan=1, sticky=W)


        #create comparison
        self.normal_res_comparison=dnComponentDlg.Comparison(fc,
                                                      lImage=self._createImage('comparison_N'),
                                                      rImage=None,
                                                      lFormat='%.2f', rFormat='%.1f')
        self.normal_res_comparison.grid(row=7, column=1, columnspan=1, sticky=E+W, pady=8)


        #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
        self.addUpdateTabFunctions('normal', updateFunc=[onCheckChange])
        
    
        
    def createTab_shear(self, tab):


        #dodanie naglowka
        l=self.createTabElement_heading(tab, u"Sia tnca Ty")
        l.pack(fill=X)


        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, padding=5, text='Ograniczenia')
        f.pack(fill=X, padx=5)


        #utworzenie ramki
        fc=soFrame(f)
        fc.pack()

        def onCheckChange():
         
            if self.var_check_Ty.get():
                self.shear_maxLimit['state']=NORMAL
                self.shear_minLimit['state']=NORMAL
            else:
                
                self.shear_maxLimit['state']=DISABLED
                self.shear_minLimit['state']=DISABLED



        self.shear_checkChB=soCheckbutton(fc,
                                                variable=self.var_check_Ty,
                                                command=onCheckChange,
                                                text=trans(u'Uwzgldnij ograniczenia'),
                                                )
        self.shear_checkChB.grid(row=1, column=1, columnspan=1, sticky=W, pady=5)


        #dodanie elementow do kontroli wartosci max i min
        def maxValidate(x):

            #sprawdzenie formatu
            try:
                x=float(x)
            except:
                return self.var_limit_Ty_max.get()

            #sprawdzenie minimum
            if x<0.:
                x=0.
            
            return x

        def minValidate(x):

            #sprawdzenie formatu
            try:
                x=float(x)
            except:
                return self.var_limit_Ty_min.get()

            #sprawdzenie minimum
            if x>0.:
                x=0.
            
            return x
                
        self.shear_maxLimit = soControl(fc,
                                    label=u'Maksymalna warto [kN]: ',
                                    variable=self.var_limit_Ty_max,
                                    step=.1,
                                    allowempty=False,
                                    validatecmd=maxValidate)
        self.shear_maxLimit['selectmode']='normal'
        self.shear_maxLimit.entry['width']=8
        self.shear_maxLimit.grid(row=2, column=1, columnspan=1, sticky=E, padx=20)


        self.shear_minLimit = soControl(fc,
                                    label=u'Minimalna warto [kN]: ',
                                    variable=self.var_limit_Ty_min,
                                    step=.1,
                                    allowempty=False,
                                    validatecmd=minValidate)
        self.shear_minLimit['selectmode']='normal'
        self.shear_minLimit.entry['width']=8
        self.shear_minLimit.grid(row=3, column=1, columnspan=1, sticky=E, padx=20)



        ################################

        #utworzenie ramki
        self.shear_hideFrame=dnComponentDlg.ResultLabelFrame(tab, text='Wyniki', padding=5)
        self.shear_hideFrame.pack(fill=X, padx=5, pady=5)
        f=self.shear_hideFrame.getFrame()

        #utworzenie ramki
        fc=soFrame(f)
        fc.pack()

        #dodanie podstawowych informacji o wynikach        
        self.shear_res_generalInfo=dnComponentDlg.GeneralInfo(fc)
        self.shear_res_generalInfo.grid(row=1, column=1, padx=5, sticky=W)

        #dodanie separatora
        l=soSeparator(fc, orient='horizontal')
        l.grid(row=2, column=1, sticky=W+E)

        #dodanie pustej ramki (obnienie tekstu poniej)
        space=soFrame(fc, height=10)
        space.grid(row=3, column=1)

        #dodanie opisu
        l=soLabel(fc, text=u'Warto siy tncej')
        l.grid(row=4, column=1, columnspan=1, sticky=W)

        #wyswietlenie sily dla najbardziej wytonego przekroju
        self.shear_res_Ty=dnComponentDlg.ResultValue(fc, lImage=self._createImage('shear_Ty'), rImage=self._createImage('unit_kN'), format='%.2f')
        self.shear_res_Ty.grid(row=5, column=1, padx=5, sticky=W+E, pady=8)


        #dodanie opisu
        l=soLabel(fc, text=u'Sprawdzenie warunku projektowego')
        l.grid(row=6, column=1, columnspan=1, sticky=W)


        #create comparison
        self.shear_res_comparison=dnComponentDlg.Comparison(fc,
                                                      lImage=self._createImage('comparison_Ty'),
                                                      rImage=None,
                                                      lFormat='%.2f', rFormat='%.1f')
        self.shear_res_comparison.grid(row=7, column=1, columnspan=1, sticky=E+W, pady=8)


        #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
        self.addUpdateTabFunctions('shear', updateFunc=[onCheckChange])
        
    
        

    def createTab_bending(self, tab):


        #dodanie naglowka
        l=self.createTabElement_heading(tab, u"Moment zginajcy Mx")
        l.pack(fill=X)


        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, padding=5, text='Ograniczenia')
        f.pack(fill=X, padx=5)


        #utworzenie ramki
        fc=soFrame(f)
        fc.pack()

        def onCheckChange():
         
            if self.var_check_Mx.get():
                self.bending_maxLimit['state']=NORMAL
                self.bending_minLimit['state']=NORMAL
            else:
                
                self.bending_maxLimit['state']=DISABLED
                self.bending_minLimit['state']=DISABLED



        self.bending_checkChB=soCheckbutton(fc,
                                                variable=self.var_check_Mx,
                                                command=onCheckChange,
                                                text=trans(u'Uwzgldnij ograniczenia'),
                                                )
        self.bending_checkChB.grid(row=1, column=1, columnspan=1, sticky=W, pady=5)


        #dodanie elementow do kontroli wartosci max i min
        def maxValidate(x):

            #sprawdzenie formatu
            try:
                x=float(x)
            except:
                return self.var_limit_Mx_max.get()

            #sprawdzenie minimum
            if x<0.:
                x=0.
            
            return x

        def minValidate(x):

            #sprawdzenie formatu
            try:
                x=float(x)
            except:
                return self.var_limit_Mx_min.get()

            #sprawdzenie minimum
            if x>0.:
                x=0.
            
            return x
                
        self.bending_maxLimit = soControl(fc,
                                    label=u'Maksymalna warto [kNm]: ',
                                    variable=self.var_limit_Mx_max,
                                    step=.1,
                                    allowempty=False,
                                    validatecmd=maxValidate)
        self.bending_maxLimit['selectmode']='normal'
        self.bending_maxLimit.entry['width']=8
        self.bending_maxLimit.grid(row=2, column=1, columnspan=1, sticky=E, padx=20)


        self.bending_minLimit = soControl(fc,
                                    label=u'Minimalna warto [kNm]: ',
                                    variable=self.var_limit_Mx_min,
                                    step=.1,
                                    allowempty=False,
                                    validatecmd=minValidate)
        self.bending_minLimit['selectmode']='normal'
        self.bending_minLimit.entry['width']=8
        self.bending_minLimit.grid(row=3, column=1, columnspan=1, sticky=E, padx=20)



        ################################

        #utworzenie ramki
        self.bending_hideFrame=dnComponentDlg.ResultLabelFrame(tab, text='Wyniki', padding=5)
        self.bending_hideFrame.pack(fill=X, padx=5, pady=5)
        f=self.bending_hideFrame.getFrame()

        #utworzenie ramki
        fc=soFrame(f)
        fc.pack()

        #dodanie podstawowych informacji o wynikach        
        self.bending_res_generalInfo=dnComponentDlg.GeneralInfo(fc)
        self.bending_res_generalInfo.grid(row=1, column=1, padx=5, sticky=W)

        #dodanie separatora
        l=soSeparator(fc, orient='horizontal')
        l.grid(row=2, column=1, sticky=W+E)

        #dodanie pustej ramki (obnienie tekstu poniej)
        space=soFrame(fc, height=10)
        space.grid(row=3, column=1)

        #dodanie opisu
        l=soLabel(fc, text=u'Warto momentu zginajcego')
        l.grid(row=4, column=1, columnspan=1, sticky=W)

        #wyswietlenie sily dla najbardziej wytonego przekroju
        self.bending_res_Mx=dnComponentDlg.ResultValue(fc, lImage=self._createImage('bending_Mx'), rImage=self._createImage('unit_kNm'), format='%.2f')
        self.bending_res_Mx.grid(row=5, column=1, padx=5, sticky=W+E, pady=8)


        #dodanie opisu
        l=soLabel(fc, text=u'Sprawdzenie warunku projektowego')
        l.grid(row=6, column=1, columnspan=1, sticky=W)


        #create comparison
        self.bending_res_comparison=dnComponentDlg.Comparison(fc,
                                                      lImage=self._createImage('comparison_Mx'),
                                                      rImage=None,
                                                      lFormat='%.2f', rFormat='%.1f')
        self.bending_res_comparison.grid(row=7, column=1, columnspan=1, sticky=E+W, pady=8)


        #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
        self.addUpdateTabFunctions('shear', updateFunc=[onCheckChange])
        
    
        

    def createTab_shear_x(self, tab):


        #dodanie naglowka
        l=self.createTabElement_heading(tab, u"Sia tnca Tx")
        l.pack(fill=X)

        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, padding=5, text='Ograniczenia')
        f.pack(fill=X, padx=5)

        #utworzenie ramki
        fc=soFrame(f)
        fc.pack()

        def onCheckChange():
         
            if self.var_check_Tx.get():
                self.shear_x_maxLimit['state']=NORMAL
                self.shear_x_minLimit['state']=NORMAL
            else:
                
                self.shear_x_maxLimit['state']=DISABLED
                self.shear_x_minLimit['state']=DISABLED



        self.shear_x_checkChB=soCheckbutton(fc,
                                                variable=self.var_check_Tx,
                                                command=onCheckChange,
                                                text=trans(u'Uwzgldnij ograniczenia'),
                                                )
        self.shear_x_checkChB.grid(row=1, column=1, columnspan=1, sticky=W, pady=5)


        #dodanie elementow do kontroli wartosci max i min
        def maxValidate(x):

            #sprawdzenie formatu
            try:
                x=float(x)
            except:
                return self.var_limit_Tx_max.get()

            #sprawdzenie minimum
            if x<0.:
                x=0.
            
            return x

        def minValidate(x):

            #sprawdzenie formatu
            try:
                x=float(x)
            except:
                return self.var_limit_Tx_min.get()

            #sprawdzenie minimum
            if x>0.:
                x=0.
            
            return x
                
        self.shear_x_maxLimit = soControl(fc,
                                    label=u'Maksymalna warto [kN]: ',
                                    variable=self.var_limit_Tx_max,
                                    step=.1,
                                    allowempty=False,
                                    validatecmd=maxValidate)
        self.shear_x_maxLimit['selectmode']='normal'
        self.shear_x_maxLimit.entry['width']=8
        self.shear_x_maxLimit.grid(row=2, column=1, columnspan=1, sticky=E, padx=20)


        self.shear_x_minLimit = soControl(fc,
                                    label=u'Minimalna warto [kN]: ',
                                    variable=self.var_limit_Tx_min,
                                    step=.1,
                                    allowempty=False,
                                    validatecmd=minValidate)
        self.shear_x_minLimit['selectmode']='normal'
        self.shear_x_minLimit.entry['width']=8
        self.shear_x_minLimit.grid(row=3, column=1, columnspan=1, sticky=E, padx=20)



        ################################

        #utworzenie ramki
        self.shear_x_hideFrame=dnComponentDlg.ResultLabelFrame(tab, text='Wyniki', padding=5)
        self.shear_x_hideFrame.pack(fill=X, padx=5, pady=5)
        f=self.shear_x_hideFrame.getFrame()

        #utworzenie ramki
        fc=soFrame(f)
        fc.pack()

        #dodanie podstawowych informacji o wynikach        
        self.shear_x_res_generalInfo=dnComponentDlg.GeneralInfo(fc)
        self.shear_x_res_generalInfo.grid(row=1, column=1, padx=5, sticky=W)

        #dodanie separatora
        l=soSeparator(fc, orient='horizontal')
        l.grid(row=2, column=1, sticky=W+E)

        #dodanie pustej ramki (obnienie tekstu poniej)
        space=soFrame(fc, height=10)
        space.grid(row=3, column=1)

        #dodanie opisu
        l=soLabel(fc, text=u'Warto siy tncej')
        l.grid(row=4, column=1, columnspan=1, sticky=W)

        #wyswietlenie sily dla najbardziej wytonego przekroju
        self.shear_x_res_Tx=dnComponentDlg.ResultValue(fc, lImage=self._createImage('shear_x_Tx'), rImage=self._createImage('unit_kN'), format='%.2f')
        self.shear_x_res_Tx.grid(row=5, column=1, padx=5, sticky=W+E, pady=8)


        #dodanie opisu
        l=soLabel(fc, text=u'Sprawdzenie warunku projektowego')
        l.grid(row=6, column=1, columnspan=1, sticky=W)


        #create comparison
        self.shear_x_res_comparison=dnComponentDlg.Comparison(fc,
                                                      lImage=self._createImage('comparison_Tx'),
                                                      rImage=None,
                                                      lFormat='%.2f', rFormat='%.1f')
        self.shear_x_res_comparison.grid(row=7, column=1, columnspan=1, sticky=E+W, pady=8)


        #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
        self.addUpdateTabFunctions('shear', updateFunc=[onCheckChange])
        
    
        


    def createTab_bending_y(self, tab):

        #dodanie naglowka
        l=self.createTabElement_heading(tab, u"Moment zginajcy My")
        l.pack(fill=X)

        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, padding=5, text='Ograniczenia')
        f.pack(fill=X, padx=5)

        #utworzenie ramki
        fc=soFrame(f)
        fc.pack()

        def onCheckChange():
         
            if self.var_check_My.get():
                self.bending_y_maxLimit['state']=NORMAL
                self.bending_y_minLimit['state']=NORMAL
            else:
                
                self.bending_y_maxLimit['state']=DISABLED
                self.bending_y_minLimit['state']=DISABLED

        self.bending_y_checkChB=soCheckbutton(fc,
                                                variable=self.var_check_My,
                                                command=onCheckChange,
                                                text=trans(u'Uwzgldnij ograniczenia'),
                                                )
        self.bending_y_checkChB.grid(row=1, column=1, columnspan=1, sticky=W, pady=5)


        #dodanie elementow do kontroli wartosci max i min
        def maxValidate(x):

            #sprawdzenie formatu
            try:
                x=float(x)
            except:
                return self.var_limit_My_max.get()

            #sprawdzenie minimum
            if x<0.:
                x=0.
            
            return x

        def minValidate(x):

            #sprawdzenie formatu
            try:
                x=float(x)
            except:
                return self.var_limit_My_min.get()

            #sprawdzenie minimum
            if x>0.:
                x=0.
            
            return x
                
        self.bending_y_maxLimit = soControl(fc,
                                    label=u'Maksymalna warto [kNm]: ',
                                    variable=self.var_limit_My_max,
                                    step=.1,
                                    allowempty=False,
                                    validatecmd=maxValidate)
        self.bending_y_maxLimit['selectmode']='normal'
        self.bending_y_maxLimit.entry['width']=8
        self.bending_y_maxLimit.grid(row=2, column=1, columnspan=1, sticky=E, padx=20)

        self.bending_y_minLimit = soControl(fc,
                                    label=u'Minimalna warto [kNm]: ',
                                    variable=self.var_limit_My_min,
                                    step=.1,
                                    allowempty=False,
                                    validatecmd=minValidate)
        self.bending_y_minLimit['selectmode']='normal'
        self.bending_y_minLimit.entry['width']=8
        self.bending_y_minLimit.grid(row=3, column=1, columnspan=1, sticky=E, padx=20)

        ################################

        #utworzenie ramki
        self.bending_y_hideFrame=dnComponentDlg.ResultLabelFrame(tab, text='Wyniki', padding=5)
        self.bending_y_hideFrame.pack(fill=X, padx=5, pady=5)
        f=self.bending_y_hideFrame.getFrame()

        #utworzenie ramki
        fc=soFrame(f)
        fc.pack()

        #dodanie podstawowych informacji o wynikach        
        self.bending_y_res_generalInfo=dnComponentDlg.GeneralInfo(fc)
        self.bending_y_res_generalInfo.grid(row=1, column=1, padx=5, sticky=W)

        #dodanie separatora
        l=soSeparator(fc, orient='horizontal')
        l.grid(row=2, column=1, sticky=W+E)

        #dodanie pustej ramki (obnienie tekstu poniej)
        space=soFrame(fc, height=10)
        space.grid(row=3, column=1)

        #dodanie opisu
        l=soLabel(fc, text=u'Warto momentu zginajcego')
        l.grid(row=4, column=1, columnspan=1, sticky=W)

        #wyswietlenie sily dla najbardziej wytonego przekroju
        self.bending_y_res_My=dnComponentDlg.ResultValue(fc, lImage=self._createImage('bending_y_My'), rImage=self._createImage('unit_kNm'), format='%.2f')
        self.bending_y_res_My.grid(row=5, column=1, padx=5, sticky=W+E, pady=8)

        #dodanie opisu
        l=soLabel(fc, text=u'Sprawdzenie warunku projektowego')
        l.grid(row=6, column=1, columnspan=1, sticky=W)

        #create comparison
        self.bending_y_res_comparison=dnComponentDlg.Comparison(fc,
                                                      lImage=self._createImage('comparison_My'),
                                                      rImage=None,
                                                      lFormat='%.2f', rFormat='%.1f')
        self.bending_y_res_comparison.grid(row=7, column=1, columnspan=1, sticky=E+W, pady=8)


        #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
        self.addUpdateTabFunctions('shear', updateFunc=[onCheckChange])

    def createDemoTab(self, tab):

        #dodanie label
        l=soLabel(tab, text='Ostatnia aktualizacja')
        l.pack()

        #dodanie label
        self.demoTab_time=soLabel(tab, textvariable=self.var_dialogVariable)
        self.demoTab_time.pack()

        #dodaj separator
        s=soSeparator(tab, orient='horizontal')
        s.pack(fill=X, padx=3)

        ##przyklad uzycia 'dodatkowych' wynikow z analizy w oknie dialogowym
        self.demoTab_label=soLabel(tab, text='Brak wyniku', textvariable=self.var_dialogVariable_string)
        self.demoTab_label.pack()

        #checkbutton
        self.demoTab_chb=soCheckbutton(tab, text='Zmienna typu "Boolean"', variable=self.var_dialogVariable_boolean)
        self.demoTab_chb.pack()

        self.demoTab_control = soControl(tab,
                                        label=u'Warto: ',
                                        variable=self.var_dialogVariable_double,
                                         )
        self.demoTab_control['selectmode']='normal'
        self.demoTab_control.pack()

    #upd
    def updateTab_normal(self):


        #pobranie obiektu z wynikami dla poszczegolnych rzednych
        iprCont=self.getCompObj().getResults().getInPointResults()

        #pobranie ekstremalnego wyniku dla biezacej rzednej oraz odpowiedniego warunku projektowego i typu wynikow
        ipsData=iprCont.find_theBiggestRatio(types=[self.getCurrentType(), ],
                                             subjects=[NORMAL_FORCE, ],
                                             ords=[self.getCurrentPoint(), ],
                                             
                                             subject=NORMAL_FORCE,
                                             )

        #jezeli znaleziono jakikolwiek wynik zwracana jest lista z szczegolowymi informacjami        
        if ipsData!=None and ipsData['calculated']:

            #wyswietlenie wartosci
            self.normal_res_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci wynikowych
            self.normal_res_N.setValue(ipsData['N'])

            #wyswietlenie wartosci dla warunkow projektowych
            self.normal_res_comparison.setValues(ipsData['ratio'], 1.)

            #przywrocenie ramki z wynikami
            self.normal_hideFrame.show()

        else:

            #wyczyszczenie kontrolek          
            self.normal_res_generalInfo.clear()
            
            self.normal_res_N.clear()
            self.normal_res_comparison.clear()

            #ukrycie calej ramki z wynikami
            self.normal_hideFrame.hide()
        

    def updateTab_shear(self):

        #pobranie obiektu z wynikami dla poszczegolnych rzednych
        iprCont=self.getCompObj().getResults().getInPointResults()

        #pobranie ekstremalnego wyniku dla biezacej rzednej oraz odpowiedniego warunku projektowego i typu wynikow
        ipsData=iprCont.find_theBiggestRatio(types=[self.getCurrentType(), ],
                                             subjects=[SHEAR, ],
                                             ords=[self.getCurrentPoint(), ],
                                             
                                             subject=SHEAR,
                                             )

        #jezeli znaleziono jakikolwiek wynik zwracana jest lista z szczegolowymi informacjami        
        if ipsData!=None and ipsData['calculated']:

            #wyswietlenie wartosci
            self.shear_res_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci wynikowych
            self.shear_res_Ty.setValue(ipsData['Ty'])

            #wyswietlenie wartosci dla warunkow projektowych
            self.shear_res_comparison.setValues(ipsData['ratio'], 1.)

            #przywrocenie ramki z wynikami
            self.shear_hideFrame.show()
            
        else:

            #wyczyszczenie            
            self.shear_res_generalInfo.clear()
            
            self.shear_res_Ty.clear()
            self.shear_res_comparison.clear()

            #ukrycie calej ramki z wynikami
            self.shear_hideFrame.hide()

    def updateTab_bending(self):
        
        #pobranie obiektu z wynikami dla poszczegolnych rzednych
        iprCont=self.getCompObj().getResults().getInPointResults()

        #pobranie ekstremalnego wyniku dla biezacej rzednej oraz odpowiedniego warunku projektowego i typu wynikow
        ipsData=iprCont.find_theBiggestRatio(types=[self.getCurrentType(), ],
                                             subjects=[BENDING, ],
                                             ords=[self.getCurrentPoint(), ],
                                             
                                             subject=BENDING,
                                             )
        
        #jezeli znaleziono jakikolwiek wynik zwracana jest lista z szczegolowymi informacjami        
        if ipsData!=None and ipsData['calculated']:

            #wyswietlenie wartosci
            self.bending_res_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci wynikowych
            self.bending_res_Mx.setValue(ipsData['Mx'])

            #wyswietlenie wartosci dla warunkow projektowych
            self.bending_res_comparison.setValues(ipsData['ratio'], 1.)

            #przywrocenie ramki z wynikami
            self.bending_hideFrame.show()
        
        else:

            #wyczyszczenie            
            self.bending_res_generalInfo.clear()
            
            self.bending_res_Mx.clear()
            self.bending_res_comparison.clear()

            #ukrycie calej ramki z wynikami
            self.bending_hideFrame.hide()
            
    def updateTab_shear_x(self):
        
        #pobranie obiektu z wynikami dla poszczegolnych rzednych
        iprCont=self.getCompObj().getResults().getInPointResults()

        #pobranie ekstremalnego wyniku dla biezacej rzednej oraz odpowiedniego warunku projektowego i typu wynikow
        ipsData=iprCont.find_theBiggestRatio(types=[self.getCurrentType(), ],
                                             subjects=[SHEAR_X, ],
                                             ords=[self.getCurrentPoint(), ],
                                             
                                             subject=SHEAR_X,
                                             )

        #jezeli znaleziono jakikolwiek wynik zwracana jest lista z szczegolowymi informacjami        
        if ipsData!=None and ipsData['calculated']:

            #wyswietlenie wartosci
            self.shear_x_res_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci wynikowych
            self.shear_x_res_Tx.setValue(ipsData['Tx'])

            #wyswietlenie wartosci dla warunkow projektowych
            self.shear_x_res_comparison.setValues(ipsData['ratio'], 1.)

            #przywrocenie ramki z wynikami
            self.shear_x_hideFrame.show()
        
        else:

            #wyczyszczenie            
            self.shear_x_res_generalInfo.clear()
            
            self.shear_x_res_Tx.clear()
            self.shear_x_res_comparison.clear()

            #ukrycie calej ramki z wynikami
            self.shear_x_hideFrame.hide()

    def updateTab_bending_y(self):

        
        #pobranie obiektu z wynikami dla poszczegolnych rzednych
        iprCont=self.getCompObj().getResults().getInPointResults()

        #pobranie ekstremalnego wyniku dla biezacej rzednej oraz odpowiedniego warunku projektowego i typu wynikow
        ipsData=iprCont.find_theBiggestRatio(types=[self.getCurrentType(), ],
                                             subjects=[BENDING_Y, ],
                                             ords=[self.getCurrentPoint(), ],
                                             
                                             subject=BENDING_Y,
                                             )

        #jezeli znaleziono jakikolwiek wynik zwracana jest lista z szczegolowymi informacjami        
        if ipsData!=None and ipsData['calculated']:

            #wyswietlenie wartosci
            self.bending_y_res_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci wynikowych
            self.bending_y_res_My.setValue(ipsData['My'])

            #wyswietlenie wartosci dla warunkow projektowych
            self.bending_y_res_comparison.setValues(ipsData['ratio'], 1.)

            #przywrocenie ramki z wynikami
            self.bending_y_hideFrame.show()
        
        else:

            #wyczyszczenie            
            self.bending_y_res_generalInfo.clear()
            
            self.bending_y_res_My.clear()
            self.bending_y_res_comparison.clear()

            #ukrycie calej ramki z wynikami
            self.bending_y_hideFrame.hide()
            
    def updateDemoTab(self):

        #import modulu
        import time

        #zmiana ostatniej aktualizacji
        st=time.strftime("%a, %d %b %Y %H:%M:%S +0000",  time.gmtime())
        self.var_dialogVariable.set(st)

        #aktualizuj wartosci okna dialogowego na podstawie wynikow 'dodatkowych'
        rObj=self.getCompObj().getResults()
        self.var_dialogVariable_string.set(rObj.getResult('wynik_1'))
        self.var_dialogVariable_double.set(rObj.getResult('wynik_2'))
        self.var_dialogVariable_boolean.set(rObj.getResult('wynik_3'))
        
    #
    def updateTabsStatus(self):

        pass
    
        #ponizej zamieszczono przyklad kontroli zakladek
        #zakladka zostaje wlaczona gdy w wynikach znaduje sie przeliczony odpowiedni warunek projektowy
        #w niniejszym komponencie nie ma koniecznosci kontroli aktywnosci zakladek


        #block all
        ##self.changeAllTabsStatus(DISABLED)

        #set active
        ##self.changeTabStatus(self.genTabObj['name'], NORMAL)
        ##self.changeTabStatus(self.loadCombTabObj['name'], NORMAL)
        ##self.changeTabStatus(self.resTabObj['name'], NORMAL)
        

        #check calculation
        ##if not self.getCompObj().getResults().getError():
            
            #calc items
            ##calculatedItems=self.getCompObj().getResults().getInPointResults().getCalculatedSubjects()

            ##if set([NORMAL_FORCE, ]) & set(calculatedItems) != set([]):
            ##    self.changeTabStatus('normal', NORMAL)

            ##if set([SHEAR, ]) & set(calculatedItems) != set([]):
            ##    self.changeTabStatus('shear', NORMAL)

            ##if set([BENDING, ]) & set(calculatedItems) != set([]):
            ##    self.changeTabStatus('bending', NORMAL)

            ##if set([SHEAR_X, ]) & set(calculatedItems) != set([]):
            ##    self.changeTabStatus('shear_x', NORMAL)

            ##if set([BENDING_Y, ]) & set(calculatedItems) != set([]):
            ##    self.changeTabStatus('bending_y', NORMAL)

                
    #overwrite
    def getSize(self):
        return (465, 495)
        

class SectionForcesAnalyzerDlg_multiPoint(dnComponentDlg.ComponentContextMultiPointBeamDlg):
    controlWidth=12
    def __init__(self, parent, compObj, **kw):

        #wywolanie klasy bazowej
        dnComponentDlg.ComponentContextMultiPointBeamDlg.__init__(self, parent, compObj, **kw)

        #utworzenie zakladek ()
        self.registerTab('data',
                         image=self._createImage('tab_data_icon'),
                         createFunc=self.createTab_data,
                         updateFun=self.updateTab_data,
                         tabType=dnConstants.TAB_TYPE_GENERAL_DATA,
                         displayName=u'Ustawienia ogranicze',
                         noUserCheckComment=u'Zwryfikuj parametry wymiarowania',
                         )
        self.loadCombTabObj=self.registerLoadCombTab()
        self.resTabObj=self.registerStdResultTab()
        
        #rejestracja zakladek (wyniki)
        self.registerTab('normal',
                         image=self._createImage('tab_normal_icon'),
                         createFunc=self.createTab_normal,
                         updateFun=self.updateTab_normal,
                         subjectId=NORMAL_FORCE,
                         tabType=dnConstants.TAB_TYPE_RESULT_IN_POINT,
                         displayName=u'Sia normalna',
                         references=['shear', 'bending', 
                                     ],#referencja do pozostalych wynikow
                         )
        self.registerTab('shear',
                         image=self._createImage('tab_shear_icon'),
                         createFunc=self.createTab_shear,
                         updateFun=self.updateTab_shear,
                         subjectId=SHEAR,
                         tabType=dnConstants.TAB_TYPE_RESULT_IN_POINT,
                         displayName=u'Sia tnca',
                         references=['normal', 'bending', 
                                     ],#referencja do pozostalych wynikow
                         )
        self.registerTab('bending',
                         image=self._createImage('tab_bending_icon'),
                         createFunc=self.createTab_bending,
                         updateFun=self.updateTab_bending,
                         subjectId=BENDING,
                         tabType=dnConstants.TAB_TYPE_RESULT_IN_POINT,
                         displayName=u'Moment zginajcy Mx',
                         references=['normal', 'shear', 
                                     ],#referencja do pozostalych wynikow
                         )
        self.registerTab('shear_x',
                         image=self._createImage('tab_shear_x_icon'),
                         createFunc=self.createTab_shear_x,
                         updateFun=self.updateTab_shear_x,
                         subjectId=SHEAR_X,
                         tabType=dnConstants.TAB_TYPE_RESULT_IN_POINT,
                         displayName=u'Sia tnca X-X',
                         references=['bending_y',
                                     ],#referencja do pozostalych wynikow
                         )
        self.registerTab('bending_y',
                         image=self._createImage('tab_bending_y_icon'),
                         createFunc=self.createTab_bending_y,
                         updateFun=self.updateTab_bending_y,
                         subjectId=BENDING_Y,
                         tabType=dnConstants.TAB_TYPE_RESULT_IN_POINT,
                         displayName=u'Moment zginajcy My',
                         references=['shear_x', 
                                     ],#referencja do pozostalych wynikow
                         )

        ##przyklad zakladki ze zmienna dialogowa (niezalezna od obiektu dnComponent.Component) - obsluguje tylko okno dialogowe
        ##aby doda zakladke jako dialog (program nie utworzy przyciku do zakladki tak jak to robi dla 'TAB_TYPE_GENERAL_DATA')
        ##nalezy rowniez wlaczyc zmienne tabType oraz displayName a nastepnie dodac odwolanie do niej dodajac 'demo' do 'references'
        ##dowolnej zakladki powyzej
        #self.registerTab('demo',
        #                 text='Demo',
        #                 createFunc=self.createDemoTab,
        #                 updateFun=self.updateDemoTab,
        #                 subjectId=None,
        #                 #tabType=dnConstants.TAB_TYPE_DIALOG,
        #                 #displayName=u'Niezalena zmienna dialogowa',
        #)

        #dodanie przyciskow z dodatkowymi funkcjami 
        self.registerOrdinateButton()
        self.registerDefaultPointsNumberControl()
        self.registerLateralLoadButton()
        self.registerCalcSavingOptButton()
        self.registerSizingPointsButton()
        self.registerRaportGeneratorButton()
        
        #dodanie listy z rzednymi i typami wynikow
        self.registerTypeChooser()
        
        #dodanie widokow
        self.registerSectionView()

        #dodanie zakladek w widoku przekroju
        self.registerGeneralSectionViewTab()

        ##PRZYKLAD DODANIE ZAKLADKI W WIDOKU PRZEKROJU (ABY WLACZYC USUN ZNAK '#' W LINIACH PONIZEJ)         
        #self.registerSectionViewTab('demoTab', text='Demo', image=None, createFunc=self.createDemoTab, updateFunc=self.updateDemoTab)
        #self.setDefaultSectionViewTab('demoTab')

        #zbudowanie okna
        self.build()
        
    def setVars(self):

        #dodanie zmiennych podstawowych       
        self.addVar('check_N', type='IntVar')
        self.addVar('check_Tx', type='IntVar')
        self.addVar('check_Mx', type='IntVar')
        self.addVar('check_Ty', type='IntVar')
        self.addVar('check_My', type='IntVar')
        self.addVar('limit_N_min', type='DoubleVar')
        self.addVar('limit_N_max', type='DoubleVar')
        self.addVar('limit_Tx_min', type='DoubleVar')
        self.addVar('limit_Tx_max', type='DoubleVar')
        self.addVar('limit_Mx_min', type='DoubleVar')
        self.addVar('limit_Mx_max', type='DoubleVar')
        self.addVar('limit_Ty_min', type='DoubleVar')
        self.addVar('limit_Ty_max', type='DoubleVar')
        self.addVar('limit_My_min', type='DoubleVar')
        self.addVar('limit_My_max', type='DoubleVar')

        #dodanie zmiennych okna
        self.addVar('dialogVariable', type='StringVar', dlgVar=True, value='')
        self.addVar('dialogVariable_string', type='StringVar', dlgVar=True, value='Brak')
        self.addVar('dialogVariable_boolean', type='IntVar', dlgVar=True, value=True)
        self.addVar('dialogVariable_double', type='DoubleVar', dlgVar=True, value=True)
        
    #create
    def createTab_data(self, tab):

        #dodanie naglowka
        l=self.createTabElement_heading(tab, u"Ograniczenia")
        l.pack(fill=X)

        def insertY(tab):

            ################################

            #utworzenie ramki
            f=soLabelFrame(tab, padding=5, text=u'Sia normalna')
            f.pack(fill=X, padx=5)


            #utworzenie ramki
            fc=soFrame(f)
            fc.pack()

            def onCheckChange():
             
                if self.var_check_Ty.get():
                    self.normal_maxLimit['state']=NORMAL
                    self.normal_minLimit['state']=NORMAL
                else:
                    
                    self.normal_maxLimit['state']=DISABLED
                    self.normal_minLimit['state']=DISABLED



            self.normal_checkChB=soCheckbutton(fc,
                                                    variable=self.var_check_N,
                                                    command=onCheckChange,
                                                    text=trans(u'Uwzgldnij ograniczenia'),
                                                    )
            self.normal_checkChB.grid(row=1, column=1, columnspan=1, sticky=W, pady=5)


            #dodanie elementow do kontroli wartosci max i min
            def maxValidate(x):

                #sprawdzenie formatu
                try:
                    x=float(x)
                except:
                    return self.var_limit_N_max.get()

                #sprawdzenie minimum
                if x<0.:
                    x=0.
                
                return x

            def minValidate(x):

                #sprawdzenie formatu
                try:
                    x=float(x)
                except:
                    return self.var_limit_N_min.get()

                #sprawdzenie minimum
                if x>0.:
                    x=0.
                
                return x
                    
            self.normal_maxLimit = soControl(fc,
                                        label=u'Maksymalna warto [kN]: ',
                                        variable=self.var_limit_N_max,
                                        step=.1,
                                        allowempty=False,
                                        validatecmd=maxValidate)
            self.normal_maxLimit['selectmode']='normal'
            self.normal_maxLimit.entry['width']=8
            self.normal_maxLimit.grid(row=2, column=1, columnspan=1, sticky=E, padx=20)


            self.normal_minLimit = soControl(fc,
                                        label=u'Minimalna warto [kN]: ',
                                        variable=self.var_limit_N_min,
                                        step=.1,
                                        allowempty=False,
                                        validatecmd=minValidate)
            self.normal_minLimit['selectmode']='normal'
            self.normal_minLimit.entry['width']=8
            self.normal_minLimit.grid(row=3, column=1, columnspan=1, sticky=E, padx=20)

            #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
            self.addUpdateTabFunctions('data', updateFunc=[onCheckChange])



            ################################

            #utworzenie ramki
            f=soLabelFrame(tab, padding=5, text=u'Sia tnca')
            f.pack(fill=X, padx=5)


            #utworzenie ramki
            fc=soFrame(f)
            fc.pack()

            def onCheckChange():
             
                if self.var_check_Ty.get():
                    self.shear_maxLimit['state']=NORMAL
                    self.shear_minLimit['state']=NORMAL
                else:
                    
                    self.shear_maxLimit['state']=DISABLED
                    self.shear_minLimit['state']=DISABLED



            self.shear_checkChB=soCheckbutton(fc,
                                                    variable=self.var_check_Ty,
                                                    command=onCheckChange,
                                                    text=trans(u'Uwzgldnij ograniczenia'),
                                                    )
            self.shear_checkChB.grid(row=1, column=1, columnspan=1, sticky=W, pady=5)


            #dodanie elementow do kontroli wartosci max i min
            def maxValidate(x):

                #sprawdzenie formatu
                try:
                    x=float(x)
                except:
                    return self.var_limit_Ty_max.get()

                #sprawdzenie minimum
                if x<0.:
                    x=0.
                
                return x

            def minValidate(x):

                #sprawdzenie formatu
                try:
                    x=float(x)
                except:
                    return self.var_limit_Ty_min.get()

                #sprawdzenie minimum
                if x>0.:
                    x=0.
                
                return x
                    
            self.shear_maxLimit = soControl(fc,
                                        label=u'Maksymalna warto [kN]: ',
                                        variable=self.var_limit_Ty_max,
                                        step=.1,
                                        allowempty=False,
                                        validatecmd=maxValidate)
            self.shear_maxLimit['selectmode']='normal'
            self.shear_maxLimit.entry['width']=8
            self.shear_maxLimit.grid(row=2, column=1, columnspan=1, sticky=E, padx=20)


            self.shear_minLimit = soControl(fc,
                                        label=u'Minimalna warto [kN]: ',
                                        variable=self.var_limit_Ty_min,
                                        step=.1,
                                        allowempty=False,
                                        validatecmd=minValidate)
            self.shear_minLimit['selectmode']='normal'
            self.shear_minLimit.entry['width']=8
            self.shear_minLimit.grid(row=3, column=1, columnspan=1, sticky=E, padx=20)


            #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
            self.addUpdateTabFunctions('data', updateFunc=[onCheckChange])
            
        
            ################################

            #utworzenie ramki
            f=soLabelFrame(tab, padding=5, text=u'Moment zginajcy Mx')
            f.pack(fill=X, padx=5)


            #utworzenie ramki
            fc=soFrame(f)
            fc.pack()

            def onCheckChange():
             
                if self.var_check_Mx.get():
                    self.bending_maxLimit['state']=NORMAL
                    self.bending_minLimit['state']=NORMAL
                else:
                    
                    self.bending_maxLimit['state']=DISABLED
                    self.bending_minLimit['state']=DISABLED



            self.bending_checkChB=soCheckbutton(fc,
                                                    variable=self.var_check_Mx,
                                                    command=onCheckChange,
                                                    text=trans(u'Uwzgldnij ograniczenia'),
                                                    )
            self.bending_checkChB.grid(row=1, column=1, columnspan=1, sticky=W, pady=5)


            #dodanie elementow do kontroli wartosci max i min
            def maxValidate(x):

                #sprawdzenie formatu
                try:
                    x=float(x)
                except:
                    return self.var_limit_Mx_max.get()

                #sprawdzenie minimum
                if x<0.:
                    x=0.
                
                return x

            def minValidate(x):

                #sprawdzenie formatu
                try:
                    x=float(x)
                except:
                    return self.var_limit_Mx_min.get()

                #sprawdzenie minimum
                if x>0.:
                    x=0.
                
                return x
                    
            self.bending_maxLimit = soControl(fc,
                                        label=u'Maksymalna warto [kNm]: ',
                                        variable=self.var_limit_Mx_max,
                                        step=.1,
                                        allowempty=False,
                                        validatecmd=maxValidate)
            self.bending_maxLimit['selectmode']='normal'
            self.bending_maxLimit.entry['width']=8
            self.bending_maxLimit.grid(row=2, column=1, columnspan=1, sticky=E, padx=20)


            self.bending_minLimit = soControl(fc,
                                        label=u'Minimalna warto [kNm]: ',
                                        variable=self.var_limit_Mx_min,
                                        step=.1,
                                        allowempty=False,
                                        validatecmd=minValidate)
            self.bending_minLimit['selectmode']='normal'
            self.bending_minLimit.entry['width']=8
            self.bending_minLimit.grid(row=3, column=1, columnspan=1, sticky=E, padx=20)

            #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
            self.addUpdateTabFunctions('data', updateFunc=[onCheckChange])
            
    
        def insertX(tab):
                
            ################################

            #utworzenie ramki
            f=soLabelFrame(tab, padding=5, text=u'Sia tnca Tx')
            f.pack(fill=X, padx=5)

            #utworzenie ramki
            fc=soFrame(f)
            fc.pack()

            def onCheckChange():
             
                if self.var_check_Tx.get():
                    self.shear_x_maxLimit['state']=NORMAL
                    self.shear_x_minLimit['state']=NORMAL
                else:
                    
                    self.shear_x_maxLimit['state']=DISABLED
                    self.shear_x_minLimit['state']=DISABLED



            self.shear_x_checkChB=soCheckbutton(fc,
                                                    variable=self.var_check_Tx,
                                                    command=onCheckChange,
                                                    text=trans(u'Uwzgldnij ograniczenia'),
                                                    )
            self.shear_x_checkChB.grid(row=1, column=1, columnspan=1, sticky=W, pady=5)


            #dodanie elementow do kontroli wartosci max i min
            def maxValidate(x):

                #sprawdzenie formatu
                try:
                    x=float(x)
                except:
                    return self.var_limit_Tx_max.get()

                #sprawdzenie minimum
                if x<0.:
                    x=0.
                
                return x

            def minValidate(x):

                #sprawdzenie formatu
                try:
                    x=float(x)
                except:
                    return self.var_limit_Tx_min.get()

                #sprawdzenie minimum
                if x>0.:
                    x=0.
                
                return x
                    
            self.shear_x_maxLimit = soControl(fc,
                                        label=u'Maksymalna warto [kN]: ',
                                        variable=self.var_limit_Tx_max,
                                        step=.1,
                                        allowempty=False,
                                        validatecmd=maxValidate)
            self.shear_x_maxLimit['selectmode']='normal'
            self.shear_x_maxLimit.entry['width']=8
            self.shear_x_maxLimit.grid(row=2, column=1, columnspan=1, sticky=E, padx=20)


            self.shear_x_minLimit = soControl(fc,
                                        label=u'Minimalna warto [kN]: ',
                                        variable=self.var_limit_Tx_min,
                                        step=.1,
                                        allowempty=False,
                                        validatecmd=minValidate)
            self.shear_x_minLimit['selectmode']='normal'
            self.shear_x_minLimit.entry['width']=8
            self.shear_x_minLimit.grid(row=3, column=1, columnspan=1, sticky=E, padx=20)

            #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
            self.addUpdateTabFunctions('data', updateFunc=[onCheckChange])
            

            ################################

            #utworzenie ramki
            f=soLabelFrame(tab, padding=5, text=u'Moment zginajcy My')
            f.pack(fill=X, padx=5)

            #utworzenie ramki
            fc=soFrame(f)
            fc.pack()

            def onCheckChange():
             
                if self.var_check_My.get():
                    self.bending_y_maxLimit['state']=NORMAL
                    self.bending_y_minLimit['state']=NORMAL
                else:
                    
                    self.bending_y_maxLimit['state']=DISABLED
                    self.bending_y_minLimit['state']=DISABLED

            self.bending_y_checkChB=soCheckbutton(fc,
                                                    variable=self.var_check_My,
                                                    command=onCheckChange,
                                                    text=trans(u'Uwzgldnij ograniczenia'),
                                                    )
            self.bending_y_checkChB.grid(row=1, column=1, columnspan=1, sticky=W, pady=5)


            #dodanie elementow do kontroli wartosci max i min
            def maxValidate(x):

                #sprawdzenie formatu
                try:
                    x=float(x)
                except:
                    return self.var_limit_My_max.get()

                #sprawdzenie minimum
                if x<0.:
                    x=0.
                
                return x

            def minValidate(x):

                #sprawdzenie formatu
                try:
                    x=float(x)
                except:
                    return self.var_limit_My_min.get()

                #sprawdzenie minimum
                if x>0.:
                    x=0.
                
                return x
                    
            self.bending_y_maxLimit = soControl(fc,
                                        label=u'Maksymalna warto [kNm]: ',
                                        variable=self.var_limit_My_max,
                                        step=.1,
                                        allowempty=False,
                                        validatecmd=maxValidate)
            self.bending_y_maxLimit['selectmode']='normal'
            self.bending_y_maxLimit.entry['width']=8
            self.bending_y_maxLimit.grid(row=2, column=1, columnspan=1, sticky=E, padx=20)

            self.bending_y_minLimit = soControl(fc,
                                        label=u'Minimalna warto [kNm]: ',
                                        variable=self.var_limit_My_min,
                                        step=.1,
                                        allowempty=False,
                                        validatecmd=minValidate)
            self.bending_y_minLimit['selectmode']='normal'
            self.bending_y_minLimit.entry['width']=8
            self.bending_y_minLimit.grid(row=3, column=1, columnspan=1, sticky=E, padx=20)

            #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
            self.addUpdateTabFunctions('data', updateFunc=[onCheckChange])

        nb=soNoteBook(tab)
        nb.pack(fill=BOTH, expand=1, padx=3, pady=3)

        xf=soFrame(tab)
        insertY(xf)

        yf=soFrame(tab)
        insertX(yf)
        
        nb.add(xf, text=u'Y-Y', padding=3,)
        nb.add(yf, text=u'X-X', padding=3,)

    def createTab_normal(self, tab):

        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=u'Sia normalna', padding=5)
        f.pack(fill=X, padx=5, pady=5)

        #utworzenie ramki
        fc=soFrame(f)
        fc.pack()

        #dodanie podstawowych informacji o wynikach        
        self.normal_res_generalInfo=dnComponentDlg.GeneralInfo(fc)
        self.normal_res_generalInfo.grid(row=1, column=1, padx=5, sticky=W)

        #dodanie separatora
        l=soSeparator(fc, orient='horizontal')
        l.grid(row=2, column=1, sticky=W+E)

        #dodanie pustej ramki (obnienie tekstu poniej)
        space=soFrame(fc, height=10)
        space.grid(row=3, column=1)

        #dodanie opisu
        l=soLabel(fc, text=u'Warto siy normalnej')
        l.grid(row=4, column=1, columnspan=1, sticky=W)

        #wyswietlenie sily dla najbardziej wytonego przekroju
        self.normal_res_N=dnComponentDlg.ResultValue(fc, lImage=self._createImage('normal_N'), rImage=self._createImage('unit_kN'), format='%.2f')
        self.normal_res_N.grid(row=5, column=1, padx=5, sticky=W+E, pady=8)


        #dodanie opisu
        l=soLabel(fc, text=u'Sprawdzenie warunku projektowego')
        l.grid(row=6, column=1, columnspan=1, sticky=W)


        #create comparison
        self.normal_res_comparison=dnComponentDlg.Comparison(fc,
                                                      lImage=self._createImage('comparison_N'),
                                                      rImage=None,
                                                      lFormat='%.2f', rFormat='%.1f')
        self.normal_res_comparison.grid(row=7, column=1, columnspan=1, sticky=E+W, pady=8)


        
    def createTab_shear(self, tab):

        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=u'Sia tnca', padding=5)
        f.pack(fill=X, padx=5, pady=5)

        #utworzenie ramki
        fc=soFrame(f)
        fc.pack()

        #dodanie podstawowych informacji o wynikach        
        self.shear_res_generalInfo=dnComponentDlg.GeneralInfo(fc)
        self.shear_res_generalInfo.grid(row=1, column=1, padx=5, sticky=W)

        #dodanie separatora
        l=soSeparator(fc, orient='horizontal')
        l.grid(row=2, column=1, sticky=W+E)

        #dodanie pustej ramki (obnienie tekstu poniej)
        space=soFrame(fc, height=10)
        space.grid(row=3, column=1)

        #dodanie opisu
        l=soLabel(fc, text=u'Warto siy tncej')
        l.grid(row=4, column=1, columnspan=1, sticky=W)

        #wyswietlenie sily dla najbardziej wytonego przekroju
        self.shear_res_Ty=dnComponentDlg.ResultValue(fc, lImage=self._createImage('shear_Ty'), rImage=self._createImage('unit_kN'), format='%.2f')
        self.shear_res_Ty.grid(row=5, column=1, padx=5, sticky=W+E, pady=8)


        #dodanie opisu
        l=soLabel(fc, text=u'Sprawdzenie warunku projektowego')
        l.grid(row=6, column=1, columnspan=1, sticky=W)


        #create comparison
        self.shear_res_comparison=dnComponentDlg.Comparison(fc,
                                                      lImage=self._createImage('comparison_Ty'),
                                                      rImage=None,
                                                      lFormat='%.2f', rFormat='%.1f')
        self.shear_res_comparison.grid(row=7, column=1, columnspan=1, sticky=E+W, pady=8)

        

    def createTab_bending(self, tab):


        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=u'Moment zginajcy Mx', padding=5)
        f.pack(fill=X, padx=5, pady=5)

        #utworzenie ramki
        fc=soFrame(f)
        fc.pack()

        #dodanie podstawowych informacji o wynikach        
        self.bending_res_generalInfo=dnComponentDlg.GeneralInfo(fc)
        self.bending_res_generalInfo.grid(row=1, column=1, padx=5, sticky=W)

        #dodanie separatora
        l=soSeparator(fc, orient='horizontal')
        l.grid(row=2, column=1, sticky=W+E)

        #dodanie pustej ramki (obnienie tekstu poniej)
        space=soFrame(fc, height=10)
        space.grid(row=3, column=1)

        #dodanie opisu
        l=soLabel(fc, text=u'Warto momentu zginajcego')
        l.grid(row=4, column=1, columnspan=1, sticky=W)

        #wyswietlenie sily dla najbardziej wytonego przekroju
        self.bending_res_Mx=dnComponentDlg.ResultValue(fc, lImage=self._createImage('bending_Mx'), rImage=self._createImage('unit_kNm'), format='%.2f')
        self.bending_res_Mx.grid(row=5, column=1, padx=5, sticky=W+E, pady=8)


        #dodanie opisu
        l=soLabel(fc, text=u'Sprawdzenie warunku projektowego')
        l.grid(row=6, column=1, columnspan=1, sticky=W)


        #create comparison
        self.bending_res_comparison=dnComponentDlg.Comparison(fc,
                                                      lImage=self._createImage('comparison_Mx'),
                                                      rImage=None,
                                                      lFormat='%.2f', rFormat='%.1f')
        self.bending_res_comparison.grid(row=7, column=1, columnspan=1, sticky=E+W, pady=8)



        

    def createTab_shear_x(self, tab):

        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=u'Sia tnca Tx', padding=5)
        f.pack(fill=X, padx=5, pady=5)

        #utworzenie ramki
        fc=soFrame(f)
        fc.pack()

        #dodanie podstawowych informacji o wynikach        
        self.shear_x_res_generalInfo=dnComponentDlg.GeneralInfo(fc)
        self.shear_x_res_generalInfo.grid(row=1, column=1, padx=5, sticky=W)

        #dodanie separatora
        l=soSeparator(fc, orient='horizontal')
        l.grid(row=2, column=1, sticky=W+E)

        #dodanie pustej ramki (obnienie tekstu poniej)
        space=soFrame(fc, height=10)
        space.grid(row=3, column=1)

        #dodanie opisu
        l=soLabel(fc, text=u'Warto siy tncej')
        l.grid(row=4, column=1, columnspan=1, sticky=W)

        #wyswietlenie sily dla najbardziej wytonego przekroju
        self.shear_x_res_Tx=dnComponentDlg.ResultValue(fc, lImage=self._createImage('shear_x_Tx'), rImage=self._createImage('unit_kN'), format='%.2f')
        self.shear_x_res_Tx.grid(row=5, column=1, padx=5, sticky=W+E, pady=8)


        #dodanie opisu
        l=soLabel(fc, text=u'Sprawdzenie warunku projektowego')
        l.grid(row=6, column=1, columnspan=1, sticky=W)


        #create comparison
        self.shear_x_res_comparison=dnComponentDlg.Comparison(fc,
                                                      lImage=self._createImage('comparison_Tx'),
                                                      rImage=None,
                                                      lFormat='%.2f', rFormat='%.1f')
        self.shear_x_res_comparison.grid(row=7, column=1, columnspan=1, sticky=E+W, pady=8) 
        


    def createTab_bending_y(self, tab):

        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=u'Moment zginajcy My', padding=5)
        f.pack(fill=X, padx=5, pady=5)

        #utworzenie ramki
        fc=soFrame(f)
        fc.pack()

        #dodanie podstawowych informacji o wynikach        
        self.bending_y_res_generalInfo=dnComponentDlg.GeneralInfo(fc)
        self.bending_y_res_generalInfo.grid(row=1, column=1, padx=5, sticky=W)

        #dodanie separatora
        l=soSeparator(fc, orient='horizontal')
        l.grid(row=2, column=1, sticky=W+E)

        #dodanie pustej ramki (obnienie tekstu poniej)
        space=soFrame(fc, height=10)
        space.grid(row=3, column=1)

        #dodanie opisu
        l=soLabel(fc, text=u'Warto momentu zginajcego')
        l.grid(row=4, column=1, columnspan=1, sticky=W)

        #wyswietlenie sily dla najbardziej wytonego przekroju
        self.bending_y_res_My=dnComponentDlg.ResultValue(fc, lImage=self._createImage('bending_y_My'), rImage=self._createImage('unit_kNm'), format='%.2f')
        self.bending_y_res_My.grid(row=5, column=1, padx=5, sticky=W+E, pady=8)

        #dodanie opisu
        l=soLabel(fc, text=u'Sprawdzenie warunku projektowego')
        l.grid(row=6, column=1, columnspan=1, sticky=W)

        #create comparison
        self.bending_y_res_comparison=dnComponentDlg.Comparison(fc,
                                                      lImage=self._createImage('comparison_My'),
                                                      rImage=None,
                                                      lFormat='%.2f', rFormat='%.1f')
        self.bending_y_res_comparison.grid(row=7, column=1, columnspan=1, sticky=E+W, pady=8)


    def createDemoTab(self, tab):

        #dodanie label
        l=soLabel(tab, text='Ostatnia aktualizacja')
        l.pack()

        #dodanie label
        self.demoTab_time=soLabel(tab, textvariable=self.var_dialogVariable)
        self.demoTab_time.pack()

        #dodaj separator
        s=soSeparator(tab, orient='horizontal')
        s.pack(fill=X, padx=3)

        ##przyklad uzycia 'dodatkowych' wynikow z analizy w oknie dialogowym
        self.demoTab_label=soLabel(tab, text='Brak wyniku', textvariable=self.var_dialogVariable_string)
        self.demoTab_label.pack()

        #checkbutton
        self.demoTab_chb=soCheckbutton(tab, text='Zmienna typu "Boolean"', variable=self.var_dialogVariable_boolean)
        self.demoTab_chb.pack()

        self.demoTab_control = soControl(tab,
                                        label=u'Warto: ',
                                        variable=self.var_dialogVariable_double,
                                         )
        self.demoTab_control['selectmode']='normal'
        self.demoTab_control.pack()

    #upd
    def updateTab_data(self):
        
        ##nie ma nic do aktualizacji
        pass
    
    def updateTab_normal(self, ipsData):


        #ipsData to slownik ze szczegolowymi informacjami zapisanymi w czasie wymiarowania
        if ipsData!=None and ipsData['calculated']:

            #wyswietlenie wartosci
            self.normal_res_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci wynikowych
            self.normal_res_N.setValue(ipsData['N'])

            #wyswietlenie wartosci dla warunkow projektowych
            self.normal_res_comparison.setValues(ipsData['ratio'], 1.)

        else:

            #wyczyszczenie kontrolek          
            self.normal_res_generalInfo.clear()
            
            self.normal_res_N.clear()
            self.normal_res_comparison.clear()

        

    def updateTab_shear(self, ipsData):

        #ipsData to slownik ze szczegolowymi informacjami zapisanymi w czasie wymiarowania       
        if ipsData!=None and ipsData['calculated']:

            #wyswietlenie wartosci
            self.shear_res_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci wynikowych
            self.shear_res_Ty.setValue(ipsData['Ty'])

            #wyswietlenie wartosci dla warunkow projektowych
            self.shear_res_comparison.setValues(ipsData['ratio'], 1.)

        else:

            #wyczyszczenie            
            self.shear_res_generalInfo.clear()
            
            self.shear_res_Ty.clear()
            self.shear_res_comparison.clear()

    def updateTab_bending(self, ipsData):
        
        #ipsData to slownik ze szczegolowymi informacjami zapisanymi w czasie wymiarowania    
        if ipsData!=None and ipsData['calculated']:

            #wyswietlenie wartosci
            self.bending_res_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci wynikowych
            self.bending_res_Mx.setValue(ipsData['Mx'])

            #wyswietlenie wartosci dla warunkow projektowych
            self.bending_res_comparison.setValues(ipsData['ratio'], 1.)
        
        else:

            #wyczyszczenie            
            self.bending_res_generalInfo.clear()
            
            self.bending_res_Mx.clear()
            self.bending_res_comparison.clear()
            
    def updateTab_shear_x(self, ipsData):
        
        #ipsData to slownik ze szczegolowymi informacjami zapisanymi w czasie wymiarowania    
        if ipsData!=None and ipsData['calculated']:

            #wyswietlenie wartosci
            self.shear_x_res_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci wynikowych
            self.shear_x_res_Tx.setValue(ipsData['Tx'])

            #wyswietlenie wartosci dla warunkow projektowych
            self.shear_x_res_comparison.setValues(ipsData['ratio'], 1.)
        
        else:

            #wyczyszczenie            
            self.shear_x_res_generalInfo.clear()
            
            self.shear_x_res_Tx.clear()
            self.shear_x_res_comparison.clear()

    def updateTab_bending_y(self, ipsData):

        #ipsData to slownik ze szczegolowymi informacjami zapisanymi w czasie wymiarowania    
        if ipsData!=None and ipsData['calculated']:

            #wyswietlenie wartosci
            self.bending_y_res_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci wynikowych
            self.bending_y_res_My.setValue(ipsData['My'])

            #wyswietlenie wartosci dla warunkow projektowych
            self.bending_y_res_comparison.setValues(ipsData['ratio'], 1.)
        
        else:

            #wyczyszczenie            
            self.bending_y_res_generalInfo.clear()
            
            self.bending_y_res_My.clear()
            self.bending_y_res_comparison.clear()
            
    def updateDemoTab(self):

        #import modulu
        import time

        #zmiana ostatniej aktualizacji
        st=time.strftime("%a, %d %b %Y %H:%M:%S +0000",  time.gmtime())
        self.var_dialogVariable.set(st)

        #aktualizuj wartosci okna dialogowego na podstawie wynikow 'dodatkowych'
        rObj=self.getCompObj().getResults()
        self.var_dialogVariable_string.set(rObj.getResult('wynik_1'))
        self.var_dialogVariable_double.set(rObj.getResult('wynik_2'))
        self.var_dialogVariable_boolean.set(rObj.getResult('wynik_3'))
        
    #
    def updateTabsStatus(self):

        pass
    
        #ponizej zamieszczono przyklad kontroli zakladek
        #zakladka zostaje wlaczona gdy w wynikach znaduje sie przeliczony odpowiedni warunek projektowy
        #w niniejszym komponencie nie ma koniecznosci kontroli aktywnosci zakladek


        #block all
        ##self.changeAllTabsStatus(DISABLED)

        #set active
        ##self.changeTabStatus(self.genTabObj['name'], NORMAL)
        ##self.changeTabStatus(self.loadCombTabObj['name'], NORMAL)
        ##self.changeTabStatus(self.resTabObj['name'], NORMAL)
        

        #check calculation
        ##if not self.getCompObj().getResults().getError():
            
            #calc items
            ##calculatedItems=self.getCompObj().getResults().getInPointResults().getCalculatedSubjects()

            ##if set([NORMAL_FORCE, ]) & set(calculatedItems) != set([]):
            ##    self.changeTabStatus('normal', NORMAL)

            ##if set([SHEAR, ]) & set(calculatedItems) != set([]):
            ##    self.changeTabStatus('shear', NORMAL)

            ##if set([BENDING, ]) & set(calculatedItems) != set([]):
            ##    self.changeTabStatus('bending', NORMAL)

            ##if set([SHEAR_X, ]) & set(calculatedItems) != set([]):
            ##    self.changeTabStatus('shear_x', NORMAL)

            ##if set([BENDING_Y, ]) & set(calculatedItems) != set([]):
            ##    self.changeTabStatus('bending_y', NORMAL)

                
    #overwrite
    def onCurrentSubjectChange(self, subject):

        #pobranie widoku glownego elementu
        generalView=self.getGeneralView()

        curSubject=self.getCurrentSubject()
        if curSubject in [NORMAL_FORCE, SHEAR, BENDING]:

            #show section forces            
            generalView.setValues(showSFGraph=True,
                           sfGraph_loadCombination=self.getCompObj().getValue('loadCombination'),
                           sfGraph_leadingValue=[NORMAL_FORCE, SHEAR, BENDING].index(curSubject),
                           sfGraph_loadCombinationType=self.getCompObj().getValue('loadCombinationType'),
                           )
            generalView.update(all=False, elementSF=True, pointSF=True, )

        else:

            #hide section forces
            generalView.setValues(showSFGraph=False,)
            generalView.update(all=False, elementSF=True, pointSF=True, )

    def getSize(self):
        return (0.9, 0.85)
        
class SectionForcesAnalyzer(dnComponent.BeamComponent):
    type=dnConstants.COMP_SECTION_FORCES_ANALYZER
    name=u'Siy przekrojowe'
    description=trans(u'Procedura do analizy si przekrojowych')
    dirPath=os.path.join(dnConstants.LIB_DIR_PATH, 'components/beam/sectionForcesAnalyzer/')
    iconPath=os.path.join(dnConstants.LIB_DIR_PATH, 'components/beam/sectionForcesAnalyzer/img/icon.gif')
    summarySubjects=[
            NORMAL_FORCE,
            SHEAR,
            BENDING,
            SHEAR_X,
            BENDING_Y,
                         ]
    def __init__(self, parent, itemId):

        #base class
        dnComponent.BeamComponent.__init__(self, parent, itemId)

        #set def point num
        self.setDefaultPointsNumber(11, update=False)


    def setDefault(self):

        #call base method
        dnComponent.BeamComponent.setDefault(self)

        #class vars   
        self.check_N=1
        self.check_Ty=1
        self.check_Mx=1
        self.check_Tx=1
        self.check_My=1
        self.limit_N_min=-10.
        self.limit_N_max=10.
        self.limit_Ty_min=-10.
        self.limit_Ty_max=10.
        self.limit_Mx_min=-10.
        self.limit_Mx_max=10.
        self.limit_Tx_min=-10.
        self.limit_Tx_max=10.
        self.limit_My_min=-10.
        self.limit_My_max=10.

        #zmienne ponizej sa dziedziczone z klasy *BeamComponent* i mozna nimi operowac uzywajac zakladki *loadComb*
        #zmienne zostaly dodane do grupy zmiennych, ktory wplywaja na wyniki analizy (patrz dokumentacja *addHardRecalcVars*)
        ##self.loadCombination=1
        ##self.loadCombinationType=sdConstants.LOAD_COMB_TYPE_USL_BASIC

    # 
    def _calcExtremalSectionForces(self):

        #pobarnie obiektu zarzadzajacego wynikami dla elementu
        resultsObj=self.getItem().getResults().getStatResults()

        #obliczenie sil przekrojowych dla elementu dla roznych kombinacji obciazenia
        sf={}
        for sfType in [0,1,2]:#petla  sily przekrojowe

            #dodanie klucza do slownika
            sf[sfType]={}

            for envType in [sdConstants.ENVELOPE_TYPE_MIN, sdConstants.ENVELOPE_TYPE_MAX]: #petla  typ obwiedni

                    #obliczenie sil przekrojowych dla kombinacji
                    sfRes=resultsObj.getInternalForcesForElement(
                                                loadCombination=self.loadCombination,
                                                leadingValue=sfType,
                                                envelopeType=envType,
                                                laodCombinationType=self.loadCombinationType,
                                                #
                                                userPoints=self.getPoints(), 
                                                ) 

                    #dodanie sil do slownika
                    sf[sfType][envType]= sfRes 

        #przypisanie slownika z silami przekrojowymi do zmiennej klasy
        self._extremalSectionForces=sf

    #
    def doCustomCheck(self):

        #nie ma koniecznosci sprawdzenia czegokolwiek

        return True
    
    def doBeforeCalculate(self):        

        #nie ma koniecznosci wykonania dodatkowych operacji na danych wejsciowych

        return True

    def doCalculate(self, soft=False):

        #jezeli konieczne, aktualizuj sily przekrojowe
        if not soft:
            self._calcExtremalSectionForces()


        #################################
        ###  DANE WEJSCIOWE
        #################################

        #W TYM PRZYKLADZIE POTRZEBNE SA TYLKO SILY PRZEKROJOWE

        #################################
        ###  OBLICZENIA
        #################################

        #obliczenia elementu dla poszczeglnych kombinacji i rzednych
        for sfType, sfData in self._extremalSectionForces.items():#petla  sily przekrojowe
            for envType, envData in sfData.items(): #petla  typ obwiedni
            
                #pobranie wynikw dla charakterystycznych puntkw/rzednych
                sfVals=envData.getForCharPoints()#szczegly: SOLDIS_reference

                for i in range(0, len(sfVals[0][0])):

                    #pobranie rzednej
                    ord = sfVals[0][0][i]
                    lcType='%s %s'%(['min', 'max'][[sdConstants.ENVELOPE_TYPE_MIN, sdConstants.ENVELOPE_TYPE_MAX].index(envType)], ['N', 'Ty', 'Mx'][sfType])               

                    #pobranie sil przekrojowych w plaszczyznie uklad
                    N = sfVals[0][1][i]
                    Ty = sfVals[1][1][i]
                    Mx = sfVals[2][1][i]
                    N_combLoadGroups = sfVals[0][2][i] # pobranie grup obc.; szczegly: SOLDIS_reference
                    Ty_combLoadGroups = sfVals[1][2][i] # pobranie grup obc.; szczegly: SOLDIS_reference
                    Mx_combLoadGroups = sfVals[2][2][i] # pobranie grup obc.; szczegly: SOLDIS_reference
                    
                    #pobranie sil w plaszczyznie prostopadlej do ukladu
                    char_Tx, char_My, Tx, My = self.calcSectionForceForXZBend(ord)

                    #pobranie obiektu przechowujacego wyniki w punkcie
                    iprContObj=self.getResults().getInPointResults()

                    #dodanie wynikw dla rzednej; jezeli istnieja to zamiast tworzyc nowy obiekt, metoda add zwrci obiekt juz istniejacy
                    iprObj=iprContObj.add(ord)

                    #obliczenie warunkow projektowych
                    
                    ####################################
                    ### NORMALNA N
                    ####################################

                    pData={}
                    pData['N'] = N
                    if self.check_N:#limit
                        if N>0.:
                            ratio=N/self.limit_N_max
                        else:
                            ratio=N/self.limit_N_min

                        pData['ratio']=ratio
                        pData['calculated']=True
                    else:
                        pData['ratio']=0.
                        pData['calculated']=False
                        
                    #dodanie wynikw
                    iprObj.addData(lcType, NORMAL_FORCE, pData, loadGroups=N_combLoadGroups)

                    ####################################
                    ### TNACA TY
                    ####################################

                    pData={}
                    pData['Ty'] = Ty
                    if self.check_Ty:#limit
                        if Ty>0.:
                            ratio=Ty/self.limit_Ty_max
                        else:
                            ratio=Ty/self.limit_Ty_min

                        pData['ratio']=ratio
                        pData['calculated']=True
                    else:
                        pData['ratio']=0.
                        pData['calculated']=False
                        
                    #dodanie wynikw
                    iprObj.addData(lcType, SHEAR, pData, loadGroups=Ty_combLoadGroups)

                    ####################################
                    ### MOMENT MX
                    ####################################

                    pData={}
                    pData['Mx'] = Mx
                    if self.check_Mx:#limit
                        if Mx>0.:
                            ratio=Mx/self.limit_Mx_max
                        else:
                            ratio=Mx/self.limit_Mx_min

                        pData['ratio']=ratio
                        pData['calculated']=True
                    else:
                        pData['ratio']=0.
                        pData['calculated']=False
                        
                    #dodanie wynikw
                    iprObj.addData(lcType, BENDING, pData, loadGroups=Mx_combLoadGroups)


                    ####################################
                    ### TNACA TX
                    ####################################

                    pData={}
                    pData['Tx'] = Tx
                    if self.check_Tx:#limit
                        if Tx>0.:
                            ratio=Tx/self.limit_Tx_max
                        else:
                            ratio=Tx/self.limit_Tx_min

                        pData['ratio']=ratio
                        pData['calculated']=True
                    else:
                        pData['ratio']=0.
                        pData['calculated']=False
                        
                    #dodanie wynikw
                    iprObj.addData(lcType, SHEAR_X, pData)

                    ####################################
                    ### MOMENT MY
                    ####################################

                    pData={}
                    pData['My'] = My
                    if self.check_My:#limit
                        if My>0.:
                            ratio=My/self.limit_My_max
                        else:
                            ratio=My/self.limit_My_min

                        pData['ratio']=ratio
                        pData['calculated']=True
                    else:
                        pData['ratio']=0.
                        pData['calculated']=False
                        
                    #dodanie wynikw
                    iprObj.addData(lcType, BENDING_Y, pData)  

            
        ####################################
        ### WYNIKI DODATKOWE
        ####################################

        #dodanie wynikow - DEMO - przyklad zastosowania w zakladce 'demo'
        self.getResults().setResults({
            'wynik_1':'wynik ogolny',
            'wynik_2':1234.,
            'wynik_3':True,
            })
        
        #################################
        ###  OKRESLENIE WYTEZENIA ELEMENTU
        #################################

        #get max ratios
        ripObj=self.getResults().getInPointResults()
        maxRatio, maxRatios = ripObj.getMaxRatio(return_all=True)

        #set summary    
        self.getResults().setSummary( [[h, maxRatios[h]] for h in self.summarySubjects] )

        #################################
        ###  DODANIE KOMENTARZA
        #################################

        #dodanie komentarza
        if self.getResults().getUseRatio() > 1.:
            self.getMessageManager().addMessage(u'!!!Nono elementu przekroczona!!!.', type=dnComponent.MSG_TYPE_ERROR)
        else:
            self.getMessageManager().addMessage(u'Element zaprojektowany poprawnie.', type=dnComponent.MSG_TYPE_IMPORTANT)

        return True

    #
    def insertRTFReport(self, docObj, sectionObj):

        #utworzenie obiektu z metodami do tworzenia raportu
        rtfReportMethod=sdRTFReport.RTFRaport_MethodsObj(self, docObj, sectionObj)

        #spacer
        indent=3*' '

        #dodanie naglowka
        self.insertRTFReport_ComponentHeader(rtfReportMethod)

        #dodanie inforamcji o elemencie       
        self.insertRTFReport_ItemInfo(rtfReportMethod)
  
        #zmienne projektowe
        rtfReportMethod.insertTitle('Dane projektowe')

        rtfReportMethod.insertText('Sprawdzaj warunek dla N: %s'%(['nie', 'tak'][self.check_N]))
        if self.check_N:
            rtfReportMethod.insertText(indent+'Warto minimalna: %s [kN]'%(str(self.limit_N_min)))
            rtfReportMethod.insertText(indent+'Warto maksymalna: %s [kN]'%(str(self.limit_N_max)))
        rtfReportMethod.insertText('Sprawdzaj warunek dla Ty: %s'%(['nie', 'tak'][self.check_Ty]))
        if self.check_Ty:
            rtfReportMethod.insertText(indent+'Warto minimalna: %s [kN]'%(str(self.limit_Ty_min)))
            rtfReportMethod.insertText(indent+'Warto maksymalna: %s [kN]'%(str(self.limit_Ty_max)))
        rtfReportMethod.insertText('Sprawdzaj warunek dla Mx: %s'%(['nie', 'tak'][self.check_Mx]))
        if self.check_Mx:
            rtfReportMethod.insertText(indent+'Warto minimalna: %s [kN]'%(str(self.limit_Mx_min)))
            rtfReportMethod.insertText(indent+'Warto maksymalna: %s [kN]'%(str(self.limit_Mx_max)))
        rtfReportMethod.insertText('Sprawdzaj warunek dla Tx: %s'%(['nie', 'tak'][self.check_Tx]))
        if self.check_Tx:
            rtfReportMethod.insertText(indent+'Warto minimalna: %s [kN]'%(str(self.limit_Tx_min)))
            rtfReportMethod.insertText(indent+'Warto maksymalna: %s [kN]'%(str(self.limit_Tx_max)))
        rtfReportMethod.insertText('Sprawdzaj warunek dla My: %s'%(['nie', 'tak'][self.check_My]))
        if self.check_My:
            rtfReportMethod.insertText(indent+'Warto minimalna: %s [kN]'%(str(self.limit_My_min)))
            rtfReportMethod.insertText(indent+'Warto maksymalna: %s [kN]'%(str(self.limit_My_max)))
        
        ##        
        ##RESULTSa
        ##

        rtfReportMethod.insertTitle('Wyniki dla elementu')

        #pobranie obiektu z wynikami dla poszczegolnych rzednych
        iprCont=self.getResults().getInPointResults()
        
        #pobranie informacji, ktory warunek byl miarodajny i narysowaniy wykresu dla niego
        extInfo=iprCont.find_theBiggestRatio(types=[None, ], subjects=None, ords=[-1, ])
        if extInfo==None:
            lv=2
        else:
            maxRatio, maxId, maxType, maxSubject = extInfo
            if maxSubject == NORMAL_FORCE:
                lv=0
            elif maxSubject == SHEAR:
                lv=1
            elif maxSubject == BENDING:
                lv=2
            else:
                lv=2

        rtfReportMethod.insertText("Wykres dla warunku: %s"%maxSubject.encode('cp1250'))
        #dodanie rysunku modelu (lub jego fragmentu)
        graphTools=rtfReportMethod.insertGraph()
        graphTools.initilize(filtr='ELEMENTS', items=[self.getItem().getGraphId(), ])
        graphTools.drawNodes()
        graphTools.drawElements()
        graphTools.drawBoundaryConditions()
        #graphTools.drawLoads()
        #graphTools.drawReactions(loadCombination=True, 	leadingValue=None, 	loadCombinationType=sdConstants.LOAD_COMB_TYPE_USL_BASIC,)
        graphTools.drawSectionForces(loadCombination=True, 	leadingValue=lv, 	loadCombinationType=sdConstants.LOAD_COMB_TYPE_USL_BASIC, log=False)
        #graphTools.drawDisplacement(loadCombination=True, 	leadingValue=None, 	loadCombinationType=sdConstants.LOAD_COMB_TYPE_USL_BASIC, log=False)
        graphTools.draw()                     

        #dodanie opisu wykresu
        loadCombDescr=self._getStatResultManager().getConfigurationText(
                                     loadCombination=True,
                                     loadCombinationType=sdConstants.LOAD_COMB_TYPE_USL_BASIC,                         
                                     )
        rtfReportMethod.insertText(loadCombDescr.encode('cp1250'))
        rtfReportMethod.insertText()

        #dodanie podsumowania 
        useRatio=self.getResults().getUseRatio()
        rtfReportMethod.insertText('%s: %s'%('Cakowite wytenie elementu', '%.0f'%(useRatio*100.)+'%'),
                                   fontEffect='bold', fontColor=['black', 'red'][useRatio>1.])
        rtfReportMethod.insertText()
        
        #dodanie podsumowania
        resObj=self.getResults()
        for sumName, sumRatio in self.getResults().getSummary():
            rtfReportMethod.insertText(indent+'%s: %s'%(sumName.encode('cp1250'), '%.0f'%(sumRatio*100.))+' %',
                                       fontColor=['black', 'red'][sumRatio>1.])
        rtfReportMethod.insertText()

        ##PRZYKLAD WSTAWIENIA RYSUNKU DO RAPORTU (ABY WLACZYC USUN ZNAK '#' W LINIACH PONIZEJ, POZOSTAW W KOMENTARZACH)
        
        #dodanie podrozdzialu
        #rtfReportMethod.insertTitle('Przykad wstawienia rysunku')

        #przyklad wstawienia rysunku
        #rtfReportMethod.insertImage(os.path.join(self.getImgDirPath(), 'image.jpg'))

        

   
    #graph
    def drawIcon_OFF(self, canvas, x, y):

        #draw symbol
        iconId=canvas.create_text(x, y,
                                              text='NTM',
                                              fill='blue',
                                              #anchor=W,
                                              activefill='red',
                                              font=('tahoma', 13, 'bold'),
                                              )
        return iconId
    
    #get
    def getDlgClass(self):
        return SectionForcesAnalyzerDlg_multiPoint
    def getAvailableDlgClasses(self):
        return [['klasyczny', SectionForcesAnalyzerDlg_classic], ['ulepszony', SectionForcesAnalyzerDlg_multiPoint]]
        