# -*- coding: cp1250 -*-

"""
plik: stressAnalyzerComp.py
autor: Krzysztof Szajek (biuro@soldis.com.pl)

Przykad reguy wymiarowania analizujcej naprenia dopuszczalne.

Modu stanowi integraln cz progrmau Soldis PROJEKTANT. Zabrania si rozpowszechniania fragmentw lub caoci poniszego kodu bez zgody AUTORA. Szczegowe warunki licencji - patrz: licencja/licence.txt w katalogu instalacyjnym programu.
"""


#general
from dnBaseLib import *

#python modules
import os
import random
import copy
import types

#design modules
import dnConstants
import dnComponent
import dnComponentDlg

#soldis
import sdConstants
import sdRTFReport
import sdSchemeImageMaker

#soldis env
import soSymbols

#exterior
import PyRTF

#warunki projektowe
COMPRESSION=trans(u'Naprenia ciskajce')
TENSION=trans(u'Naprenia rozcigajce')

class StressAnalyzerDlg_classic(dnComponentDlg.ComponentContextBeamDlg):
    def __init__(self, parent, compObj, **kw):

        #klasa nadrzdna
        dnComponentDlg.ComponentContextBeamDlg.__init__(self, parent, compObj, **kw)

        #rejestracja zakladek
        tabObj=self.registerGeneralTab(addSubjectChooser=True)
        #tabObj=self.registerProfileTab()
        self.registerLoadCombTab()
        self.registerTab('general', image=self._createImage('tab_data_icon'),
                         createFunc=self.createGeneralTab, updateFun=self.updateGeneralTab, subjectId=[0, 1])
        #self.registerResultTab(createFunc=self.createResultTab, updateFun=self.updateResultTab)
        self.registerStdResultTab()

        #dodanie listy z rzednymi i typami wynikow
        self.registerOrdinateChooser()
        self.registerTypeChooser()

        #rejestracja widoku przekroju
        self.registerSectionView(activeSectionEdges=False)                
        self.registerGeneralSectionViewTab()

        #rejestracja dodatkowych przyciskow 
        self.registerOrdinateButton()
        self.registerSizingPointsButton()
        self.registerDefaultPointsNumberControl()
        self.registerNextPrevButtons()
        self.setDefaultTab(tabObj['name'])
        
        #budowa okna
        self.build()

        
    def setVars(self):


        #dodanie zmiennych      
        self._addVar('tensionLimit', type='DoubleVar')
        self._addVar('compressionLimit', type='DoubleVar')
        self._addVar('defaultTensionLimit', type='IntVar')
        self._addVar('defaultCompressionLimit', type='IntVar')

        
    #
    def createGeneralTab(self, tab):
        

        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=COMPRESSION, padding=5)
        f.pack(padx=5, pady=5, fill=X)
        f.columnconfigure(0, weight=1)

        #dodanie podstawowych informacji o wynikach        
        self.stress_res_min_generalInfo=dnComponentDlg.GeneralInfo(f)
        self.stress_res_min_generalInfo.grid(row=1, column=0, columnspan=1, sticky=W)

        #dummy
        l=soLabel(f, text=' ')
        l.grid(row=2, column=0)

        #dodanie opisu
        l=soLabel(f, text=u'Warto dopuszczalna')
        l.grid(row=3, column=0, columnspan=1, sticky=E+W)

        #dodanie ramki
        stressLimitLF=soFrame(f)
        stressLimitLF.grid(row=4, column=0, columnspan=1, sticky=E+W)

        #dodanie obslugi limitu naprezen
        def onDefaultCompressionLimit():
            self.compressionLimitCon['state']=[NORMAL, DISABLED][self.var_defaultCompressionLimit.get()]
            
        self.defaultCompressionLimitChB=soCheckbutton(stressLimitLF,
                                                    variable=self.var_defaultCompressionLimit,
                                                    command=onDefaultCompressionLimit,
                                                    text=trans(u'Domylny limit dla napre ciskajcych')
                                                    )
        self.defaultCompressionLimitChB.pack()

        #dodanie obslugi limitu naprezen
        def _checkIfFloat(x):
            #check if float            
            try:
                float(x)
                return True
            except:
                return False     

        def limitValidate(x):
            if not _checkIfFloat(x):
                x=1.0
            if float(x)>10e9:
                x=10e6
            if float(x)<0.1:
                x=0.1
            return x

        self.compressionLimitCon = soControl(stressLimitLF,
                                    label=trans(u'Max. naprenia ciskajce: '),
                                    variable=self.var_compressionLimit,
                                    step=1.0,
                                    allowempty=False,
                                    validatecmd=limitValidate)
        self.compressionLimitCon.entry['width']=12
        self.compressionLimitCon['selectmode']='normal'
        self.compressionLimitCon.pack()

        #dummy
        l=soFrame(f,)
        l.grid(row=5, column=0, pady=7)

        #dodanie opisu
        l=soLabel(f, text=u'Sprawdzenie warunku projektowego:')
        l.grid(row=6, column=0, columnspan=1, sticky=E+W)


        #dodanie wizualizacji warunku projektowego
        self.stress_res_min_comparison=dnComponentDlg.Comparison(f,
                                                      lImage=self._createImage('res_sigmaMin'),
                                                      rImage=self._createImage('res_sigmaMinLimit'),
                                                      lFormat='%.2f', rFormat='%.2f')
        self.stress_res_min_comparison.grid(row=7, column=0, columnspan=1, sticky=E+W)

        #dummy
        l=soFrame(f,)
        l.grid(row=8, column=0, pady=7)

        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=TENSION, padding=[5,5,5,5])
        f.pack(padx=5, pady=5, fill=X)
        f.columnconfigure(0, weight=1)

        #dodanie podstawowych informacji o wynikach        
        self.stress_res_max_generalInfo=dnComponentDlg.GeneralInfo(f)
        self.stress_res_max_generalInfo.grid(row=1, column=0, columnspan=1, sticky=W)

        #dummy
        l=soFrame(f)
        l.grid(row=2, column=0, pady=7)

        #dodanie opisu
        l=soLabel(f, text=u'Warto dopuszczalna')
        l.grid(row=3, column=0, columnspan=1, sticky=E+W)
        
        #dodanie ramki
        stressLimitLF=soFrame(f)
        stressLimitLF.grid(row=4, column=0, columnspan=1, sticky=E+W)

        #dodanie obslugi limitu
        def onDefaultTensionLimit():
            self.tensionLimitCon['state']=[NORMAL, DISABLED][self.var_defaultTensionLimit.get()]
                
        self.defaultTensionLimitChB=soCheckbutton(stressLimitLF,
                                                variable=self.var_defaultTensionLimit,
                                                command=onDefaultTensionLimit,
                                                text=trans(u'Domylny limit dla napre rozcigajcych')
                                                )
        self.defaultTensionLimitChB.pack()

        #dodanie obslugi limitu
        self.tensionLimitCon = soControl(stressLimitLF,
                                    label=trans(u'Max. naprenia rozcigajce: '),
                                    variable=self.var_tensionLimit,
                                    step=1.0,
                                    allowempty=False,
                                    validatecmd=limitValidate)
        self.tensionLimitCon['selectmode']='normal'
        self.tensionLimitCon.entry['width']=12
        self.tensionLimitCon.pack()

        #dummy
        l=soFrame(f)
        l.grid(row=5, column=0, pady=7)

        #dodanie opisu
        l=soLabel(f, text=u'Sprawdzenie warunku projektowego:')
        l.grid(row=6, column=0, columnspan=1, sticky=E+W)
        
        #dodanie warunku projektowego
        self.stress_res_max_comparison=dnComponentDlg.Comparison(f,
                                                      lImage=self._createImage('res_sigmaMax'),
                                                      rImage=self._createImage('res_sigmaMaxLimit'),
                                                      lFormat='%.2f', rFormat='%.2f')
        self.stress_res_max_comparison.grid(row=7, column=0, columnspan=1, sticky=E+W)


        #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
        self.addUpdateTabFunctions('general', updateFunc=[onDefaultTensionLimit,
                                                          onDefaultCompressionLimit,
                                                          ])
        
    #
    def updateGeneralTab(self):

        #pobranie wynikw
        resCont=self.getCompObj().getResults()

        #pobranie obiektu z wynikami dla poszczegolnych rzednych
        iprCont=resCont.getInPointResults()

        #pobranie ekstremalnego wyniku dla biezacej rzednej oraz odpowiedniego warunku projektowego i typu wynikow
        iprCont=self.getCompObj().getResults().getInPointResults()
        ipsData=iprCont.find_theBiggestRatio(types=[self.getCurrentType(), ],
                                             subjects=[COMPRESSION, ],
                                             ords=[self.getCurrentPoint(), ],
                                             
                                             subject=COMPRESSION,
                                             )

        if ipsData!=None and ipsData['calculated']:

            #wyswietlenie wartosci
            self.stress_res_min_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci dla warunkow projektowych
            self.stress_res_min_comparison.setValues(fabs(ipsData['minStress']), resCont.getResult('cStressLimit'))

        
        else:

            #wyczyszczenie            
            self.stress_res_min_generalInfo.clear()
            self.stress_res_min_comparison.clear()


        #pobranie ekstremalnego wyniku dla biezacej rzednej oraz odpowiedniego warunku projektowego i typu wynikow
        iprCont=self.getCompObj().getResults().getInPointResults()
        ipsData=iprCont.find_theBiggestRatio(types=[self.getCurrentType(), ],
                                             subjects=[TENSION, ],
                                             ords=[self.getCurrentPoint(), ],
                                             
                                             subject=TENSION,
                                             )

        if ipsData!=None and ipsData['calculated']:


            #wyswietlenie wartosci
            self.stress_res_max_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci dla warunkow projektowych
            self.stress_res_max_comparison.setValues(ipsData['maxStress'], resCont.getResult('tStressLimit'))

        
        else:

            #wyczyszczenie            
            self.stress_res_max_generalInfo.clear()
            self.stress_res_max_comparison.clear()

    #
    def getSize(self):
        return (525, 520)
    
       
class StressAnalyzerDlg_multiPoint(dnComponentDlg.ComponentContextMultiPointBeamDlg):
    def __init__(self, parent, compObj, **kw):

        #klasa nadrzdna
        dnComponentDlg.ComponentContextMultiPointBeamDlg.__init__(self, parent, compObj, **kw)

        #rejestracja zakladek
        self.registerTab('data',
                         image=self._createImage('tab_data_icon'),
                         createFunc=self.createDataTab,
                         updateFun=self.updateDataTab,
                         tabType=dnConstants.TAB_TYPE_GENERAL_DATA,
                         displayName=u'Ustawienia ogranicze',
                         noUserCheckComment=u'Zweryfikuj parametry wymiarowania',
                         )
        self.registerLoadCombTab()
        self.registerTab('compression', image=self._createImage('tab_comp_icon'),
                         createFunc=self.createCompTab,
                         updateFun=self.updateCompTab,
                         subjectId=COMPRESSION,
                         tabType=dnConstants.TAB_TYPE_RESULT_IN_POINT,
                         displayName=COMPRESSION,
                         references=['tension', #'separator',
                                     ],#referencja do zakadek z innymi wynikami
                         )
        self.registerTab('tension', image=self._createImage('tab_tension_icon'),
                         createFunc=self.createTensionTab,
                         updateFun=self.updateTensionTab,
                         subjectId=TENSION,
                         tabType=dnConstants.TAB_TYPE_RESULT_IN_POINT,
                         displayName=TENSION,
                         references=['compression',
                                     ],#referencja do zakadek z innymi wynikami
                         )
        self.registerStdResultTab()

        #dodanie listy z rzednymi i typami wynikow
        self.registerTypeChooser()

        #rejestracja widoku przekroju
        self.registerSectionView(activeSectionEdges=False)                
        self.registerGeneralSectionViewTab()

        #rejestracja dodatkowych przyciskow
        self.registerOrdinateButton()
        self.registerSizingPointsButton()
        self.registerRaportGeneratorButton()
        self.registerDefaultPointsNumberControl()
        
        #budowa okna
        self.build()

        
    def setVars(self):


        #dodanie zmiennych      
        self._addVar('tensionLimit', type='DoubleVar')
        self._addVar('compressionLimit', type='DoubleVar')
        
        #zmienne dialogowa, s zapamitywane ale ich zmiana nie powoduje przeliczenia wynikw
        self._addVar('defaultTensionLimit', type='IntVar', dlgVar=True)
        self._addVar('defaultCompressionLimit', type='IntVar', dlgVar=True)

        
    #
    def createDataTab(self, tab):

        #utworzenie ramki
        f=soLabelFrame(tab, text=COMPRESSION, padding=5)
        f.pack(padx=5, pady=5, fill=X)
        f.columnconfigure(0, weight=1)

        #dodanie opisu
        l=soLabel(f, text=u'Warto dopuszczalna:')
        l.grid(row=3, column=0, columnspan=1, sticky=E+W)

        #dodanie ramki
        stressLimitLF=soFrame(f)
        stressLimitLF.grid(row=4, column=0, columnspan=1, sticky=E+W)

        #dodanie obslugi limitu naprezen
        def updateCompressionLimitCtrl():
            compressionLimitCon['state']=[NORMAL, DISABLED][self.var_defaultCompressionLimit.get()]
        def onDefaultCompressionLimit():
            if self.var_defaultCompressionLimit.get():
                stressLimit=self.getCompObj().getItem().getComplexProfile().getPrincipalMaterial().get_fc()
                self.var_compressionLimit.set(stressLimit)
            updateCompressionLimitCtrl()
            
        defaultCompressionLimitChB=soCheckbutton(stressLimitLF,
                                                    variable=self.var_defaultCompressionLimit,
                                                    command=onDefaultCompressionLimit,
                                                    text=trans(u'Domylny limit dla napre ciskajcych')
                                                    )
        defaultCompressionLimitChB.pack()

        #dodanie obslugi limitu naprezen
        def _checkIfFloat(x):
            #check if float            
            try:
                float(x)
                return True
            except:
                return False     

        def limitValidate(x):
            if not _checkIfFloat(x):
                x=1.0
            if float(x)>10e9:
                x=10e6
            if float(x)<0.1:
                x=0.1
            return x

        compressionLimitCon = soControl(stressLimitLF,
                                    label=trans(u'Max. naprenia ciskajce: '),
                                    variable=self.var_compressionLimit,
                                    step=1.0,
                                    allowempty=False,
                                    validatecmd=limitValidate)
        compressionLimitCon.entry['width']=12
        compressionLimitCon['selectmode']='normal'
        compressionLimitCon.pack()

        ####################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=TENSION, padding=[5,5,5,5])
        f.pack(padx=5, pady=5, fill=X)
        f.columnconfigure(0, weight=1)



        #dodanie opisu
        l=soLabel(f, text=u'Warto dopuszczalna:')
        l.grid(row=3, column=0, columnspan=1, sticky=E+W)
        
        #dodanie ramki
        stressLimitLF=soFrame(f)
        stressLimitLF.grid(row=4, column=0, columnspan=1, sticky=E+W)

        #dodanie obslugi limitu
        def updateTensionLimitCtrl():
            tensionLimitCon['state']=[NORMAL, DISABLED][self.var_defaultTensionLimit.get()]
        def onDefaultTensionLimit():
            if self.var_defaultTensionLimit.get():
                stressLimit=self.getCompObj().getItem().getComplexProfile().getPrincipalMaterial().get_ft()
                self.var_tensionLimit.set(stressLimit)
            updateTensionLimitCtrl()
                
        defaultTensionLimitChB=soCheckbutton(stressLimitLF,
                                                variable=self.var_defaultTensionLimit,
                                                command=onDefaultTensionLimit,
                                                text=trans(u'Domylny limit dla napre rozcigajcych')
                                                )
        defaultTensionLimitChB.pack()


        #dodanie obslugi limitu
        tensionLimitCon = soControl(stressLimitLF,
                                    label=trans(u'Max. naprenia rozcigajce: '),
                                    variable=self.var_tensionLimit,
                                    step=1.0,
                                    allowempty=False,
                                    validatecmd=limitValidate)
        tensionLimitCon['selectmode']='normal'
        tensionLimitCon.entry['width']=12
        tensionLimitCon.pack()


        #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
        self.addUpdateTabFunctions('data', updateFunc=[updateCompressionLimitCtrl,
                                                       updateTensionLimitCtrl,
                                                          ])

    def createCompTab(self, tab):

        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=COMPRESSION, padding=5)
        f.pack(padx=5, pady=5, fill=X)
        f.columnconfigure(0, weight=1)

        #dodanie podstawowych informacji o wynikach        
        self.stress_res_min_generalInfo=dnComponentDlg.GeneralInfo(f)
        self.stress_res_min_generalInfo.grid(row=1, column=0, columnspan=1, sticky=W)

        #dodanie separatora
        l=soSeparator(f, orient='horizontal')
        l.grid(row=2, column=0, sticky=W+E, pady=2)

        #dodanie opisu
        l=soLabel(f, text=u'Warto dopuszczalna:')
        l.grid(row=3, column=0, columnspan=1, sticky=E+W)

        #dodanie ramki
        stressLimitLF=soFrame(f)
        stressLimitLF.grid(row=4, column=0, columnspan=1, sticky=E+W)

        #dodanie obslugi limitu naprezen
        def updateCompressionLimitCtrl():
            compressionLimitCon['state']=[NORMAL, DISABLED][self.var_defaultCompressionLimit.get()]
        def onDefaultCompressionLimit():
            if self.var_defaultCompressionLimit.get():
                stressLimit=self.getCompObj().getItem().getComplexProfile().getPrincipalMaterial().get_fc()
                self.var_compressionLimit.set(stressLimit)
            updateCompressionLimitCtrl()
            
        defaultCompressionLimitChB=soCheckbutton(stressLimitLF,
                                                    variable=self.var_defaultCompressionLimit,
                                                    command=onDefaultCompressionLimit,
                                                    text=trans(u'Domylny limit dla napre ciskajcych')
                                                    )
        defaultCompressionLimitChB.pack()

        #dodanie obslugi limitu naprezen
        def _checkIfFloat(x):
            #check if float            
            try:
                float(x)
                return True
            except:
                return False     

        def limitValidate(x):
            if not _checkIfFloat(x):
                x=1.0
            if float(x)>10e9:
                x=10e6
            if float(x)<0.1:
                x=0.1
            return x

        compressionLimitCon = soControl(stressLimitLF,
                                    label=trans(u'Max. naprenia ciskajce: '),
                                    variable=self.var_compressionLimit,
                                    step=1.0,
                                    allowempty=False,
                                    validatecmd=limitValidate)
        compressionLimitCon.entry['width']=12
        compressionLimitCon['selectmode']='normal'
        compressionLimitCon.pack()

        #dummy
        l=soFrame(f,)
        l.grid(row=5, column=0, pady=7)

        #dodanie opisu
        l=soLabel(f, text=u'Sprawdzenie warunku projektowego:')
        l.grid(row=6, column=0, columnspan=1, sticky=E+W)


        #dodanie wizualizacji warunku projektowego
        self.stress_res_min_comparison=dnComponentDlg.Comparison(f,
                                                      lImage=self._createImage('res_sigmaMin'),
                                                      rImage=self._createImage('res_sigmaMinLimit'),
                                                      lFormat='%.2f', rFormat='%.2f')
        self.stress_res_min_comparison.grid(row=7, column=0, columnspan=1, sticky=E+W)

        #dummy
        l=soFrame(f,)
        l.grid(row=8, column=0, pady=7)


        #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
        self.addUpdateTabFunctions('compression', updateFunc=[updateCompressionLimitCtrl,
                                                          ])
        

    def createTensionTab(self, tab):

        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text=TENSION, padding=[5,5,5,5])
        f.pack(padx=5, pady=5, fill=X)
        f.columnconfigure(0, weight=1)

        #dodanie podstawowych informacji o wynikach        
        self.stress_res_max_generalInfo=dnComponentDlg.GeneralInfo(f)
        self.stress_res_max_generalInfo.grid(row=1, column=0, columnspan=1, sticky=W)
        
        #dodanie separatora
        l=soSeparator(f, orient='horizontal')
        l.grid(row=2, column=0, sticky=W+E, pady=2)

        #dodanie opisu
        l=soLabel(f, text=u'Warto dopuszczalna:')
        l.grid(row=3, column=0, columnspan=1, sticky=E+W)
        
        #dodanie ramki
        stressLimitLF=soFrame(f)
        stressLimitLF.grid(row=4, column=0, columnspan=1, sticky=E+W)

        #dodanie obslugi limitu
        def updateTensionLimitCtrl():
            tensionLimitCon['state']=[NORMAL, DISABLED][self.var_defaultTensionLimit.get()]
        def onDefaultTensionLimit():
            if self.var_defaultTensionLimit.get():
                stressLimit=self.getCompObj().getItem().getComplexProfile().getPrincipalMaterial().get_ft()
                self.var_tensionLimit.set(stressLimit)
            updateTensionLimitCtrl()
                
        defaultTensionLimitChB=soCheckbutton(stressLimitLF,
                                                variable=self.var_defaultTensionLimit,
                                                command=onDefaultTensionLimit,
                                                text=trans(u'Domylny limit dla napre rozcigajcych')
                                                )
        defaultTensionLimitChB.pack()

        #dodanie obslugi limitu
        #dodanie obslugi limitu naprezen
        def _checkIfFloat(x):
            #check if float            
            try:
                float(x)
                return True
            except:
                return False     

        def limitValidate(x):
            if not _checkIfFloat(x):
                x=1.0
            if float(x)>10e9:
                x=10e6
            if float(x)<0.1:
                x=0.1
            return x

        #dodanie obslugi limitu
        tensionLimitCon = soControl(stressLimitLF,
                                    label=trans(u'Max. naprenia rozcigajce: '),
                                    variable=self.var_tensionLimit,
                                    step=1.0,
                                    allowempty=False,
                                    validatecmd=limitValidate)
        tensionLimitCon['selectmode']='normal'
        tensionLimitCon.entry['width']=12
        tensionLimitCon.pack()

        #dummy
        l=soFrame(f)
        l.grid(row=5, column=0, pady=7)

        #dodanie opisu
        l=soLabel(f, text=u'Sprawdzenie warunku projektowego:')
        l.grid(row=6, column=0, columnspan=1, sticky=E+W)
        
        #dodanie warunku projektowego
        self.stress_res_max_comparison=dnComponentDlg.Comparison(f,
                                                      lImage=self._createImage('res_sigmaMax'),
                                                      rImage=self._createImage('res_sigmaMaxLimit'),
                                                      lFormat='%.2f', rFormat='%.2f')
        self.stress_res_max_comparison.grid(row=7, column=0, columnspan=1, sticky=E+W)


        #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
        self.addUpdateTabFunctions('tension', updateFunc=[updateTensionLimitCtrl,
                                                          ])
        
    #
    def updateDataTab(self):
        pass
    def updateCompTab(self, ipsData):

        #pobranie wynikw
        resCont=self.getCompObj().getResults()

        #ipsData to slownik ze szczegolowymi informacjami zapisanymi w czasie wymiarowania
        if ipsData!=None and ipsData['calculated']:

            #wyswietlenie wartosci
            self.stress_res_min_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci dla warunkow projektowych
            self.stress_res_min_comparison.setValues(fabs(ipsData['minStress']), resCont.getResult('cStressLimit'))

        
        else:

            #wyczyszczenie            
            self.stress_res_min_generalInfo.clear()
            self.stress_res_min_comparison.clear()



    def updateTensionTab(self, ipsData):
        
        #pobranie wynikw
        resCont=self.getCompObj().getResults()

        #ipsData to slownik ze szczegolowymi informacjami zapisanymi w czasie wymiarowania
        if ipsData!=None and ipsData['calculated']:


            #wyswietlenie wartosci
            self.stress_res_max_generalInfo.setValuesByResultObj(ipsData)

            #wyswietlenie wartosci dla warunkow projektowych
            self.stress_res_max_comparison.setValues(ipsData['maxStress'], resCont.getResult('tStressLimit'))

        
        else:

            #wyczyszczenie            
            self.stress_res_max_generalInfo.clear()
            self.stress_res_max_comparison.clear()


    #
    def getSize(self):
        return (0.85, 0.85)
    
class StressAnalyzer(dnComponent.BeamComponent):
    type=dnConstants.COMP_STRESS_ANALYZER
    #name=trans(u'Analiza napre')
    name=trans(u'Dopuszczalne naprenia')
    description=trans(u'Analiza napre dopuszczalnych dla elementu prtowego')
    dirPath=os.path.join(dnConstants.LIB_DIR_PATH, 'components/beam/stressAnalyzer')
    iconPath=os.path.join(dnConstants.LIB_DIR_PATH, 'components/beam/stressAnalyzer/img/icon.gif')
    summarySubjects=[
            TENSION,
            COMPRESSION,
                         ]
    def __init__(self, parent, itemId):

        #klasa nadrzedna
        dnComponent.BeamComponent.__init__(self, parent, itemId)

        #definicja minimalnej liczby rzdnych do wymiarowania (rozstaw rwnomierny)
        self.setDefaultPointsNumber(5, update=False)

    def setDefault(self):

        #metoda obiektu nadrzednego
        dnComponent.BeamComponent.setDefault(self)

        #pobierz limit naprezen dla materialu
        matObj=self.getItem().getComplexProfile().getPrincipalMaterial()
        tStressLimit=matObj.get_ft()
        cStressLimit=matObj.get_fc()

        #zmienne projektowe
        self.defaultTensionLimit=True
        self.defaultCompressionLimit=True
        
        self.tensionLimit=tStressLimit
        self.compressionLimit=cStressLimit

        
    #
    def _calcExtremalStresses(self):

        #pobarnie obiektu zarzadzajacego wynikami dla elementu
        resultsObj=self.getItem().getResults().getStatResults()

        #obliczenie sil przekrojowych dla elementu dla rznych kombinacji obciazenia
        sf={}
        for sfType in [3,4]:#petla  naprezenia gora/dol

            #dodanie klucza do slownika
            sf[sfType]={}

            for envType in [sdConstants.ENVELOPE_TYPE_MIN, sdConstants.ENVELOPE_TYPE_MAX]: #petla  typ obwiedni

                    # obliczenie sil przekrojowych dla kombinacji
                    sfRes=resultsObj.getSectionForcesForElement(
                                                loadCombination=self.loadCombination,
                                                leadingValue=sfType,
                                                envelopeType=envType,
                                                laodCombinationType=self.loadCombinationType,
                                                
                                                userPoints=self.getPoints(), 
                                                ) 

                    #dodanie sil do slownika
                    sf[sfType][envType]= sfRes 

        #przypisanie slownika z silami przekrojowymi do zmiennej klasy
        self._extremalStresses=sf
        self.res_minTopStress=sf[3][sdConstants.ENVELOPE_TYPE_MIN]
        self.res_maxTopStress=sf[3][sdConstants.ENVELOPE_TYPE_MAX]
        self.res_minBottomStress=sf[4][sdConstants.ENVELOPE_TYPE_MIN]
        self.res_maxBottomStress=sf[4][sdConstants.ENVELOPE_TYPE_MAX]

    #
    def _calcStressRatio(self, minStress, maxStress):
    
        #pobierz limit dla naprezen
        tStressLimit=self.tensionLimit
        cStressLimit=self.compressionLimit

        #obliczenia dla naprezen sciskajacych
        if fabs(minStress) < 1e-6:
            compressionStressRatio=0.
        elif minStress > 0.:#brak sciskania
            compressionStressRatio=0.
        else:
            compressionStressRatio=fabs(minStress)/cStressLimit
                
        #obliczenia dla naprezen rozciagajacych     
        if fabs(maxStress) < 1e-6:
            tensionStressRatio=0.
        elif maxStress < 0.:#brak rozciagania
            tensionStressRatio=0.
        else:
            tensionStressRatio=maxStress/tStressLimit

        #set results        
        self.getResults().setResults({
            'cStressLimit':cStressLimit,
            'tStressLimit':tStressLimit,            
            })

        #get extremal max ratio
        stressRatio=max(compressionStressRatio, tensionStressRatio)       

        return compressionStressRatio, tensionStressRatio, stressRatio

    def doCustomCheck(self):

        return True
    
    def doBeforeCalculate(self):

        if not dnComponent.BeamComponent.doBeforeCalculate(self):
            return False
        
        return True

    def doCalculate(self, soft=False):

        #przelicz jezeli konieczne
        if not soft:
            self._calcExtremalStresses()

        #################################
        ###  DANE WEJSCIOWE
        #################################

        #W TYM PRZYKLADZIE POTRZEBNE SA TYLKO NAPREZENIA

        #################################
        ###  OBLICZENIA
        #################################

        #obliczenia elementu dla poszczeglnych kombinacji i rzednych
        for sfType, sfData in self._extremalStresses.items():#petla  sily przekrojowe
            for envType, envData in sfData.items(): #petla  typ obwiedni
            
                #pobranie wynikw dla charakterystycznych puntkw/rzednych
                sfVals=envData.getForCharPoints() # szczegly: SOLDIS_reference

                for i in range(0, len(sfVals[0][0])):

                    #pobranie rzednej
                    ord = sfVals[0][0][i]
                    lcType='%s %s'%(['min', 'max'][[sdConstants.ENVELOPE_TYPE_MIN, sdConstants.ENVELOPE_TYPE_MAX].index(envType)], ['Sg', 'Sd'][sfType-3])               

                    #pobranie sil przekrojowych w plaszczyznie uklad
                    #N = sfVals[0][1][i]
                    #Ty = sfVals[1][1][i]
                    #Mx = sfVals[2][1][i]
                    Sg = sfVals[3][1][i]
                    Sd = sfVals[4][1][i]                    
                    Sg_combLoadGroups = sfVals[3][2][i] # pobranie grup obc.; szczegly: SOLDIS_reference
                    Sd_combLoadGroups = sfVals[4][2][i] # pobranie grup obc.; szczegly: SOLDIS_reference
                    
                    #pobranie obiektu przechowujacego wyniki w punkcie
                    iprContObj=self.getResults().getInPointResults()

                    #dodanie wynikw dla rzednej; jezeli istnieja to zamiast tworzyc nowy obiekt, metoda add zwrci obiekt juz istniejacy
                    iprObj=iprContObj.add(ord)

                    #obliczenie warunkow projektowych
                    
                    ####################################
                    ### NAPREZENIA NA GORZE PRZEKROJU
                    ####################################

                    minStress = min(Sg, Sd)
                    minStress_combLoadGroups = [Sg_combLoadGroups, Sd_combLoadGroups][Sd_combLoadGroups < Sg_combLoadGroups]
                    maxStress = max(Sg, Sd)
                    maxStress_combLoadGroups = [Sg_combLoadGroups, Sd_combLoadGroups][Sd_combLoadGroups > Sg_combLoadGroups]

                    #oblicz wytezenie elementu
                    compRatio, tensionRatio, ratio = self._calcStressRatio(minStress, maxStress)

                    #dodanie wynikw
                    iprObj.addData(lcType, COMPRESSION, {
                                    'minStress':minStress,
                                    'ratio':compRatio,
                                    'calculated':True,
                                    },
                                   loadGroups=minStress_combLoadGroups
                                   )
                    iprObj.addData(lcType, TENSION, {
                                    'maxStress':maxStress,
                                    'ratio':tensionRatio,
                                    'calculated':True,
                                    },
                                   loadGroups=minStress_combLoadGroups
                                   )

            
        ####################################
        ### DODANIE WYNIKOW OGOLNYCH
        ####################################

        #przypisz wyniki
        self.getResults().setResults({
            'minStress':minStress,
            'maxStress':maxStress,  
            })
        
        #################################
        ###  OKRESLENIE WYTEZENIA ELEMENTU
        #################################

        #pobierz wytezenie
        ripObj=self.getResults().getInPointResults()
        maxRatio, maxRatios = ripObj.getMaxRatio(return_all=True)

        #przypisz wytezenie dla poszczegolnych warunkow projektowych
        self.getResults().setSummary( [[h, maxRatios[h]] for h in self.summarySubjects] )        

        #################################
        ###  DODANIE KOMENTARZA
        #################################

        #dodaj komentarz
        if self.getResults().getUseRatio() > 1.:
            self.getMessageManager().addMessage(u'!!!Nono elementu przekroczona!!!.', type=dnComponent.MSG_TYPE_ERROR)
        else:
            self.getMessageManager().addMessage(u'Element zaprojektowany poprawnie.', type=dnComponent.MSG_TYPE_IMPORTANT)
 
        return True
    #
    def insertRTFReport(self, docObj, sectionObj):

        #utworz kontroler
        rtfReportMethod=sdRTFReport.RTFRaport_MethodsObj(self, docObj, sectionObj)

        #wciecie
        indent=3*' '
        
        ##DANE OGOLNE
        self.insertRTFReport_ComponentHeader(rtfReportMethod)

        ##DANE OGOLNE    
        self.insertRTFReport_ElementInfo(rtfReportMethod)
  
  
        ##DANE PROJEKTOWE
        rtfReportMethod.insertTitle(trans('Dane projektowe'))

        profileObj=self.getItem().getComplexProfile()
        matObj=profileObj.getPrincipalMaterial()
        t='%s (%s, %sMPa)'%(trans('Domylny limit dla napre rozcigajcych'), matObj.getName(), matObj.get_ft())
        rtfReportMethod.insertText(t+': '+[trans('Nie'), trans('Tak')][self.defaultTensionLimit])
        if not self.defaultTensionLimit:
            rtfReportMethod.insertText(indent+trans('Max. naprenia rozcigajce: ')+'%.2f'%self.tensionLimit+'MPa')
            
        t='%s (%s, %sMPa)'%(trans('Domylny limit dla napre ciskajcych'), matObj.getName(), matObj.get_fc())
        rtfReportMethod.insertText(t+': '+[trans('Nie'), trans('Tak')][self.defaultCompressionLimit])
        if not self.defaultCompressionLimit:
            rtfReportMethod.insertText(indent+trans('Max. naprenia ciskajce: ')+'%.2f'%self.compressionLimit+'MPa')
            
        rtfReportMethod.insertText(trans('Kombinacja obcienia')+': '+[trans('Nie'), trans('Tak')][self.loadCombination])
        if self.loadCombination:
            loadCombDescr=self._getStatResultManager().getConfigurationText(
                                         loadCombination=self.loadCombination,
                                         loadCombinationType=self.loadCombinationType,
                                         #obliqueValues=self.obliqueValues,
                                         #permamentValues=self.permamentValues,                            
                                         )
            rtfReportMethod.insertText(indent+trans('Typ kombinacji')+': '+loadCombDescr.encode('cp1250'))
        
        ##        
        ##WYNIKI
        ##

        rtfReportMethod.insertTitle(trans('Wyniki dla elementu'))

        rtfReportMethod.insertText('Wykres napre')
        #dodanie rysunku modelu (lub jego fragmentu)
        graphTools=rtfReportMethod.insertGraph()
        graphTools.initilize(filtr=sdSchemeImageMaker.ELEMENTS, items=[self.getItem().getGraphId(), ])
        graphTools.drawNodes()
        graphTools.drawElements()
        graphTools.drawBoundaryConditions()
        #graphTools.drawLoads()
        #graphTools.drawReactions(loadCombination=True, 	leadingValue=None, 	loadCombinationType=sdConstants.LOAD_COMB_TYPE_USL_BASIC,)
        graphTools.drawSectionForces(loadCombination=self.loadCombination,
                                     leadingValue=34,
                                     loadCombinationType=self.loadCombinationType,
                                     log=False)
        #graphTools.drawDisplacement(loadCombination=True, 	leadingValue=None, 	loadCombinationType=sdConstants.LOAD_COMB_TYPE_USL_BASIC, log=False)
        graphTools.draw() 

        #wstaw opis
        loadCombDescr=self._getStatResultManager().getConfigurationText(
                                     loadCombination=self.loadCombination,
                                     loadCombinationType=self.loadCombinationType,                          
                                     )
        rtfReportMethod.insertText(loadCombDescr.encode('cp1250'))

        
        ##
        ## WYTEZENIE
        ##
        
        self.insertRTFReport_EffortRatios(rtfReportMethod)

        ##
        ## WYNIKI DLA PUKTOW
        ##

        self.insertRTFReport_ResultInPoints(rtfReportMethod)

    #
    def drawIcon_OFF(self, canvas, x, y):

        #rysuj symbol
        iconId=canvas.create_text(x, y,
                                              text='s',
                                              fill='blue',
                                              #anchor=W,
                                              activefill='red',
                                              font=('symbol', 13, 'bold'),
                                              )
        return iconId
    
    #
    def getDlgClass(self):
        return StressAnalyzerDlg_multiPoint
    
    def getAvailableDlgClasses(self):
        return [['klasyczny', StressAnalyzerDlg_classic], ['ulepszony', StressAnalyzerDlg_multiPoint]]