# -*- coding: cp1250 -*-

"""
plik: myComp.py
autor: Krzysztof Szajek (biuro@soldis.com.pl)

Przykad reguy wymiarowania analizujcej spoin blachownicy.

Modu stanowi integraln cz progrmau Soldis PROJEKTANT. Zabrania si rozpowszechniania fragmentw lub caoci poniszego kodu bez zgody AUTORA. Szczegowe warunki licencji - patrz: licencja/licence.txt w katalogu instalacyjnym programu.
"""


#general
from dnBaseLib import *

#python modules
import os
import types

#solsec modules
import ssConstants

#design modules
import dnConstants
import dnComponent
import dnComponentDlg

#soldis
import sdConstants
import sdRTFReport
import sdSchemeImageMaker

#soldis env
import soSymbols

#add
import PyRTF

#constants
CONDITION_1='Warunek 1'
CONDITION_2='Warunek 2'

        
class MyComponentDlg(dnComponentDlg.ComponentContextBeamDlg):
    controlWidth=12
    def __init__(self, parent, compObj, **kw):

        #klasa na
        dnComponentDlg.ComponentContextBeamDlg.__init__(self, parent, compObj, **kw)

        #rejestracja zakladek
        self.registerTab('general',
                         image=self._createImage('tab_inputDataIcon'),
                         createFunc=self.createGeneralTab,
                         updateFun=self.updateGeneralTab,
                         subjectId=CONDITION_1)
        self.registerTab('addWidgets',
                         image=self._createImage('tab_generalResultsIcon'),
                         createFunc=self.createAddTab,
                         updateFun=self.updateAddTab,
                         subjectId=CONDITION_2)

        #rejestracaj przyciskow      
        #self.registerOrdinateButton()
        self.registerNextPrevButtons()
        
        #buduj okno
        self.build()

        
    def setVars(self):

        #dodanie zmiennych projektowych       
        self.addVar('weldThickness', type='DoubleVar')

        #przykladowe zmienne projektowe
        self.addVar('radioValue', type='IntVar')
        self.addVar('checkValue', type='IntVar')
        self.addVar('controlValue', type='DoubleVar')
        self.addVar('controlValue1', type='DoubleVar')
        self.addVar('comboValue', type='StringVar')
        self.addVar('entryValue', type='StringVar')
        self.addVar('scaleValue', type='DoubleVar')

        #dodanie zmiennej dialogowej - nie jest zmienna projektowa ale pomaga w obsludze okna dialogowego
        self.addVar('dlgValue', type='IntVar', dlgVar=True, value=0)
        

    #create
    def createGeneralTab(self, tab):

        ######################
    
        #dodaj ramke
        statDF=soFrame(tab)
        statDF.pack(padx=5, pady=5)

        #dodaj opis
        l=soLabel(statDF, text=u'Grubo spoiny:')
        l.grid(row=2, column=0, columnspan=1, sticky=W)

        #dodaj kontroler grubosci spoiny
        def aValidate(x):

            #check if float
            try:
                float(x)
            except:
                return 5.

            #check range
            if float(x)<2.:
                x=2.

            if float(x)>16.:
                x=16.
            
            return x
        
        self.weldThicknessCon = soControl(statDF,
                                          label='a [mm]: ',
                                          selectmode='normal',
                                          width=8,
                                          variable=self.var_weldThickness,
                                          step=.1,
                                          allowempty=False,
                                          validatecmd=aValidate)
        self.weldThicknessCon.grid(row=3, column=0, columnspan=1, sticky=E)

        ######################

        #dodanie ramki
        spacer=soFrame(tab)
        spacer.pack(padx=5, pady=2)

        #dodanie ramki
        statDF=soFrame(tab)
        statDF.pack(padx=5, pady=2)

        #dodanie opisu
        l=soLabel(statDF, text=u'Przykadowy rysunek')
        l.pack(padx=5, pady=0)

        #dodanie rysunku
        l=soLabel(statDF, image=self._createImage('I_Beam'))
        l.pack()

        ######################

        #dodanie ramki
        spacer=soFrame(tab)
        spacer.pack(padx=5, pady=3)

        #dodanie ramki (ukrywanej)
        #self.resultLF=dnComponentDlg.ResultLabelFrame(tab, text='Wyniki')
        #self.resultLF.pack(padx=5, pady=5)

        #dodanie ramki (klasycznej)
        statDF=soFrame(tab)
        statDF.pack(padx=5, pady=5)

        #dodanie opisu
        l=soLabel(statDF, text=u'Wyniki porednie oblicze:')
        l.grid(row=0, column=0, columnspan=2, padx=5, sticky=W)

        #dodanie wynikow
        self.res_S=dnComponentDlg.ResultValue(statDF, lLabel='S = ', rLabel=' [cm3]', format='%.2f')
        self.res_S.grid(row=1, column=0, padx=5, sticky=E)

        self.res_extQ=dnComponentDlg.ResultValue(statDF, lLabel='ext Q = ', rLabel=' [kN]', format='%.2f')
        self.res_extQ.grid(row=2, column=0, padx=5, sticky=E)

        def getLoadGroups_extQ():
            rObj=self.getCompObj().getResults()
            return rObj.getResult('extQ_combLoadGroups')
            
        res_extQ_combLoadGroups = self.insertCombLoadGroupsInfo(statDF, getLoadGroupsFun=getLoadGroups_extQ)
        res_extQ_combLoadGroups.grid(row=2, column=1, padx=5, sticky=E)


        self.res_tau_II=dnComponentDlg.ResultValue(statDF, lLabel='%s II = '%soSymbols.greek['tau'], rLabel=' [kN/cm2]', format='%.2f')
        self.res_tau_II.grid(row=3, column=0, padx=5, sticky=E)

        self.res_maxTau_II=dnComponentDlg.ResultValue(statDF, lLabel='max %s II = '%soSymbols.greek['tau'], rLabel=' [kN/cm2]', format='%.2f')
        self.res_maxTau_II.grid(row=4, column=0, padx=5, sticky=E)
        

        ######################

        #dodanie ramki (ukrywanej)
        #self.compResF=dnComponentDlg.ResultFrame(tab)
        #self.compResF.pack(padx=5, pady=10)
        #statDF=self.compResF.getFrame()

        #dodanie ramki (klasycznej)
        statDF=soFrame(tab)
        statDF.pack(padx=5, pady=10)

        #dodanie opisu
        l=soLabel(statDF, text=u'Nono spoiny:')
        l.grid(row=0, column=0, columnspan=1, sticky=W)

        #dodanie warunku projektowego
        self.res_comparison=dnComponentDlg.Comparison(statDF,
                                                      lImage=self._createImage('comparison_1'),
                                                      rImage=self._createImage('comparison_2'),
                                                      lFormat='%.2f', rFormat='%.1f')
        self.res_comparison.grid(row=1, column=0, columnspan=1, sticky=E+W)
        
        ######################
        #przyklad z oknem popup oraz z trescia w pasku statusu
        self.addBalloon(self.res_S, popupMsg=u'Moment statyczny pki [cm3]', statusMsg=u'Tre dodatkowa pojawiajca si w pasku u dou okna')
        #przyklad tylko z oknem popup
        self.addBalloon(self.res_extQ, popupMsg=u'Moment statyczny 	pki [cm3]', statusMsg=None)
        #przyklad tylko z wiadomoscia w pasku statusu
        self.addBalloon(self.res_maxTau_II, popupMsg=None, 	statusMsg=u'Maksymalne, dopuszczalne naprenia w spoinie [kN/cm2]')
              

    def createAddTab(self, tab):


        ###################### NoteBook

        nb=soNoteBook(tab)
        nb.pack(fill=BOTH, expand=True)


        #utworzenie zakadek
        frame1=soFrame(nb)
        nb.add(frame1, text=u'Zakadka 1', )
        frame2=soFrame(nb)
        nb.add(frame2, text=u'Zakadka 2', )
        
        ###################### LABEL        
    
        #utworzenie ramki
        labelF=soLabelFrame(frame1, text='soLabel', padding=3)
        labelF.pack(padx=5, pady=5, fill=X)

        #wstawienie opisu
        l=soLabel(labelF, text=u'Przykadowy tekst')
        l.pack()

        ###################### ENTRY        
    
        #wstawienie ramki
        entryF=soLabelFrame(frame1, text='soEntry', padding=3)
        entryF.pack(padx=5, pady=5, fill=X)

        #wstawienie pola tekstowego
        l=soEntry(entryF, textvariable=self.var_entryValue)
        l.pack()

        ###################### CONTROL  

        #wstawienie ramki
        controlF=soLabelFrame(frame1, text='soControl', padding=3)
        controlF.pack(padx=5, pady=5, fill=X)

        #wstawienie kontrolera liczb calkowitych i zmiennoprzecinkowych
        def aValidate(x):

            #check if float
            try:
                x=float(x)
            except:
                return 5.#np warto domylna

            if x<2.:
                x=2.
            
            return x
        
        control = soControl(controlF,
                                    label='a [mm]: ',
                                    variable=self.var_controlValue,
                                    step=.1,
                                    width=8,
                                    allowempty=False,
                                    selectmode='normal',
                                    validatecmd=aValidate
                                  )
        control['selectmode']='normal'
        control.pack(side=LEFT)


        def converter(x):#przykladowy konwerter
            if x>4 and x<5:
                x=4.5
            return x
        
        def getMin():#przykladowa funkcja do pobierania wartosci minimalnej
            return self.var_controlValue.get()

        def onValChange(value):#przykadowa funkcja wywoywana przy zmianie wartoci
            print value
            
        control2 = soControl(controlF,
                                    label=u'a (min max) [mm]: ',
                                    variable=self.var_controlValue1,
                                    step=.1,
                                    allowempty=False,
                                    validatecmd=aValidate,
                                    command=onValChange,
                                    selectmode='normal',

                                     #soControl posiada argumenty jak obiekt Tix.Control oraz kilka dodatkowych umieszczonych poniej
                                     width=8,
                             
                                     converter=converter,
                                     round=2,#zaokraglenie - liczba miejsc po przecinku
                                     min=getMin,#warto minimalna - moe by rowni podana jako funkcja
                                     max=30.,

                                     scaleorient='horizontal',#,'vertical'
                                     showscale=True,#jeeli True i podane s min i max to wywietlany jest suwak
                                     sliderselectmode="immediate",#"normal"#jeeli "immediate" to command wywolywana jest natychniast przy ruchu suwaka, w przeciwnym wypadku dopiero po zwolnieniu przycisku myszy
                                     sliderpoints=None,#jeeli zostanie podana lista wartoci to suwak jest do nich przycigany z tolerancj 'slidercatchtolerance'
                                     sliderdivisions=None,#jeeli zostanie podana liczba dodatnia cakowita to w zakresie od min do max zostan automatycznie utworzone punkty znaczce (do ktrych suwak bdzie przycigany) bdce granic midzy sekcjami o takiej samej dugoci
                                     slidercatchtolerance=0.025,#tolerancja przy przyciganiu podana jako cz uamkowa zakresu


                                  )
        control2.pack()
        

        ###################### CHECKBUTTON

        #create frame
        checkF=soLabelFrame(frame1, text='soCheckbutton', padding=3)
        checkF.pack(padx=5, pady=5, fill=X)

        #insert label
        chLabel=soLabel(checkF, text=' - ')
        chLabel.pack()

        #insert radiobutton
        def onCheckChange():

            #pobierz aktualna wartosc
            val=self.var_checkValue.get()

            #zmien opis
            if val:
                chLabel['text']='Opcja 1 aktywna'
            else:
                chLabel['text']='Opcja 1 nieaktywna'
            
        self.myChB=soCheckbutton(checkF, text='Opcja 1', variable=self.var_checkValue, command=onCheckChange)
        self.myChB.pack()

        ###################### COMBOBOX

        #wstawienie ramki
        comboF=soLabelFrame(frame1, text='soComboBox', padding=3)
        comboF.pack(padx=5, pady=5, fill=X)

        #wstawienie opisu
        cLabel=soLabel(comboF, text=' >> nic nie wybrano << ')
        cLabel.pack()

        def onCBChange(value):

            #pokaz wybor
            cLabel['text']='Wybrano: '+value
            
        ######
        f=soFrame(comboF)
        f.pack()
        
        l=soLabel(f, text=u'Wybierz: ')
        l.pack(side=LEFT)
        
        myCB=soComboBox(f, state='readonly', width=10, values=['Opcja 1', 'Opcja 2', 'Opcja 3'], textvariable=self.var_comboValue ) 
        myCB.pack(side=RIGHT)
        myCB.setOnSelectCommand(onCBChange)

        ###################### CHECKBUTTON dla zmiennej dialogowej

        #utworzenie ramki
        dlgVarF=soLabelFrame(frame1, text='soCheckbutton - zmienna dialogowa', padding=3)
        dlgVarF.pack(padx=5, pady=5, fill=X)

        #wstawienie opisu
        chDlgEntry=soEntry(dlgVarF,)
        chDlgEntry.insert(0, u'Przykadowy tekst')
        chDlgEntry.pack()

        #wstawienie radiobutton
        def onDlgCheckChange():

            #pobierz aktualna wartosc
            val=self.var_dlgValue.get()

            #aktywuj/deaktywuj pole tekstowe
            if val:
                chDlgEntry['state']=NORMAL
            else:
                chDlgEntry['state']=DISABLED
            
        self.dlgValChB=soCheckbutton(dlgVarF, text='Aktywuj/deaktywuj pole tekstowe', variable=self.var_dlgValue, command=onDlgCheckChange)
        self.dlgValChB.pack()

        ###################### RADIOBUTTON

        #utworz ramke
        radioF=soLabelFrame(frame2, text='soRadiobutton', padding=3)
        radioF.pack(padx=5, pady=5, fill=X)

        #wstaw opis
        rLabel=soLabel(radioF, text=' - ')
        rLabel.pack()

        #wstaw radiobutton
        def onRadioChange():

            #get value
            val=self.var_radioValue.get()

            #change label
            rLabel['text']='Wybrano: '+str(val)
            
        r1=soRadiobutton(radioF, text=u'Opcja 1 - warto 5', value=5, variable=self.var_radioValue, command=onRadioChange)
        r1.pack()
        r2=soRadiobutton(radioF, text=u'Opcja 2 - warto 8', value=8, variable=self.var_radioValue, command=onRadioChange)
        r2.pack()


        ################## BUTTON

        #utworzenie ramki
        buttonF=soLabelFrame(frame2, text='soButton - przycisk', padding=3)
        buttonF.pack(padx=5, pady=5, fill=X)

        def onButtonCmd():
            print 'Wcinito przycisk'
            self.var_scaleValue.set(5.)
            onScaleChange(5.)

        #wstawienie przycisku
        b=soButton(buttonF, text=u'Wcinij', command=onButtonCmd)
        b.pack()

        ################## SEPARATOR

        #utworzenie ramki
        sepF=soLabelFrame(frame2, text='soSeparator', padding=3)
        sepF.pack(padx=5, pady=5, fill=X)

        #wstawienie separatora
        s=soSeparator(sepF, orient='horizontal')
        s.pack(fill=X, pady=2)

        ################## SCALE

        #utworzenie ramki
        scaleF=soLabelFrame(frame2, text='soScale', padding=3)
        scaleF.pack(padx=5, pady=5, fill=X)

        def onScaleChange(value):
            print u'Bieca warto to:', str(value)
            curScaleValue['text']=u'Bieca warto to: %s'%str(value)

        #wstawinie biecej wartosci
        curScaleValue=soLabel(scaleF, text=u'Bieca warto to: %s'%str(self.var_scaleValue.get()))
        curScaleValue.pack()

        #wstawienie suwaka
        s=soScale(scaleF, orient='horizontal', command=onScaleChange,
                      from_=0.,
                      to=10.,
                      variable=self.var_scaleValue)
        s.pack(fill=X, pady=2)

    
        ################## SEPARATOR

        #utworzenie ramki
        sepF=soLabelFrame(frame2, text='soSeparatorWithText', padding=3)
        sepF.pack(padx=5, pady=5, fill=X)

        #wstawienie separatora
        s=soSeparatorWithText(sepF, text='Separator z tekstem')
        s.pack(fill=X, pady=2)

        ##################
        #zarejestrowanie dodatkowych funkcji, ktore beda wywolywane przy odswiezaniu zakladki
        self.addUpdateTabFunctions('addWidgets', updateFunc=[onCheckChange, onRadioChange, onDlgCheckChange])

    #upd
    def updateGeneralTab(self):

        #set results
        status=self.getCompObj().getResults().getResult('status')
        if status:

            #pokaz ramke (jeeli ramka ukrywana aktywna)
            #self.resultLF.show()
            #self.compResF.show()

            #get results        
            S=self.getCompObj().getResults().getResult('S')
            extQ=self.getCompObj().getResults().getResult('extQ')
            tau_II=self.getCompObj().getResults().getResult('tau_II')
            max_tau_II=self.getCompObj().getResults().getResult('max_tau_II')
            S=self.getCompObj().getResults().getResult('S')
            
            #update
            self.res_S.setValue(S)
            self.res_extQ.setValue(extQ)
            self.res_tau_II.setValue(tau_II)
            self.res_maxTau_II.setValue(max_tau_II)
            self.res_comparison.setValues(tau_II, max_tau_II)
            
        else:
 
            #ukryj ramke (jeeli ramka ukrywana aktywna)
            #self.resultLF.hide()
            #self.compResF.hide()

            #clear
            self.res_S.clear()
            self.res_extQ.clear()
            self.res_tau_II.clear()
            self.res_maxTau_II.clear()
            self.res_comparison.clear()
        
    def updateAddTab(self):
        pass
    
    #overwrite
    def getSize(self):
        return (500, 575)
        
class MyComponent(dnComponent.BeamComponent):
    type=dnConstants.COMP_USER_APP
    name='Spawy w blachownicy'
    description=trans(u'Procedura do wymiarowania spaww w blachownicy')
    dirPath=os.path.join(dnConstants.LIB_DIR_PATH, 'components/beam/tutorialComponent/')
    iconPath=os.path.join(dnConstants.LIB_DIR_PATH, 'components/beam/tutorialComponent/img/icon.gif')
    summarySubjects=[
            CONDITION_1,
            CONDITION_2,
                         ]
    def __init__(self, parent, itemId):

        #klasa nadrzdna
        dnComponent.BeamComponent.__init__(self, parent, itemId)

    def setDefault(self):

        #metoda obiektu nadrzednego
        dnComponent.BeamComponent.setDefault(self)

        #zmienna projekotwa
        self.weldThickness=5.

        #inne przykadowe zmienne projektowe roznego typu     
        self.radioValue=5
        self.checkValue=0
        self.controlValue=0
        self.controlValue1=5
        self.comboValue='Opcja 1'
        self.entryValue='Tekst'
        self.scaleValue=2.
        
    # 
    def _calcExtremalForces(self):

        # pobierz wyniki statyki dla elementu
        resultsObj=self.getItem().getResults().getStatResults()

        # pobierz wyniki dla maksymalnej sily tnacej
        maxQ_results = resultsObj.getSectionForcesForElement(
            
                                    loadCombination=True,

                                    #only for comb
                                    leadingValue=1,
                                    envelopeType=sdConstants.ENVELOPE_TYPE_MAX,
                                    laodCombinationType=sdConstants.LOAD_COMB_TYPE_USL_BASIC,    
                                    
                                    userPoints=self.getPoints(),
                                    )        #


        # pobierz wyniki dla minimalnej sily tnacej
        minQ_results = resultsObj.getSectionForcesForElement(
            
                                    loadCombination=True,

                                    #only for comb
                                    leadingValue=1,
                                    envelopeType=sdConstants.ENVELOPE_TYPE_MIN,
                                    laodCombinationType=sdConstants.LOAD_COMB_TYPE_USL_BASIC,    
                                    
                                    userPoints=self.getPoints(),
                                    )        #
        

        # pobierz min i max sile tnaca
        minQ, minQ_combLoadGroups = minQ_results.getExtremal(resultType=1)[0][1:]
        maxQ, maxQ_combLoadGroups = maxQ_results.getExtremal(resultType=1)[1][1:]

        # pobierz wartosc ekstremalna     
        self.extQ = max([fabs(minQ), fabs(maxQ)])
        self.extQ_combLoadGroups = [minQ_combLoadGroups, maxQ_combLoadGroups][fabs(maxQ) > fabs(minQ)]
        
    #
    def doCustomCheck(self):

        #sprawdz profil
        cpObj=self.getItem().getComplexProfile()
        profObjs=cpObj.getProfiles()
        if len(profObjs)>1 or profObjs[0].getSection().getType() not in [ssConstants.WELDED_I_BEAM, ]:
            self.getMessageManager().addMessage((u'Nieprawidowy profil..'), type=dnComponent.MSG_TYPE_ERROR)   
            return False

        #sprawdz grubosc spoiny
        a=self.weldThickness
        if a<2. or a>16.:
            self.getMessageManager().addMessage((u'Nieprawidowa grubo spoiny.'), type=dnComponent.MSG_TYPE_ERROR)   
            return False

        return True
    
    def doBeforeCalculate(self):        
        return True

    def doCalculate(self, soft=False):

        #jezeli konieczne, oblicz ekstremalna tnace
        if not soft:
            self._calcExtremalForces()


        #################################
        ###  dane wejsciowe
        #################################

        #ekstremalna sila tnaca
        extQ = self.extQ
        extQ_combLoadGroups = self.extQ_combLoadGroups

        #charakterystyki geometryczne profilu zlozonego
        cpObj=self.getItem().getComplexProfile()
        Jxg=cpObj.get_Jxg()#cm4

        #charakterystyki dla przekroju
        sObj=cpObj.getProfiles()[0].getSection()
        H=sObj.get_H()#mm
        t=sObj.get_t()#mm
        S=sObj.get_S()#mm
        g=sObj.get_g()#mm
        rx=sObj.get_rx()#mm
        ry=sObj.get_ry()#mm
        S=t*S*(H/2.-t/2.)/1000.#cm3

        #charakterystyki materialowe
        mObj=cpObj.getPrincipalMaterial()
        mDesData=mObj.getDesignData(sObj)
        fd=mDesData['fd']/10.#kN/cm2
        Re=mDesData['Re_min']#MPa

        #grubosc spoiny
        a=self.weldThickness/10.#cm

        #################################
        ###  OBLICZENIA
        #################################

        #ustalenie wspolczynnika
        if Re<=255.:
            alpha_II=0.8
        elif Re<=355.:
            alpha_II=0.7
        else:
            alpha_II=0.6

        #obliczenie spoiny
        tau_II=extQ*S/(Jxg*2.*a)
        max_tau_II=alpha_II*fd

        #obliczenie wytezenia
        useRatio=tau_II/max_tau_II

        #################################
        ###  przypisanie wynikow
        #################################

        #wyniki dodatkowe
        self.getResults().setResults({
            'status':True,
            'S':S,
            'extQ':extQ,
            'extQ_combLoadGroups':extQ_combLoadGroups,
            'tau_II':tau_II,
            'max_tau_II':max_tau_II,
            })

        #wytezenie elementow wzgledem poszczegolnych warunkow projektowych
        self.getResults().setSummary(
            [
                [CONDITION_1, useRatio, ],
                [CONDITION_2, useRatio/2., ],
                ]
            )

        #################################
        ###  DODAJ KOMENTARZ
        #################################

        #komentarz
        if self.getResults().getUseRatio() > 1.:
            self.getMessageManager().addMessage(u'!!!Nono elementu przekroczona!!!.', type=dnComponent.MSG_TYPE_ERROR)
        else:
            self.getMessageManager().addMessage(u'Element zaprojektowany poprawnie.', type=dnComponent.MSG_TYPE_IMPORTANT)
  
        return True

    #
    def insertRTFReport(self, docObj, sectionObj):

        #utworz kontroler
        rtfReportMethod=sdRTFReport.RTFRaport_MethodsObj(self, docObj, sectionObj)

        #spacer
        indent=3*' '
        
        ##DANE OGOLNE      
        self.insertRTFReport_ComponentHeader(rtfReportMethod)

        ##DANE OGOLNE     
        self.insertRTFReport_ItemInfo(rtfReportMethod)
  
  
        ##DANE PROJEKTOWE
        rtfReportMethod.insertTitle('Dane projektowe')
        rtfReportMethod.insertText()
        rtfReportMethod.insertText('%s: %s [mm]'%('Grubo spoiny', str(self.weldThickness)))
        rtfReportMethod.insertText()
        
        ##        
        ##WYNIKI
        ##

        rtfReportMethod.insertTitle('Wyniki dla elementu')

        #wstaw schemat
        graphTools=rtfReportMethod.insertGraph()
        graphTools.initilize(filtr='ELEMENTS', items=[self.getItem().getGraphId(), ])
        graphTools.drawNodes()
        graphTools.drawElements()
        graphTools.drawBoundaryConditions()
        graphTools.drawLoads()
        #graphTools.drawReactions(loadCombination=True, 	leadingValue=None, 	loadCombinationType=sdConstants.LOAD_COMB_TYPE_USL_BASIC,)
        graphTools.drawSectionForces(loadCombination=True, 	leadingValue=1, 	loadCombinationType=sdConstants.LOAD_COMB_TYPE_USL_BASIC,)
        #graphTools.drawDisplacement(loadCombination=True, 	leadingValue=None, 	loadCombinationType=sdConstants.LOAD_COMB_TYPE_USL_BASIC,)
        graphTools.draw()                     

  
        #wstaw opis
        loadCombDescr=self._getStatResultManager().getConfigurationText(
                                     loadCombination=True,
                                     loadCombinationType=sdConstants.LOAD_COMB_TYPE_USL_BASIC,                          
                                     )
        rtfReportMethod.insertText(loadCombDescr.encode('cp1250'))
        rtfReportMethod.insertText()
        
        #wstaw informacje o wytezeniu
        useRatio=self.getResults().getUseRatio()
        rtfReportMethod.insertText('%s: %s'%('Cakowite wytenie elementu', '%.0f'%(useRatio*100.)+'%'),
                                   fontEffect='bold', fontColor=['black', 'red'][useRatio>1.])

        #wstaw informacje o poszczegolnych warunkach projektowych
        resObj=self.getResults()
        for sumName, sumRatio in self.getResults().getSummary():
            rtfReportMethod.insertText(indent+'%s: %s'%(sumName.encode('cp1250'), '%.0f'%(sumRatio*100.))+' %',
                                       fontColor=['black', 'red'][sumRatio>1.])
        rtfReportMethod.insertText()


    #graph
    def drawIcon_OFF(self, canvas, x, y):


        #rysuj symbol
        size=14.
        iconId=canvas.create_polygon(x-size/2., y+size/2., x+size/2., y+size/2. , x+size/2., y-size/2.,
                                              fill='orange',
                                              activefill='red',
                                              outline='black',
                                              width=2,
                                              )
        
        return iconId
    
    #get
    def getDlgClass(self):
        return MyComponentDlg

        