# -*- coding: cp1250 -*-

"""
plik: reactionAnalyzer.py
autor: Krzysztof Szajek (biuro@soldis.com.pl)

Przykad reguy wymiarowania analizujcej reakcje podporowe.

Modu stanowi integraln cz progrmau Soldis PROJEKTANT. Zabrania si rozpowszechniania fragmentw lub caoci poniszego kodu bez zgody AUTORA. Szczegowe warunki licencji - patrz: licencja/licence.txt w katalogu instalacyjnym programu.
"""

#general
from dnBaseLib import *

#python modules
import os
import types
import copy

#solsec modules
import ssConstants

#design modules
import dnConstants
import dnComponent
import dnComponentDlg

#soldis
import sdConstants
import sdRTFReport
import sdSchemeImageMaker

#soldis env
import soSymbols

#add
import PyRTF


#CONSTANTS
REACTION_X='Reakcja x'
REACTION_Y=u'Reakcja y'
REACTION_FI='Reakcja fi'

        
class ReactionAnalyzerDlg(dnComponentDlg.ComponentContextNodeDlg):
    controlWidth=12
    def __init__(self, parent, compObj, **kw):

        #wywolanie klasy bazowej
        dnComponentDlg.ComponentContextNodeDlg.__init__(self, parent, compObj, **kw)

        #utworzenie zakladek
        self.loadCombTabObj=self.registerLoadCombTab()
        self.registerTab('reakcja_x',
                         image=self._createImage('tab_reaction_x_icon'),
                         disableImage=self._createImage('tab_reaction_x_disabled_icon'),
                         createFunc=self.createTab_reaction_x,
                         updateFun=self.updateTab_reaction_x,
                         subjectId=0)
        self.registerTab('reakcja_y',
                         image=self._createImage('tab_reaction_y_icon'),
                         disableImage=self._createImage('tab_reaction_y_disabled_icon'),
                         createFunc=self.createTab_reaction_y,
                         updateFun=self.updateTab_reaction_y,
                         subjectId=1)
        self.registerTab('reakcja_fi',
                         image=self._createImage('tab_reaction_fi_icon'),
                         disableImage=self._createImage('tab_reaction_fi_disabled_icon'),
                         createFunc=self.createTab_reaction_fi,
                         updateFun=self.updateTab_reaction_fi,
                         subjectId=2)
                
        #ustawienie zakladki domyslnej   
        self.setDefaultTab('loadComb')

        #dodanie penelu ze stalymi elementami interfejsu (usun ## aby aktywowac)
        ##self.registerPermamentPanel(createFun=self._createPermamentPanel, updateFun=self._updatePermamentPanel) # PRZYKAD PANELU ZE STAYMI ELEMENTAMI INTERFEJSU

        #dodanie przyciskow z dodatkowymi funkcjami
        self.registerNextPrevButtons()

        #zbudowanie okna
        self.build()
        
    def setVars(self):

        #dodanie zmiennych podstawowych       
        self.addVar('check_X', type='IntVar')
        self.addVar('check_Y', type='IntVar')
        self.addVar('check_Fi', type='IntVar')
        self.addVar('limit_X_min', type='DoubleVar')
        self.addVar('limit_X_max', type='DoubleVar')
        self.addVar('limit_Y_min', type='DoubleVar')
        self.addVar('limit_Y_max', type='DoubleVar')
        self.addVar('limit_Fi_min', type='DoubleVar')
        self.addVar('limit_Fi_max', type='DoubleVar')

        

    #create
    def createTab_reaction_x(self, tab):

        #dodanie naglowka
        l=self.createTabElement_heading(tab, u"Reakcja pozioma")
        l.pack(fill=X)


        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text='Ograniczenia', padding=4)
        f.pack(padx=5, pady=0, fill=X)

        #dodanie ramki wewnetrznej
        iFrame=soFrame(f)
        iFrame.pack()
        
        #dodanie checkbox
        def onCheckChange():
         
            if self.var_check_X.get():
                self.reaction_x_maxLimit['state']=NORMAL
                self.reaction_x_minLimit['state']=NORMAL
            else:
                
                self.reaction_x_maxLimit['state']=DISABLED
                self.reaction_x_minLimit['state']=DISABLED


        self.reaction_x_checkChB=soCheckbutton(iFrame,
                                                variable=self.var_check_X,
                                                command=onCheckChange,
                                                text=trans(u'Uwzgldnij ograniczenia'),
                                                )
        self.reaction_x_checkChB.grid(row=1, column=1, columnspan=1, sticky=W, pady=5)




        #dodanie elementow do kontroli wartosci max i min
        def maxValidate(x):

            #sprawdzenie formatu
            try:
                x=float(x)
            except:
                return self.var_limit_X_max.get()

            #sprawdzenie minimum
            if x<0.:
                x=0.
            
            return x

        def minValidate(x):

            #sprawdzenie formatu
            try:
                x=float(x)
            except:
                return self.var_limit_X_min.get()

            #sprawdzenie minimum
            if x>0.:
                x=0.
            
            return x
                
        self.reaction_x_maxLimit = soControl(iFrame,
                                    label=u'Maksymalna warto: [kN]: ',
                                    variable=self.var_limit_X_max,
                                    step=1.,
                                    allowempty=False,
                                    validatecmd=maxValidate)
        self.reaction_x_maxLimit['selectmode']='normal'
        self.reaction_x_maxLimit.entry['width']=8
        self.reaction_x_maxLimit.grid(row=2, column=1, columnspan=1, sticky=E, padx=10)


        self.reaction_x_minLimit = soControl(iFrame,
                                    label=u'Minimalna warto: [kN]: ',
                                    variable=self.var_limit_X_min,
                                    step=1.,
                                    allowempty=False,
                                    validatecmd=minValidate)
        self.reaction_x_minLimit['selectmode']='normal'
        self.reaction_x_minLimit.entry['width']=8
        self.reaction_x_minLimit.grid(row=3, column=1, columnspan=1, sticky=E, padx=10)



        ################################

        #utworzenie ramki
        self.reaction_x_hideFrame=dnComponentDlg.ResultLabelFrame(tab, text='Wyniki', padding=4)
        self.reaction_x_hideFrame.pack(padx=5, pady=4, fill=BOTH)
        f=self.reaction_x_hideFrame.getFrame()

        #dodanie ramki wewnetrznej
        iFrame=soFrame(f)
        iFrame.pack()

        #dodanie opisu
        l=soLabel(iFrame, text=u'Ekstremalne reakcje')
        l.grid(row=1, column=0, columnspan=2, pady=3)

        #dodanie opisu
        l=soLabel(iFrame, text=u'min')
        l.grid(row=2, column=0)

        #wyswietlenie sily max i min
        self.reaction_x_res_Rx_min=dnComponentDlg.ResultValue(iFrame, lImage=self._createImage('reaction_x_Rx'),
                                                              rImage=self._createImage('unit_kN'), format='%.2f')
        self.reaction_x_res_Rx_min.grid(row=2, column=1, padx=2, sticky=W)

        def getLoadGroups_Rx_min():
            rObj=self.getCompObj().getResults()
            if rObj.hasResult(REACTION_X):
                return rObj.getResult(REACTION_X)['minRx_combLoadGroups']
            else:
                return None
            
        reaction_x_res_Rx_min_combLoadGroups = self.insertCombLoadGroupsInfo(iFrame, getLoadGroupsFun=getLoadGroups_Rx_min)
        reaction_x_res_Rx_min_combLoadGroups.grid(row=2, column=2, padx=2, sticky=W)

        #dodanie opisu
        l=soLabel(iFrame, text=u'max')
        l.grid(row=3, column=0, sticky=E)

        #wyswietlenie sily max i min
        self.reaction_x_res_Rx_max=dnComponentDlg.ResultValue(iFrame, lImage=self._createImage('reaction_x_Rx'),
                                                              rImage=self._createImage('unit_kN'), format='%.2f')
        self.reaction_x_res_Rx_max.grid(row=3, column=1, padx=2, sticky=W)

        def getLoadGroups_Rx_max():
            rObj=self.getCompObj().getResults()
            if rObj.hasResult(REACTION_X):
                return rObj.getResult(REACTION_X)['maxRx_combLoadGroups']
            else:
                return None
            
        reaction_x_res_Rx_max_combLoadGroups = self.insertCombLoadGroupsInfo(iFrame, getLoadGroupsFun=getLoadGroups_Rx_max)
        reaction_x_res_Rx_max_combLoadGroups.grid(row=3, column=2, padx=2, sticky=W)

        ###################################
        
        #dodanie ramki wewnetrznej
        iFrame=soFrame(f)
        iFrame.pack()

        #dodanie opisu
        l=soLabel(iFrame, text=u'Sprawdzenie warunku projektowego')
        l.grid(row=1, column=0, columnspan=1, pady=3)


        #dodanie wynikow
        self.reaction_x_res_comparison=dnComponentDlg.Comparison(iFrame,
                                                      lImage=self._createImage('comparison_Rx'),
                                                      rImage=None,
                                                      lFormat='%.2f', rFormat='%.1f')
        self.reaction_x_res_comparison.grid(row=2, column=0, columnspan=1, sticky=E+W)
        

        
    
    def createTab_reaction_y(self, tab):

        #dodanie naglowka
        l=self.createTabElement_heading(tab, u"Reakcja pionowa")
        l.pack(fill=X)


        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text='Ograniczenia', padding=4)
        f.pack(padx=5, pady=0, fill=X)

        #dodanie ramki wewnetrznej
        iFrame=soFrame(f)
        iFrame.pack()
        
        #dodanie checkbox
        def onCheckChange():
         
            if self.var_check_Y.get():
                self.reaction_y_maxLimit['state']=NORMAL
                self.reaction_y_minLimit['state']=NORMAL
            else:
                
                self.reaction_y_maxLimit['state']=DISABLED
                self.reaction_y_minLimit['state']=DISABLED


        self.reaction_y_checkChB=soCheckbutton(iFrame,
                                                variable=self.var_check_Y,
                                                command=onCheckChange,
                                                text=trans(u'Uwzgldnij ograniczenia'),
                                                )
        self.reaction_y_checkChB.grid(row=1, column=1, columnspan=1, sticky=W, pady=5)




        #dodanie elementow do kontroli wartosci max i min
        def maxValidate(x):

            #sprawdzenie formatu
            try:
                x=float(x)
            except:
                return self.var_limit_Y_max.get()

            #sprawdzenie minimum
            if x<0.:
                x=0.
            
            return x

        def minValidate(x):

            #sprawdzenie formatu
            try:
                x=float(x)
            except:
                return self.var_limit_Y_min.get()

            #sprawdzenie minimum
            if x>0.:
                x=0.
            
            return x
                
        self.reaction_y_maxLimit = soControl(iFrame,
                                    label=u'Maksymalna warto: [kN]: ',
                                    variable=self.var_limit_Y_max,
                                    step=1.,
                                    allowempty=False,
                                    validatecmd=maxValidate)
        self.reaction_y_maxLimit['selectmode']='normal'
        self.reaction_y_maxLimit.entry['width']=8
        self.reaction_y_maxLimit.grid(row=2, column=1, columnspan=1, sticky=E, padx=10)


        self.reaction_y_minLimit = soControl(iFrame,
                                    label=u'Minimalna warto: [kN]: ',
                                    variable=self.var_limit_Y_min,
                                    step=1.,
                                    allowempty=False,
                                    validatecmd=minValidate)
        self.reaction_y_minLimit['selectmode']='normal'
        self.reaction_y_minLimit.entry['width']=8
        self.reaction_y_minLimit.grid(row=3, column=1, columnspan=1, sticky=E, padx=10)



        ################################

        #utworzenie ramki
        self.reaction_y_hideFrame=dnComponentDlg.ResultLabelFrame(tab, text='Wyniki', padding=4)
        self.reaction_y_hideFrame.pack(padx=5, pady=4, fill=BOTH)
        f=self.reaction_y_hideFrame.getFrame()

        #dodanie ramki wewnetrznej
        iFrame=soFrame(f)
        iFrame.pack()

        #dodanie opisu
        l=soLabel(iFrame, text=u'Ekstremalne reakcje')
        l.grid(row=1, column=0, columnspan=2, pady=3)

        #dodanie opisu
        l=soLabel(iFrame, text=u'min')
        l.grid(row=2, column=0)

        #wyswietlenie sily max i min
        self.reaction_y_res_Ry_min=dnComponentDlg.ResultValue(iFrame, lImage=self._createImage('reaction_y_Ry'),
                                                              rImage=self._createImage('unit_kN'), format='%.2f')
        self.reaction_y_res_Ry_min.grid(row=2, column=1, padx=2, sticky=W)

        def getLoadGroups_Ry_min():
            rObj=self.getCompObj().getResults()
            if rObj.hasResult(REACTION_Y):
                return rObj.getResult(REACTION_Y)['minRy_combLoadGroups']
            else:
                return None
            
        reaction_y_res_Ry_min_combLoadGroups = self.insertCombLoadGroupsInfo(iFrame, getLoadGroupsFun=getLoadGroups_Ry_min)
        reaction_y_res_Ry_min_combLoadGroups.grid(row=2, column=2, padx=2, sticky=W)

        #dodanie opisu
        l=soLabel(iFrame, text=u'max')
        l.grid(row=3, column=0, sticky=E)

        #wyswietlenie sily max i min
        self.reaction_y_res_Ry_max=dnComponentDlg.ResultValue(iFrame, lImage=self._createImage('reaction_y_Ry'),
                                                              rImage=self._createImage('unit_kN'), format='%.2f')
        self.reaction_y_res_Ry_max.grid(row=3, column=1, padx=2, sticky=W)

        def getLoadGroups_Ry_max():
            rObj=self.getCompObj().getResults()
            if rObj.hasResult(REACTION_Y):
                return rObj.getResult(REACTION_Y)['maxRy_combLoadGroups']
            else:
                return None
            
        reaction_y_res_Ry_max_combLoadGroups = self.insertCombLoadGroupsInfo(iFrame, getLoadGroupsFun=getLoadGroups_Ry_max)
        reaction_y_res_Ry_max_combLoadGroups.grid(row=3, column=2, padx=2, sticky=W)

        ###################################
        
        #dodanie ramki wewnetrznej
        iFrame=soFrame(f)
        iFrame.pack()

        #dodanie opisu
        l=soLabel(iFrame, text=u'Sprawdzenie warunku projektowego')
        l.grid(row=1, column=0, columnspan=1, pady=3)


        #dodanie wynikow
        self.reaction_y_res_comparison=dnComponentDlg.Comparison(iFrame,
                                                      lImage=self._createImage('comparison_Ry'),
                                                      rImage=None,
                                                      lFormat='%.2f', rFormat='%.1f')
        self.reaction_y_res_comparison.grid(row=2, column=0, columnspan=1, sticky=E+W)
            

    def createTab_reaction_fi(self, tab):

        #dodanie naglowka
        l=self.createTabElement_heading(tab, u"Moment utwierdzenia")
        l.pack(fill=X)


        ################################

        #utworzenie ramki
        f=soLabelFrame(tab, text='Ograniczenia', padding=4)
        f.pack(padx=5, pady=0, fill=X)

        #dodanie ramki wewnetrznej
        iFrame=soFrame(f)
        iFrame.pack()
        
        #dodanie checkbox
        def onCheckChange():
         
            if self.var_check_Fi.get():
                self.reaction_fi_maxLimit['state']=NORMAL
                self.reaction_fi_minLimit['state']=NORMAL
            else:
                
                self.reaction_fi_maxLimit['state']=DISABLED
                self.reaction_fi_minLimit['state']=DISABLED


        self.reaction_fi_checkChB=soCheckbutton(iFrame,
                                                variable=self.var_check_Fi,
                                                command=onCheckChange,
                                                text=trans(u'Uwzgldnij ograniczenia'),
                                                )
        self.reaction_fi_checkChB.grid(row=1, column=1, columnspan=1, sticky=W, pady=5)


        #dodanie elementow do kontroli wartosci max i min
        def maxValidate(x):

            #sprawdzenie formatu
            try:
                x=float(x)
            except:
                return self.var_limit_Fi_max.get()

            #sprawdzenie minimum
            if x<0.:
                x=0.
            
            return x

        def minValidate(x):

            #sprawdzenie formatu
            try:
                x=float(x)
            except:
                return self.var_limit_Fi_min.get()

            #sprawdzenie minimum
            if x>0.:
                x=0.
            
            return x
                
        self.reaction_fi_maxLimit = soControl(iFrame,
                                    label=u'Maksymalna warto: [kN]: ',
                                    variable=self.var_limit_Fi_max,
                                    step=1.,
                                    allowempty=False,
                                    validatecmd=maxValidate)
        self.reaction_fi_maxLimit['selectmode']='normal'
        self.reaction_fi_maxLimit.entry['width']=8
        self.reaction_fi_maxLimit.grid(row=2, column=1, columnspan=1, sticky=E, padx=10)


        self.reaction_fi_minLimit = soControl(iFrame,
                                    label=u'Minimalna warto: [kN]: ',
                                    variable=self.var_limit_Fi_min,
                                    step=1.,
                                    allowempty=False,
                                    validatecmd=minValidate)
        self.reaction_fi_minLimit['selectmode']='normal'
        self.reaction_fi_minLimit.entry['width']=8
        self.reaction_fi_minLimit.grid(row=3, column=1, columnspan=1, sticky=E, padx=10)



        ################################

        #utworzenie ramki
        self.reaction_fi_hideFrame=dnComponentDlg.ResultLabelFrame(tab, text='Wyniki', padding=4)
        self.reaction_fi_hideFrame.pack(padx=5, pady=4, fill=BOTH)
        f=self.reaction_fi_hideFrame.getFrame()

        #dodanie ramki wewnetrznej
        iFrame=soFrame(f)
        iFrame.pack()

        #dodanie opisu
        l=soLabel(iFrame, text=u'Ekstremalne reakcje')
        l.grid(row=1, column=0, columnspan=2, pady=3)

        #dodanie opisu
        l=soLabel(iFrame, text=u'min')
        l.grid(row=2, column=0)

        #wyswietlenie sily max i min
        self.reaction_fi_res_Rfi_min=dnComponentDlg.ResultValue(iFrame, lImage=self._createImage('reaction_fi_Rfi'),
                                                              rImage=self._createImage('unit_kNm'), format='%.2f')
        self.reaction_fi_res_Rfi_min.grid(row=2, column=1, padx=2, sticky=W)

        def getLoadGroups_Rfi_min():
            rObj=self.getCompObj().getResults()
            if rObj.hasResult(REACTION_FI):
                return rObj.getResult(REACTION_FI)['minRfi_combLoadGroups']
            else:
                return None
            
        reaction_fi_res_Rfi_min_combLoadGroups = self.insertCombLoadGroupsInfo(iFrame, getLoadGroupsFun=getLoadGroups_Rfi_min)
        reaction_fi_res_Rfi_min_combLoadGroups.grid(row=2, column=2, padx=2, sticky=W)

        #dodanie opisu
        l=soLabel(iFrame, text=u'max')
        l.grid(row=3, column=0, sticky=E)

        #wyswietlenie sily max i min
        self.reaction_fi_res_Rfi_max=dnComponentDlg.ResultValue(iFrame, lImage=self._createImage('reaction_fi_Rfi'),
                                                              rImage=self._createImage('unit_kNm'), format='%.2f')
        self.reaction_fi_res_Rfi_max.grid(row=3, column=1, padx=2, sticky=W)

        def getLoadGroups_Rfi_max():
            rObj=self.getCompObj().getResults()
            if rObj.hasResult(REACTION_FI):
                return rObj.getResult(REACTION_FI)['maxRfi_combLoadGroups']
            else:
                return None
            
        reaction_fi_res_Rfi_max_combLoadGroups = self.insertCombLoadGroupsInfo(iFrame, getLoadGroupsFun=getLoadGroups_Rfi_max)
        reaction_fi_res_Rfi_max_combLoadGroups.grid(row=3, column=2, padx=2, sticky=W)

        ###################################
        
        #dodanie ramki wewnetrznej
        iFrame=soFrame(f)
        iFrame.pack()

        #dodanie opisu
        l=soLabel(iFrame, text=u'Sprawdzenie warunku projektowego')
        l.grid(row=1, column=0, columnspan=1, pady=3)


        #dodanie wynikow
        self.reaction_fi_res_comparison=dnComponentDlg.Comparison(iFrame,
                                                      lImage=self._createImage('comparison_Rfi'),
                                                      rImage=None,
                                                      lFormat='%.2f', rFormat='%.1f')
        self.reaction_fi_res_comparison.grid(row=2, column=0, columnspan=1, sticky=E+W)

    def _createPermamentPanel(self, parent):


        #uzupelnienie zawartosci okna
        l=soLabel(parent, text=u'Stae elementy interjesu uytkownika')
        l.pack()

        #dodanie ramki wewnetrznej
        iFrame=soFrame(parent)
        iFrame.pack()
        
        #dodanie checkbox
        reaction_x_checkChB=soCheckbutton(iFrame,
                                                variable=self.var_check_X,
                                                #command=onCheckChange,
                                                text=trans(u'Uwzgldnij Rx'),
                                                )
        reaction_x_checkChB.grid(row=1, column=1, columnspan=1, sticky=W, pady=5)

        #dodanie ramki wewnetrznej
        iFrame=soFrame(parent)
        iFrame.pack()
        
        #dodanie checkbox
        reaction_y_checkChB=soCheckbutton(iFrame,
                                                variable=self.var_check_Y,
                                                #command=onCheckChange,
                                                text=trans(u'Uwzgldnij Ry'),
                                                )
        reaction_y_checkChB.grid(row=1, column=1, columnspan=1, sticky=W, pady=5)


        #dodanie ramki wewnetrznej
        iFrame=soFrame(parent)
        iFrame.pack()
        
        #dodanie checkbox
        reaction_fi_checkChB=soCheckbutton(iFrame,
                                                variable=self.var_check_Fi,
                                                #command=onCheckChange,
                                                text=trans(u'Uwzgldnij Rfi'),
                                                )
        reaction_fi_checkChB.grid(row=1, column=1, columnspan=1, sticky=W, pady=5)

        #dodanie ramki wewnetrznej
        iFrame=soFrame(parent)
        iFrame.pack()

        l = soLabel(iFrame, text = 'x min limit:')
        l.grid(row=1, column=1, columnspan=1, sticky=W, pady=5)

        self.permPanel_label = soLabel(iFrame)
        self.permPanel_label.grid(row=1, column=2, columnspan=1, sticky=W, pady=5)

    def _updatePermamentPanel(self):

        self.permPanel_label['text'] = self.var_limit_X_min.get()

    #upd
    def updateTab_reaction_x(self):

        #pobarnie obiektu zarzadzajacego wynikami
        rObj=self.getCompObj().getResults()

        #jezeli znaleziono jakikolwiek wynik zwracana jest lista z szczegolowymi informacjami
        if rObj.hasResult(REACTION_X):

            #pobranie wynikow
            res=rObj.getResult(REACTION_X)

            #wyswietlenie wartosci wynikowych
            self.reaction_x_res_Rx_min.setValue(res['minRx'])
            self.reaction_x_res_Rx_max.setValue(res['maxRx'])

            #wyswietlenie wartosci dla warunkow projektowych
            self.reaction_x_res_comparison.setValues(res['ratio'], 1.)

            #przywrocenie ramki
            self.reaction_x_hideFrame.show()
            
        else:

            #wyczyszczenie                        
            self.reaction_x_res_Rx_min.clear()
            self.reaction_x_res_Rx_max.clear()
            self.reaction_x_res_comparison.clear()

            #ukrycie ramki
            self.reaction_x_hideFrame.hide()

    def updateTab_reaction_y(self):
        
        #pobarnie obiektu zarzadzajacego wynikami
        rObj=self.getCompObj().getResults()

        #jezeli znaleziono jakikolwiek wynik zwracana jest lista z szczegolowymi informacjami
        if rObj.hasResult(REACTION_Y):

            #pobranie wynikow
            res=rObj.getResult(REACTION_Y)

            #wyswietlenie wartosci wynikowych
            self.reaction_y_res_Ry_min.setValue(res['minRy'])
            self.reaction_y_res_Ry_max.setValue(res['maxRy'])

            #wyswietlenie wartosci dla warunkow projektowych
            self.reaction_y_res_comparison.setValues(res['ratio'], 1.)

            #przywrocenie ramki
            self.reaction_y_hideFrame.show()
            
        else:

            #wyczyszczenie                        
            self.reaction_y_res_Ry_min.clear()
            self.reaction_y_res_Ry_max.clear()
            self.reaction_y_res_comparison.clear()

            #ukrycie ramki
            self.reaction_y_hideFrame.hide()
            
    def updateTab_reaction_fi(self):
        
        #pobarnie obiektu zarzadzajacego wynikami
        rObj=self.getCompObj().getResults()

        #jezeli znaleziono jakikolwiek wynik zwracana jest lista z szczegolowymi informacjami
        if rObj.hasResult(REACTION_FI):

            #pobranie wynikow
            res=rObj.getResult(REACTION_FI)

            #wyswietlenie wartosci wynikowych
            self.reaction_fi_res_Rfi_min.setValue(res['minRfi'])
            self.reaction_fi_res_Rfi_max.setValue(res['maxRfi'])

            #wyswietlenie wartosci dla warunkow projektowych
            self.reaction_fi_res_comparison.setValues(res['ratio'], 1.)

            #przywrocenie ramki
            self.reaction_fi_hideFrame.show()
            
        else:

            #wyczyszczenie                        
            self.reaction_fi_res_Rfi_min.clear()
            self.reaction_fi_res_Rfi_max.clear()
            self.reaction_fi_res_comparison.clear()

            #ukrycie ramki
            self.reaction_fi_hideFrame.hide()
    #
    def updateTabsStatus(self):

        pass
    
        #ponizej zamieszczono przyklad kontroli zakladek
        #zakladka zostaje wlaczona gdy w wynikach jest odpowiedni rezultat
        #w niniejszym komponencie nie ma koniecznosci kontroli aktywnosci zakladek

        #zablokowanie wszystkich
        ##self.changeAllTabsStatus(DISABLED)

        #odblokowanie        
        ##self.changeTabStatus(self.loadCombTabObj['name'], NORMAL)

        #sprawdzenie ktore odblokowac
        ##if not self.getCompObj().getResults().getError():
            

            #pobarnie obiektu zarzadzajacego wynikami
            ##rObj=self.getCompObj().getResults()

            ##if rObj.hasResult(REACTION_X):
            ##    self.changeTabStatus('reakcja_x', NORMAL)

            ##if rObj.hasResult(REACTION_Y):
            ##    self.changeTabStatus('reakcja_y', NORMAL)

            ##if rObj.hasResult(REACTION_FI):
            ##    self.changeTabStatus('reakcja_fi', NORMAL)


    #
    def getSize(self):
        return (410,430)

       
class ReactionAnalyzer(dnComponent.NodeComponent):
    type=dnConstants.COMP_REACTIONS_ANALYZER
    name=u'Reakcje wzowe'
    description=trans(u'Procedura do analizy reakcji wzowych')
    dirPath=os.path.join(dnConstants.LIB_DIR_PATH, 'components/node/reactionAnalyzer/')
    iconPath=os.path.join(dnConstants.LIB_DIR_PATH, 'components/node/reactionAnalyzer/img/icon.gif')
    summarySubjects=[
            REACTION_X,
            REACTION_Y,
            REACTION_FI,
                         ]
    def __init__(self, parent, itemId):

        #base class
        dnComponent.NodeComponent.__init__(self, parent, itemId)

    def setDefault(self):

        #metoda obiektu nadrzednego
        dnComponent.NodeComponent.setDefault(self)

        #parametry 
        self.check_X=1
        self.check_Y=1
        self.check_Fi=1
        self.limit_X_min=-10.
        self.limit_X_max=10.
        self.limit_Y_min=-10.
        self.limit_Y_max=10.
        self.limit_Fi_min=-10.
        self.limit_Fi_max=10.

        #zmienne ponizej sa dziedziczone z klasy *Component* i mozna nimi operowac uzywajca zakladki *loadComb*
        #zmienne zostaly dodane do grupy zmiennych, ktory wplywaja na wyniki analizy (patrz dokumentacja *addHardRecalcVars*)
        ##self.loadCombination=1
        ##self.loadCombinationType=sdConstants.LOAD_COMB_TYPE_USL_BASIC


    #
    def doCustomCheck(self):

        #sprawdzenie czy w wezle jest podpora
        nObj=self.getItem()
        bcObj=nObj.getBC()
        if bcObj == None:
            self.getMessageManager().addMessage((u'W wle nie zdefiniowano podpory.'), type=dnComponent.MSG_TYPE_ERROR)   
            return False

        return True
    
    def doBeforeCalculate(self):        

        #nie ma koniecznosci wykonania dodatkowych operacji na danych wejsciowych

        return True

    def doCalculate(self, soft=False):

        #jezeli konieczne, aktualizuj sily przekrojowe
        if not soft:

            #pobranie ekstremalnych reakcji
            nObj=self.getItem()
            bcObj=nObj.getBC()
            rObj=bcObj.getResults().getStatResults()
            
            self.minReactions=rObj.getReactions(
                                        loadCombination=True,
                                        leadingValue=None,
                                        envelopeType=sdConstants.ENVELOPE_TYPE_MIN,
                                        laodCombinationType=self.loadCombinationType,
                                           )


            self.maxReactions=rObj.getReactions(
                                        loadCombination=True,
                                        leadingValue=None,
                                        envelopeType=sdConstants.ENVELOPE_TYPE_MAX,
                                        laodCombinationType=self.loadCombinationType,
                                           )

        #################################
        ###  DANE WEJSCIOWE
        #################################

        minRx=self.minReactions.getReaction(resultType=0)
        minRy=self.minReactions.getReaction(resultType=1)
        minRfi=self.minReactions.getReaction(resultType=2)
        maxRx=self.maxReactions.getReaction(resultType=0)
        maxRy=self.maxReactions.getReaction(resultType=1)
        maxRfi=self.maxReactions.getReaction(resultType=2)        

        minRx_combLoadGroups = self.minReactions.getLoadGroupList(resultType=0)
        minRy_combLoadGroups = self.minReactions.getLoadGroupList(resultType=1)
        minRfi_combLoadGroups = self.minReactions.getLoadGroupList(resultType=2)
        maxRx_combLoadGroups = self.maxReactions.getLoadGroupList(resultType=0)
        maxRy_combLoadGroups = self.maxReactions.getLoadGroupList(resultType=1)
        maxRfi_combLoadGroups = self.maxReactions.getLoadGroupList(resultType=2)


        #################################
        ###  OBLICZENIA
        #################################


        #obliczenie warunkow projektowych
        
        ####################################
        ### REAKCJA RX
        ####################################

        if self.check_X:#limit
            if minRx<0.:
                min_ratio=minRx/self.limit_X_min
            else:
                min_ratio=0.
            if maxRx>0.:
                max_ratio=maxRx/self.limit_X_max
            else:
                max_ratio=0.

            #utworzenie slownika z wynikami
            pData={}
            pData['minRx'] = minRx
            pData['minRx_combLoadGroups'] = minRx_combLoadGroups
            pData['maxRx'] = maxRx
            pData['maxRx_combLoadGroups'] = maxRx_combLoadGroups

            #obliczenie wyniku
            pData['ratio']=max(min_ratio, max_ratio)
                
            #dodanie wynikow      
            self.getResults().setResults({
                REACTION_X:pData,
                })

        

        ####################################
        ### REAKCJA RY
        ####################################

        if self.check_Y:#limit
            if minRy<0.:
                min_ratio=minRy/self.limit_Y_min
            else:
                min_ratio=0.
            if maxRy>0.:
                max_ratio=maxRy/self.limit_Y_max
            else:
                max_ratio=0.


            #utworzenie slownika z wynikami
            pData={}
            pData['minRy'] = minRy
            pData['minRy_combLoadGroups'] = minRy_combLoadGroups
            pData['maxRy'] = maxRy
            pData['maxRy_combLoadGroups'] = maxRy_combLoadGroups

            #obliczenie wyniku
            pData['ratio']=max(min_ratio, max_ratio)
                
            #dodanie wynikow      
            self.getResults().setResults({
                REACTION_Y:pData,
                })
      


        ####################################
        ### REAKCJA RFI
        ####################################

        
        if self.check_Fi:#limit
            if minRfi<0.:
                min_ratio=minRfi/self.limit_Fi_min
            else:
                min_ratio=0.
            if maxRfi>0.:
                max_ratio=maxRfi/self.limit_Fi_max
            else:
                max_ratio=0.

            #utworzenie slownika z wynikami
            pData={}
            pData['minRfi'] = minRfi
            pData['minRfi_combLoadGroups'] = minRfi_combLoadGroups
            pData['maxRfi'] = maxRfi
            pData['maxRfi_combLoadGroups'] = maxRfi_combLoadGroups

            #obliczenie wyniku
            pData['ratio']=max(min_ratio, max_ratio)
                
            #dodanie wynikow      
            self.getResults().setResults({
                REACTION_FI:pData,
                })


        
        #################################
        ###  OKRESLENIE WYTEZENIA ELEMENTU
        #################################

        #get max ratios
        if self.getResults().hasResult(REACTION_X):
            rxRatio=self.getResults().getResult(REACTION_X)['ratio']
        else:
            rxRatio=0.
        if self.getResults().hasResult(REACTION_Y):
            ryRatio=self.getResults().getResult(REACTION_Y)['ratio']
        else:
            ryRatio=0.
        if self.getResults().hasResult(REACTION_FI):
            rfiRatio=self.getResults().getResult(REACTION_FI)['ratio']
        else:
            rfiRatio=0.
        maxRatios={
            REACTION_X:rxRatio,
            REACTION_Y:ryRatio,
            REACTION_FI:rfiRatio
            }
        ratio=max(maxRatios.values())
                
        #przypisanie wynikow dla poszczegolnych warunkow projektowych
        ##self.getResults().setSummary( [[h, maxRatios[h]] for h in self.summarySubjects] )
        #lub
        self.getResults().setSummary( [
            [REACTION_X, maxRatios[REACTION_X]],
            [REACTION_Y, maxRatios[REACTION_Y]],
            [REACTION_FI, maxRatios[REACTION_FI]],
            ] )
        

        #################################
        ###  DODANIE KOMENTARZA
        #################################

        #komentarz
        if self.getResults().getUseRatio() > 1.:
            self.getMessageManager().addMessage(u'!!!Nono elementu przekroczona!!!.', type=dnComponent.MSG_TYPE_ERROR)
        else:
            self.getMessageManager().addMessage(u'Element zaprojektowany poprawnie.', type=dnComponent.MSG_TYPE_IMPORTANT)

        return True

    #
    def insertRTFReport(self, docObj, sectionObj):

        #utworzenie obiektu z metodami do tworzenia raportu
        rtfReportMethod=sdRTFReport.RTFRaport_MethodsObj(self, docObj, sectionObj)

        #spacer
        indent=3*' '

        #dodanie naglowka
        self.insertRTFReport_ComponentHeader(rtfReportMethod)

        #wstawienie informacji o wezle
        self.insertRTFReport_ItemInfo(rtfReportMethod)
  
        #zmienne projektowe
        rtfReportMethod.insertTitle('Dane projektowe')
        rtfReportMethod.insertText()
        rtfReportMethod.insertText('Sprawdzaj warunek dla Rx: %s'%(['nie', 'tak'][self.check_X]))
        if self.check_X:
            rtfReportMethod.insertText(indent+'Warto minimalna: %s [kN]'%(str(self.limit_X_min)))
            rtfReportMethod.insertText(indent+'Warto maksymalna: %s [kN]'%(str(self.limit_X_max)))
        rtfReportMethod.insertText('Sprawdzaj warunek dla Ry: %s'%(['nie', 'tak'][self.check_Y]))
        if self.check_Y:
            rtfReportMethod.insertText(indent+'Warto minimalna: %s [kN]'%(str(self.limit_Y_min)))
            rtfReportMethod.insertText(indent+'Warto maksymalna: %s [kN]'%(str(self.limit_Y_max)))
        rtfReportMethod.insertText('Sprawdzaj warunek dla Rfi: %s'%(['nie', 'tak'][self.check_Fi]))
        if self.check_Fi:
            rtfReportMethod.insertText(indent+'Warto minimalna: %s [kN]'%(str(self.limit_Fi_min)))
            rtfReportMethod.insertText(indent+'Warto maksymalna: %s [kN]'%(str(self.limit_Fi_max)))
        rtfReportMethod.insertText()
        
        ##        
        ##RESULTS
        ##

        rtfReportMethod.insertTitle('Reakcje dla wza')


        #pobranie elementow dochodzacych do wezla
        elObjs=self.getItem().getElements()

        #dodanie rysunku modelu (lub jego fragmentu)
        graphTools=rtfReportMethod.insertGraph()
        graphTools.initilize(filtr='ELEMENTS', items=[elObj.getGraphId() for elObj in elObjs ])
        graphTools.drawNodes()
        graphTools.drawElements()
        graphTools.drawBoundaryConditions()
        graphTools.drawLoads()
        graphTools.drawReactions(loadCombination=True, 	leadingValue=None, 	loadCombinationType=sdConstants.LOAD_COMB_TYPE_USL_BASIC,)
        #graphTools.drawSectionForces(loadCombination=True, 	leadingValue=None, 	loadCombinationType=sdConstants.LOAD_COMB_TYPE_USL_BASIC,)
        #graphTools.drawDisplacement(loadCombination=True, 	leadingValue=None, 	loadCombinationType=sdConstants.LOAD_COMB_TYPE_USL_BASIC,)
        graphTools.draw()                     

        #dodanie opisu wykresu
        loadCombDescr=self._getStatResultManager().getConfigurationText(
                                     loadCombination=True,
                                     loadCombinationType=sdConstants.LOAD_COMB_TYPE_USL_BASIC,                           
                                     )
        rtfReportMethod.insertText(loadCombDescr.encode('cp1250'))
        rtfReportMethod.insertText()
        
        #dodanie podsumowania 
        useRatio=self.getResults().getUseRatio()
        rtfReportMethod.insertText('%s: %s'%('Cakowite wytenie elementu', '%.0f'%(useRatio*100.)+'%'),
                                            fontEffect='bold', fontColor=['black', 'red'][useRatio>1.])
        rtfReportMethod.insertText()
        
        #dodanie podsumowania
        resObj=self.getResults()
        for sumName, sumRatio in self.getResults().getSummary():
            rtfReportMethod.insertText(indent+'%s: %s'%(sumName.encode('cp1250'), '%.0f'%(sumRatio*100.))+' %',
                                       fontColor=['black', 'red'][sumRatio>1.])
        rtfReportMethod.insertText()



    #graph
    def drawIcon_OFF(self, canvas, x, y):

        #draw symbol
        iconId=canvas.create_text(x, y,
                                              text=soSymbols.latex['Downarrow'],
                                              fill='blue',
                                              #anchor=W,
                                              activefill='red',
                                              font=('symbol', 13, 'bold'),
                                              )
        return iconId
    
    #get
    def getDlgClass(self):
        return ReactionAnalyzerDlg

        